---
title: wezterm.nerdfonts
tags:
 - utility
 - font
 - string
---
# `wezterm.nerdfonts`

{{since('20220319-142410-0fcdea07')}}

A special userdata value that can be used to resolve the symbolic name
of a glyph from the [Nerd Fonts](https://www.nerdfonts.com/cheat-sheet)
font set into a string that can be used for example when formatting
status lines and titles in your wezterm configuration.

WezTerm includes `Nerd Font Symbols Font` as a default font fallback
which means that these special symbols are available even without 
requiring you to use a patched font.

This example shows how to lookup `wezterm.nerdfonts.mdi_clock`,
the Material Design Icons glyph representing a clock, and use
that together with the current date/time in the status area:

```lua
local wezterm = require 'wezterm'

wezterm.on('update-right-status', function(window, pane)
  -- "Wed Mar 3 08:14"
  local date = wezterm.strftime '%a %b %-d %H:%M '

  window:set_right_status(wezterm.format {
    { Text = wezterm.nerdfonts.mdi_clock .. ' ' .. date },
  })
end)
```

The following symbols are defined:

<style>
.big {
  font-size: 3em;
}
</style>

<!--
This block generated by:
:r! cd termwiz && cargo run --example gennerdfonts 2>/dev/null
-->
| | |
|-|-|
|<span class="nerdfont big">&#xeb99;</span>|cod_account|
|<span class="nerdfont big">&#xea97;</span>|cod_activate_breakpoints|
|<span class="nerdfont big">&#xea60;</span>|cod_add|
|<span class="nerdfont big">&#xea98;</span>|cod_archive|
|<span class="nerdfont big">&#xea99;</span>|cod_arrow_both|
|<span class="nerdfont big">&#xea9a;</span>|cod_arrow_down|
|<span class="nerdfont big">&#xea9b;</span>|cod_arrow_left|
|<span class="nerdfont big">&#xea9c;</span>|cod_arrow_right|
|<span class="nerdfont big">&#xea9d;</span>|cod_arrow_small_down|
|<span class="nerdfont big">&#xea9e;</span>|cod_arrow_small_left|
|<span class="nerdfont big">&#xea9f;</span>|cod_arrow_small_right|
|<span class="nerdfont big">&#xeaa0;</span>|cod_arrow_small_up|
|<span class="nerdfont big">&#xebcb;</span>|cod_arrow_swap|
|<span class="nerdfont big">&#xeaa1;</span>|cod_arrow_up|
|<span class="nerdfont big">&#xebd8;</span>|cod_azure|
|<span class="nerdfont big">&#xebe8;</span>|cod_azure_devops|
|<span class="nerdfont big">&#xea79;</span>|cod_beaker|
|<span class="nerdfont big">&#xebe1;</span>|cod_beaker_stop|
|<span class="nerdfont big">&#xeaa2;</span>|cod_bell|
|<span class="nerdfont big">&#xeb9a;</span>|cod_bell_dot|
|<span class="nerdfont big">&#xeaa3;</span>|cod_bold|
|<span class="nerdfont big">&#xeaa4;</span>|cod_book|
|<span class="nerdfont big">&#xeaa5;</span>|cod_bookmark|
|<span class="nerdfont big">&#xebe5;</span>|cod_bracket_dot|
|<span class="nerdfont big">&#xebe6;</span>|cod_bracket_error|
|<span class="nerdfont big">&#xeaac;</span>|cod_briefcase|
|<span class="nerdfont big">&#xeaad;</span>|cod_broadcast|
|<span class="nerdfont big">&#xeaae;</span>|cod_browser|
|<span class="nerdfont big">&#xeaaf;</span>|cod_bug|
|<span class="nerdfont big">&#xeab0;</span>|cod_calendar|
|<span class="nerdfont big">&#xeb92;</span>|cod_call_incoming|
|<span class="nerdfont big">&#xeb93;</span>|cod_call_outgoing|
|<span class="nerdfont big">&#xeab1;</span>|cod_case_sensitive|
|<span class="nerdfont big">&#xeab2;</span>|cod_check|
|<span class="nerdfont big">&#xebb1;</span>|cod_check_all|
|<span class="nerdfont big">&#xeab3;</span>|cod_checklist|
|<span class="nerdfont big">&#xeab4;</span>|cod_chevron_down|
|<span class="nerdfont big">&#xeab5;</span>|cod_chevron_left|
|<span class="nerdfont big">&#xeab6;</span>|cod_chevron_right|
|<span class="nerdfont big">&#xeab7;</span>|cod_chevron_up|
|<span class="nerdfont big">&#xeab8;</span>|cod_chrome_close|
|<span class="nerdfont big">&#xeab9;</span>|cod_chrome_maximize|
|<span class="nerdfont big">&#xeaba;</span>|cod_chrome_minimize|
|<span class="nerdfont big">&#xeabb;</span>|cod_chrome_restore|
|<span class="nerdfont big">&#xeabc;</span>|cod_circle|
|<span class="nerdfont big">&#xea71;</span>|cod_circle_filled|
|<span class="nerdfont big">&#xebb5;</span>|cod_circle_large|
|<span class="nerdfont big">&#xebb4;</span>|cod_circle_large_filled|
|<span class="nerdfont big">&#xeabd;</span>|cod_circle_slash|
|<span class="nerdfont big">&#xeb8a;</span>|cod_circle_small_filled|
|<span class="nerdfont big">&#xeabe;</span>|cod_circuit_board|
|<span class="nerdfont big">&#xeabf;</span>|cod_clear_all|
|<span class="nerdfont big">&#xeac0;</span>|cod_clippy|
|<span class="nerdfont big">&#xea76;</span>|cod_close|
|<span class="nerdfont big">&#xeac1;</span>|cod_close_all|
|<span class="nerdfont big">&#xebaa;</span>|cod_cloud|
|<span class="nerdfont big">&#xeac2;</span>|cod_cloud_download|
|<span class="nerdfont big">&#xeac3;</span>|cod_cloud_upload|
|<span class="nerdfont big">&#xeac4;</span>|cod_code|
|<span class="nerdfont big">&#xeac5;</span>|cod_collapse_all|
|<span class="nerdfont big">&#xeac6;</span>|cod_color_mode|
|<span class="nerdfont big">&#xebb6;</span>|cod_combine|
|<span class="nerdfont big">&#xea6b;</span>|cod_comment|
|<span class="nerdfont big">&#xeac7;</span>|cod_comment_discussion|
|<span class="nerdfont big">&#xebd5;</span>|cod_compass|
|<span class="nerdfont big">&#xebd7;</span>|cod_compass_active|
|<span class="nerdfont big">&#xebd6;</span>|cod_compass_dot|
|<span class="nerdfont big">&#xebcc;</span>|cod_copy|
|<span class="nerdfont big">&#xeac9;</span>|cod_credit_card|
|<span class="nerdfont big">&#xeacc;</span>|cod_dash|
|<span class="nerdfont big">&#xeacd;</span>|cod_dashboard|
|<span class="nerdfont big">&#xeace;</span>|cod_database|
|<span class="nerdfont big">&#xead8;</span>|cod_debug|
|<span class="nerdfont big">&#xebdc;</span>|cod_debug_all|
|<span class="nerdfont big">&#xeb91;</span>|cod_debug_alt|
|<span class="nerdfont big">&#xeba8;</span>|cod_debug_alt_small|
|<span class="nerdfont big">&#xeaa7;</span>|cod_debug_breakpoint_conditional|
|<span class="nerdfont big">&#xeaa6;</span>|cod_debug_breakpoint_conditional_unverified|
|<span class="nerdfont big">&#xeaa9;</span>|cod_debug_breakpoint_data|
|<span class="nerdfont big">&#xeaa8;</span>|cod_debug_breakpoint_data_unverified|
|<span class="nerdfont big">&#xeb88;</span>|cod_debug_breakpoint_function|
|<span class="nerdfont big">&#xeb87;</span>|cod_debug_breakpoint_function_unverified|
|<span class="nerdfont big">&#xeaab;</span>|cod_debug_breakpoint_log|
|<span class="nerdfont big">&#xeaaa;</span>|cod_debug_breakpoint_log_unverified|
|<span class="nerdfont big">&#xeb8c;</span>|cod_debug_breakpoint_unsupported|
|<span class="nerdfont big">&#xeb9b;</span>|cod_debug_console|
|<span class="nerdfont big">&#xeacf;</span>|cod_debug_continue|
|<span class="nerdfont big">&#xebe0;</span>|cod_debug_continue_small|
|<span class="nerdfont big">&#xebdd;</span>|cod_debug_coverage|
|<span class="nerdfont big">&#xead0;</span>|cod_debug_disconnect|
|<span class="nerdfont big">&#xebd0;</span>|cod_debug_line_by_line|
|<span class="nerdfont big">&#xead1;</span>|cod_debug_pause|
|<span class="nerdfont big">&#xebc0;</span>|cod_debug_rerun|
|<span class="nerdfont big">&#xead2;</span>|cod_debug_restart|
|<span class="nerdfont big">&#xeb90;</span>|cod_debug_restart_frame|
|<span class="nerdfont big">&#xeb8e;</span>|cod_debug_reverse_continue|
|<span class="nerdfont big">&#xeb8b;</span>|cod_debug_stackframe|
|<span class="nerdfont big">&#xeb89;</span>|cod_debug_stackframe_active|
|<span class="nerdfont big">&#xead3;</span>|cod_debug_start|
|<span class="nerdfont big">&#xeb8f;</span>|cod_debug_step_back|
|<span class="nerdfont big">&#xead4;</span>|cod_debug_step_into|
|<span class="nerdfont big">&#xead5;</span>|cod_debug_step_out|
|<span class="nerdfont big">&#xead6;</span>|cod_debug_step_over|
|<span class="nerdfont big">&#xead7;</span>|cod_debug_stop|
|<span class="nerdfont big">&#xea78;</span>|cod_desktop_download|
|<span class="nerdfont big">&#xeada;</span>|cod_device_camera|
|<span class="nerdfont big">&#xead9;</span>|cod_device_camera_video|
|<span class="nerdfont big">&#xeadb;</span>|cod_device_mobile|
|<span class="nerdfont big">&#xeae1;</span>|cod_diff|
|<span class="nerdfont big">&#xeadc;</span>|cod_diff_added|
|<span class="nerdfont big">&#xeadd;</span>|cod_diff_ignored|
|<span class="nerdfont big">&#xeade;</span>|cod_diff_modified|
|<span class="nerdfont big">&#xeadf;</span>|cod_diff_removed|
|<span class="nerdfont big">&#xeae0;</span>|cod_diff_renamed|
|<span class="nerdfont big">&#xeae2;</span>|cod_discard|
|<span class="nerdfont big">&#xea73;</span>|cod_edit|
|<span class="nerdfont big">&#xeae3;</span>|cod_editor_layout|
|<span class="nerdfont big">&#xea7c;</span>|cod_ellipsis|
|<span class="nerdfont big">&#xeae4;</span>|cod_empty_window|
|<span class="nerdfont big">&#xea87;</span>|cod_error|
|<span class="nerdfont big">&#xeae5;</span>|cod_exclude|
|<span class="nerdfont big">&#xeb95;</span>|cod_expand_all|
|<span class="nerdfont big">&#xebac;</span>|cod_export|
|<span class="nerdfont big">&#xeae6;</span>|cod_extensions|
|<span class="nerdfont big">&#xea70;</span>|cod_eye|
|<span class="nerdfont big">&#xeae7;</span>|cod_eye_closed|
|<span class="nerdfont big">&#xeb96;</span>|cod_feedback|
|<span class="nerdfont big">&#xea7b;</span>|cod_file|
|<span class="nerdfont big">&#xeae8;</span>|cod_file_binary|
|<span class="nerdfont big">&#xeae9;</span>|cod_file_code|
|<span class="nerdfont big">&#xeaea;</span>|cod_file_media|
|<span class="nerdfont big">&#xeaeb;</span>|cod_file_pdf|
|<span class="nerdfont big">&#xeaec;</span>|cod_file_submodule|
|<span class="nerdfont big">&#xeaed;</span>|cod_file_symlink_directory|
|<span class="nerdfont big">&#xeaee;</span>|cod_file_symlink_file|
|<span class="nerdfont big">&#xeaef;</span>|cod_file_zip|
|<span class="nerdfont big">&#xeaf0;</span>|cod_files|
|<span class="nerdfont big">&#xeaf1;</span>|cod_filter|
|<span class="nerdfont big">&#xebce;</span>|cod_filter_filled|
|<span class="nerdfont big">&#xeaf2;</span>|cod_flame|
|<span class="nerdfont big">&#xeaf5;</span>|cod_fold|
|<span class="nerdfont big">&#xeaf3;</span>|cod_fold_down|
|<span class="nerdfont big">&#xeaf4;</span>|cod_fold_up|
|<span class="nerdfont big">&#xea83;</span>|cod_folder|
|<span class="nerdfont big">&#xeaf6;</span>|cod_folder_active|
|<span class="nerdfont big">&#xebdf;</span>|cod_folder_library|
|<span class="nerdfont big">&#xeaf7;</span>|cod_folder_opened|
|<span class="nerdfont big">&#xeaf8;</span>|cod_gear|
|<span class="nerdfont big">&#xeaf9;</span>|cod_gift|
|<span class="nerdfont big">&#xeafa;</span>|cod_gist_secret|
|<span class="nerdfont big">&#xeafc;</span>|cod_git_commit|
|<span class="nerdfont big">&#xeafd;</span>|cod_git_compare|
|<span class="nerdfont big">&#xeafe;</span>|cod_git_merge|
|<span class="nerdfont big">&#xea64;</span>|cod_git_pull_request|
|<span class="nerdfont big">&#xebda;</span>|cod_git_pull_request_closed|
|<span class="nerdfont big">&#xebbc;</span>|cod_git_pull_request_create|
|<span class="nerdfont big">&#xebdb;</span>|cod_git_pull_request_draft|
|<span class="nerdfont big">&#xea84;</span>|cod_github|
|<span class="nerdfont big">&#xeaff;</span>|cod_github_action|
|<span class="nerdfont big">&#xeb00;</span>|cod_github_alt|
|<span class="nerdfont big">&#xeba1;</span>|cod_github_inverted|
|<span class="nerdfont big">&#xeb01;</span>|cod_globe|
|<span class="nerdfont big">&#xea94;</span>|cod_go_to_file|
|<span class="nerdfont big">&#xeb02;</span>|cod_grabber|
|<span class="nerdfont big">&#xeb03;</span>|cod_graph|
|<span class="nerdfont big">&#xebad;</span>|cod_graph_left|
|<span class="nerdfont big">&#xebe2;</span>|cod_graph_line|
|<span class="nerdfont big">&#xebe3;</span>|cod_graph_scatter|
|<span class="nerdfont big">&#xeb04;</span>|cod_gripper|
|<span class="nerdfont big">&#xeb97;</span>|cod_group_by_ref_type|
|<span class="nerdfont big">&#xeb05;</span>|cod_heart|
|<span class="nerdfont big">&#xea82;</span>|cod_history|
|<span class="nerdfont big">&#xeb06;</span>|cod_home|
|<span class="nerdfont big">&#xeb07;</span>|cod_horizontal_rule|
|<span class="nerdfont big">&#xeb08;</span>|cod_hubot|
|<span class="nerdfont big">&#xeb09;</span>|cod_inbox|
|<span class="nerdfont big">&#xea74;</span>|cod_info|
|<span class="nerdfont big">&#xebd1;</span>|cod_inspect|
|<span class="nerdfont big">&#xebd9;</span>|cod_issue_draft|
|<span class="nerdfont big">&#xeb0b;</span>|cod_issue_reopened|
|<span class="nerdfont big">&#xeb0c;</span>|cod_issues|
|<span class="nerdfont big">&#xeb0d;</span>|cod_italic|
|<span class="nerdfont big">&#xeb0e;</span>|cod_jersey|
|<span class="nerdfont big">&#xeb0f;</span>|cod_json|
|<span class="nerdfont big">&#xeb10;</span>|cod_kebab_vertical|
|<span class="nerdfont big">&#xeb11;</span>|cod_key|
|<span class="nerdfont big">&#xeb12;</span>|cod_law|
|<span class="nerdfont big">&#xebd2;</span>|cod_layers|
|<span class="nerdfont big">&#xebd4;</span>|cod_layers_active|
|<span class="nerdfont big">&#xebd3;</span>|cod_layers_dot|
|<span class="nerdfont big">&#xebeb;</span>|cod_layout|
|<span class="nerdfont big">&#xeb9c;</span>|cod_library|
|<span class="nerdfont big">&#xea61;</span>|cod_lightbulb|
|<span class="nerdfont big">&#xeb13;</span>|cod_lightbulb_autofix|
|<span class="nerdfont big">&#xeb15;</span>|cod_link|
|<span class="nerdfont big">&#xeb14;</span>|cod_link_external|
|<span class="nerdfont big">&#xeb83;</span>|cod_list_filter|
|<span class="nerdfont big">&#xeb84;</span>|cod_list_flat|
|<span class="nerdfont big">&#xeb16;</span>|cod_list_ordered|
|<span class="nerdfont big">&#xeb85;</span>|cod_list_selection|
|<span class="nerdfont big">&#xeb86;</span>|cod_list_tree|
|<span class="nerdfont big">&#xeb17;</span>|cod_list_unordered|
|<span class="nerdfont big">&#xeb18;</span>|cod_live_share|
|<span class="nerdfont big">&#xeb19;</span>|cod_loading|
|<span class="nerdfont big">&#xeb1a;</span>|cod_location|
|<span class="nerdfont big">&#xea75;</span>|cod_lock|
|<span class="nerdfont big">&#xebe7;</span>|cod_lock_small|
|<span class="nerdfont big">&#xebae;</span>|cod_magnet|
|<span class="nerdfont big">&#xeb1c;</span>|cod_mail|
|<span class="nerdfont big">&#xeb1b;</span>|cod_mail_read|
|<span class="nerdfont big">&#xeb1d;</span>|cod_markdown|
|<span class="nerdfont big">&#xeb1e;</span>|cod_megaphone|
|<span class="nerdfont big">&#xeb1f;</span>|cod_mention|
|<span class="nerdfont big">&#xeb94;</span>|cod_menu|
|<span class="nerdfont big">&#xebab;</span>|cod_merge|
|<span class="nerdfont big">&#xeb20;</span>|cod_milestone|
|<span class="nerdfont big">&#xea69;</span>|cod_mirror|
|<span class="nerdfont big">&#xeb21;</span>|cod_mortar_board|
|<span class="nerdfont big">&#xeb22;</span>|cod_move|
|<span class="nerdfont big">&#xeb23;</span>|cod_multiple_windows|
|<span class="nerdfont big">&#xeb24;</span>|cod_mute|
|<span class="nerdfont big">&#xea7f;</span>|cod_new_file|
|<span class="nerdfont big">&#xea80;</span>|cod_new_folder|
|<span class="nerdfont big">&#xebea;</span>|cod_newline|
|<span class="nerdfont big">&#xeb25;</span>|cod_no_newline|
|<span class="nerdfont big">&#xeb26;</span>|cod_note|
|<span class="nerdfont big">&#xebaf;</span>|cod_notebook|
|<span class="nerdfont big">&#xebbf;</span>|cod_notebook_template|
|<span class="nerdfont big">&#xeb27;</span>|cod_octoface|
|<span class="nerdfont big">&#xeb28;</span>|cod_open_preview|
|<span class="nerdfont big">&#xea7e;</span>|cod_organization|
|<span class="nerdfont big">&#xeb9d;</span>|cod_output|
|<span class="nerdfont big">&#xeb29;</span>|cod_package|
|<span class="nerdfont big">&#xeb2a;</span>|cod_paintcan|
|<span class="nerdfont big">&#xeba4;</span>|cod_pass|
|<span class="nerdfont big">&#xebb3;</span>|cod_pass_filled|
|<span class="nerdfont big">&#xea67;</span>|cod_person|
|<span class="nerdfont big">&#xebcd;</span>|cod_person_add|
|<span class="nerdfont big">&#xebe4;</span>|cod_pie_chart|
|<span class="nerdfont big">&#xeb2b;</span>|cod_pin|
|<span class="nerdfont big">&#xeba0;</span>|cod_pinned|
|<span class="nerdfont big">&#xebb2;</span>|cod_pinned_dirty|
|<span class="nerdfont big">&#xeb2c;</span>|cod_play|
|<span class="nerdfont big">&#xeba6;</span>|cod_play_circle|
|<span class="nerdfont big">&#xeb2d;</span>|cod_plug|
|<span class="nerdfont big">&#xeb2e;</span>|cod_preserve_case|
|<span class="nerdfont big">&#xeb2f;</span>|cod_preview|
|<span class="nerdfont big">&#xea72;</span>|cod_primitive_square|
|<span class="nerdfont big">&#xeb30;</span>|cod_project|
|<span class="nerdfont big">&#xeb31;</span>|cod_pulse|
|<span class="nerdfont big">&#xeb32;</span>|cod_question|
|<span class="nerdfont big">&#xeb33;</span>|cod_quote|
|<span class="nerdfont big">&#xeb34;</span>|cod_radio_tower|
|<span class="nerdfont big">&#xeb35;</span>|cod_reactions|
|<span class="nerdfont big">&#xeba7;</span>|cod_record|
|<span class="nerdfont big">&#xea65;</span>|cod_record_keys|
|<span class="nerdfont big">&#xebb0;</span>|cod_redo|
|<span class="nerdfont big">&#xeb36;</span>|cod_references|
|<span class="nerdfont big">&#xeb37;</span>|cod_refresh|
|<span class="nerdfont big">&#xeb38;</span>|cod_regex|
|<span class="nerdfont big">&#xeb3a;</span>|cod_remote|
|<span class="nerdfont big">&#xeb39;</span>|cod_remote_explorer|
|<span class="nerdfont big">&#xeb3b;</span>|cod_remove|
|<span class="nerdfont big">&#xeb3d;</span>|cod_replace|
|<span class="nerdfont big">&#xeb3c;</span>|cod_replace_all|
|<span class="nerdfont big">&#xea7d;</span>|cod_reply|
|<span class="nerdfont big">&#xea62;</span>|cod_repo|
|<span class="nerdfont big">&#xeb3e;</span>|cod_repo_clone|
|<span class="nerdfont big">&#xeb3f;</span>|cod_repo_force_push|
|<span class="nerdfont big">&#xea63;</span>|cod_repo_forked|
|<span class="nerdfont big">&#xeb40;</span>|cod_repo_pull|
|<span class="nerdfont big">&#xeb41;</span>|cod_repo_push|
|<span class="nerdfont big">&#xeb42;</span>|cod_report|
|<span class="nerdfont big">&#xeb43;</span>|cod_request_changes|
|<span class="nerdfont big">&#xeb44;</span>|cod_rocket|
|<span class="nerdfont big">&#xeb46;</span>|cod_root_folder|
|<span class="nerdfont big">&#xeb45;</span>|cod_root_folder_opened|
|<span class="nerdfont big">&#xeb47;</span>|cod_rss|
|<span class="nerdfont big">&#xeb48;</span>|cod_ruby|
|<span class="nerdfont big">&#xebbd;</span>|cod_run_above|
|<span class="nerdfont big">&#xeb9e;</span>|cod_run_all|
|<span class="nerdfont big">&#xebbe;</span>|cod_run_below|
|<span class="nerdfont big">&#xebde;</span>|cod_run_errors|
|<span class="nerdfont big">&#xeb4b;</span>|cod_save|
|<span class="nerdfont big">&#xeb49;</span>|cod_save_all|
|<span class="nerdfont big">&#xeb4a;</span>|cod_save_as|
|<span class="nerdfont big">&#xeb4c;</span>|cod_screen_full|
|<span class="nerdfont big">&#xeb4d;</span>|cod_screen_normal|
|<span class="nerdfont big">&#xea6d;</span>|cod_search|
|<span class="nerdfont big">&#xeb4e;</span>|cod_search_stop|
|<span class="nerdfont big">&#xeb50;</span>|cod_server|
|<span class="nerdfont big">&#xeba3;</span>|cod_server_environment|
|<span class="nerdfont big">&#xeba2;</span>|cod_server_process|
|<span class="nerdfont big">&#xeb52;</span>|cod_settings|
|<span class="nerdfont big">&#xeb51;</span>|cod_settings_gear|
|<span class="nerdfont big">&#xeb53;</span>|cod_shield|
|<span class="nerdfont big">&#xea6f;</span>|cod_sign_in|
|<span class="nerdfont big">&#xea6e;</span>|cod_sign_out|
|<span class="nerdfont big">&#xeb54;</span>|cod_smiley|
|<span class="nerdfont big">&#xeb55;</span>|cod_sort_precedence|
|<span class="nerdfont big">&#xea68;</span>|cod_source_control|
|<span class="nerdfont big">&#xeb56;</span>|cod_split_horizontal|
|<span class="nerdfont big">&#xeb57;</span>|cod_split_vertical|
|<span class="nerdfont big">&#xeb58;</span>|cod_squirrel|
|<span class="nerdfont big">&#xea6a;</span>|cod_star_empty|
|<span class="nerdfont big">&#xeb59;</span>|cod_star_full|
|<span class="nerdfont big">&#xeb5a;</span>|cod_star_half|
|<span class="nerdfont big">&#xeba5;</span>|cod_stop_circle|
|<span class="nerdfont big">&#xea8a;</span>|cod_symbol_array|
|<span class="nerdfont big">&#xea8f;</span>|cod_symbol_boolean|
|<span class="nerdfont big">&#xeb5b;</span>|cod_symbol_class|
|<span class="nerdfont big">&#xeb5c;</span>|cod_symbol_color|
|<span class="nerdfont big">&#xeb5d;</span>|cod_symbol_constant|
|<span class="nerdfont big">&#xea95;</span>|cod_symbol_enum|
|<span class="nerdfont big">&#xeb5e;</span>|cod_symbol_enum_member|
|<span class="nerdfont big">&#xea86;</span>|cod_symbol_event|
|<span class="nerdfont big">&#xeb5f;</span>|cod_symbol_field|
|<span class="nerdfont big">&#xeb60;</span>|cod_symbol_file|
|<span class="nerdfont big">&#xeb61;</span>|cod_symbol_interface|
|<span class="nerdfont big">&#xea93;</span>|cod_symbol_key|
|<span class="nerdfont big">&#xeb62;</span>|cod_symbol_keyword|
|<span class="nerdfont big">&#xea8c;</span>|cod_symbol_method|
|<span class="nerdfont big">&#xeb63;</span>|cod_symbol_misc|
|<span class="nerdfont big">&#xea8b;</span>|cod_symbol_namespace|
|<span class="nerdfont big">&#xea90;</span>|cod_symbol_numeric|
|<span class="nerdfont big">&#xeb64;</span>|cod_symbol_operator|
|<span class="nerdfont big">&#xea92;</span>|cod_symbol_parameter|
|<span class="nerdfont big">&#xeb65;</span>|cod_symbol_property|
|<span class="nerdfont big">&#xea96;</span>|cod_symbol_ruler|
|<span class="nerdfont big">&#xeb66;</span>|cod_symbol_snippet|
|<span class="nerdfont big">&#xeb8d;</span>|cod_symbol_string|
|<span class="nerdfont big">&#xea91;</span>|cod_symbol_structure|
|<span class="nerdfont big">&#xea88;</span>|cod_symbol_variable|
|<span class="nerdfont big">&#xea77;</span>|cod_sync|
|<span class="nerdfont big">&#xeb9f;</span>|cod_sync_ignored|
|<span class="nerdfont big">&#xebb7;</span>|cod_table|
|<span class="nerdfont big">&#xea66;</span>|cod_tag|
|<span class="nerdfont big">&#xeb67;</span>|cod_tasklist|
|<span class="nerdfont big">&#xeb68;</span>|cod_telescope|
|<span class="nerdfont big">&#xea85;</span>|cod_terminal|
|<span class="nerdfont big">&#xebca;</span>|cod_terminal_bash|
|<span class="nerdfont big">&#xebc4;</span>|cod_terminal_cmd|
|<span class="nerdfont big">&#xebc5;</span>|cod_terminal_debian|
|<span class="nerdfont big">&#xebc6;</span>|cod_terminal_linux|
|<span class="nerdfont big">&#xebc7;</span>|cod_terminal_powershell|
|<span class="nerdfont big">&#xebc8;</span>|cod_terminal_tmux|
|<span class="nerdfont big">&#xebc9;</span>|cod_terminal_ubuntu|
|<span class="nerdfont big">&#xeb69;</span>|cod_text_size|
|<span class="nerdfont big">&#xeb6a;</span>|cod_three_bars|
|<span class="nerdfont big">&#xeb6b;</span>|cod_thumbsdown|
|<span class="nerdfont big">&#xeb6c;</span>|cod_thumbsup|
|<span class="nerdfont big">&#xeb6d;</span>|cod_tools|
|<span class="nerdfont big">&#xea81;</span>|cod_trash|
|<span class="nerdfont big">&#xeb6e;</span>|cod_triangle_down|
|<span class="nerdfont big">&#xeb6f;</span>|cod_triangle_left|
|<span class="nerdfont big">&#xeb70;</span>|cod_triangle_right|
|<span class="nerdfont big">&#xeb71;</span>|cod_triangle_up|
|<span class="nerdfont big">&#xeb72;</span>|cod_twitter|
|<span class="nerdfont big">&#xebb9;</span>|cod_type_hierarchy|
|<span class="nerdfont big">&#xebba;</span>|cod_type_hierarchy_sub|
|<span class="nerdfont big">&#xebbb;</span>|cod_type_hierarchy_super|
|<span class="nerdfont big">&#xeb73;</span>|cod_unfold|
|<span class="nerdfont big">&#xeb98;</span>|cod_ungroup_by_ref_type|
|<span class="nerdfont big">&#xeb74;</span>|cod_unlock|
|<span class="nerdfont big">&#xeb75;</span>|cod_unmute|
|<span class="nerdfont big">&#xeb76;</span>|cod_unverified|
|<span class="nerdfont big">&#xebb8;</span>|cod_variable_group|
|<span class="nerdfont big">&#xeb77;</span>|cod_verified|
|<span class="nerdfont big">&#xebe9;</span>|cod_verified_filled|
|<span class="nerdfont big">&#xeb78;</span>|cod_versions|
|<span class="nerdfont big">&#xea7a;</span>|cod_vm|
|<span class="nerdfont big">&#xeb79;</span>|cod_vm_active|
|<span class="nerdfont big">&#xeba9;</span>|cod_vm_connect|
|<span class="nerdfont big">&#xeb7a;</span>|cod_vm_outline|
|<span class="nerdfont big">&#xeb7b;</span>|cod_vm_running|
|<span class="nerdfont big">&#xebcf;</span>|cod_wand|
|<span class="nerdfont big">&#xea6c;</span>|cod_warning|
|<span class="nerdfont big">&#xeb7c;</span>|cod_watch|
|<span class="nerdfont big">&#xeb7d;</span>|cod_whitespace|
|<span class="nerdfont big">&#xeb7e;</span>|cod_whole_word|
|<span class="nerdfont big">&#xeb7f;</span>|cod_window|
|<span class="nerdfont big">&#xeb80;</span>|cod_word_wrap|
|<span class="nerdfont big">&#xebc1;</span>|cod_workspace_trusted|
|<span class="nerdfont big">&#xebc3;</span>|cod_workspace_unknown|
|<span class="nerdfont big">&#xebc2;</span>|cod_workspace_untrusted|
|<span class="nerdfont big">&#xeb81;</span>|cod_zoom_in|
|<span class="nerdfont big">&#xeb82;</span>|cod_zoom_out|
|<span class="nerdfont big">&#xe6ab;</span>|custom_asm|
|<span class="nerdfont big">&#xe61e;</span>|custom_c|
|<span class="nerdfont big">&#xe61d;</span>|custom_cpp|
|<span class="nerdfont big">&#xe62f;</span>|custom_crystal|
|<span class="nerdfont big">&#xe612;</span>|custom_default|
|<span class="nerdfont big">&#xe62e;</span>|custom_electron|
|<span class="nerdfont big">&#xe62d;</span>|custom_elixir|
|<span class="nerdfont big">&#xe62c;</span>|custom_elm|
|<span class="nerdfont big">&#xe632;</span>|custom_emacs|
|<span class="nerdfont big">&#xe5ff;</span>|custom_folder|
|<span class="nerdfont big">&#xe5fc;</span>|custom_folder_config|
|<span class="nerdfont big">&#xe5fb;</span>|custom_folder_git|
|<span class="nerdfont big">&#xe5fd;</span>|custom_folder_github|
|<span class="nerdfont big">&#xe5fa;</span>|custom_folder_npm|
|<span class="nerdfont big">&#xe5fe;</span>|custom_folder_open|
|<span class="nerdfont big">&#xe626;</span>|custom_go|
|<span class="nerdfont big">&#xe617;</span>|custom_home|
|<span class="nerdfont big">&#xe634;</span>|custom_kotlin|
|<span class="nerdfont big">&#xe629;</span>|custom_msdos|
|<span class="nerdfont big">&#xe633;</span>|custom_orgmode|
|<span class="nerdfont big">&#xe602;</span>|custom_play_arrow|
|<span class="nerdfont big">&#xe630;</span>|custom_purescript|
|<span class="nerdfont big">&#xe6ac;</span>|custom_v_lang|
|<span class="nerdfont big">&#xe62b;</span>|custom_vim|
|<span class="nerdfont big">&#xe62a;</span>|custom_windows|
|<span class="nerdfont big">&#xe70e;</span>|dev_android|
|<span class="nerdfont big">&#xe753;</span>|dev_angular|
|<span class="nerdfont big">&#xe7ab;</span>|dev_appcelerator|
|<span class="nerdfont big">&#xe711;</span>|dev_apple|
|<span class="nerdfont big">&#xe713;</span>|dev_appstore|
|<span class="nerdfont big">&#xe799;</span>|dev_aptana|
|<span class="nerdfont big">&#xe7ac;</span>|dev_asterisk|
|<span class="nerdfont big">&#xe75b;</span>|dev_atlassian|
|<span class="nerdfont big">&#xe764;</span>|dev_atom|
|<span class="nerdfont big">&#xe7ad;</span>|dev_aws|
|<span class="nerdfont big">&#xe752;</span>|dev_backbone|
|<span class="nerdfont big">&#xe700;</span>|dev_bing_small|
|<span class="nerdfont big">&#xe794;</span>|dev_bintray|
|<span class="nerdfont big">&#xe703;</span>|dev_bitbucket|
|<span class="nerdfont big">&#xe723;</span>|dev_blackberry|
|<span class="nerdfont big">&#xe747;</span>|dev_bootstrap|
|<span class="nerdfont big">&#xe74d;</span>|dev_bower|
|<span class="nerdfont big">&#xe79d;</span>|dev_brackets|
|<span class="nerdfont big">&#xe78d;</span>|dev_bugsense|
|<span class="nerdfont big">&#xe76b;</span>|dev_celluloid|
|<span class="nerdfont big">&#xe760;</span>|dev_chart|
|<span class="nerdfont big">&#xe743;</span>|dev_chrome|
|<span class="nerdfont big">&#xe765;</span>|dev_cisco|
|<span class="nerdfont big">&#xe768;</span>|dev_clojure|
|<span class="nerdfont big">&#xe76a;</span>|dev_clojure_alt|
|<span class="nerdfont big">&#xe79f;</span>|dev_cloud9|
|<span class="nerdfont big">&#xe793;</span>|dev_coda|
|<span class="nerdfont big">&#xe796;</span>|dev_code|
|<span class="nerdfont big">&#xe7a3;</span>|dev_code_badge|
|<span class="nerdfont big">&#xe780;</span>|dev_codeigniter|
|<span class="nerdfont big">&#xe716;</span>|dev_codepen|
|<span class="nerdfont big">&#xe72f;</span>|dev_codrops|
|<span class="nerdfont big">&#xe751;</span>|dev_coffeescript|
|<span class="nerdfont big">&#xe761;</span>|dev_compass|
|<span class="nerdfont big">&#xe783;</span>|dev_composer|
|<span class="nerdfont big">&#xe789;</span>|dev_creativecommons|
|<span class="nerdfont big">&#xe78a;</span>|dev_creativecommons_badge|
|<span class="nerdfont big">&#xe749;</span>|dev_css3|
|<span class="nerdfont big">&#xe74a;</span>|dev_css3_full|
|<span class="nerdfont big">&#xe701;</span>|dev_css_tricks|
|<span class="nerdfont big">&#xe72a;</span>|dev_cssdeck|
|<span class="nerdfont big">&#xe798;</span>|dev_dart|
|<span class="nerdfont big">&#xe706;</span>|dev_database|
|<span class="nerdfont big">&#xe77d;</span>|dev_debian|
|<span class="nerdfont big">&#xe7ae;</span>|dev_digital_ocean|
|<span class="nerdfont big">&#xe71d;</span>|dev_django|
|<span class="nerdfont big">&#xe7af;</span>|dev_dlang|
|<span class="nerdfont big">&#xe7b0;</span>|dev_docker|
|<span class="nerdfont big">&#xe774;</span>|dev_doctrine|
|<span class="nerdfont big">&#xe71c;</span>|dev_dojo|
|<span class="nerdfont big">&#xe77f;</span>|dev_dotnet|
|<span class="nerdfont big">&#xe79c;</span>|dev_dreamweaver|
|<span class="nerdfont big">&#xe707;</span>|dev_dropbox|
|<span class="nerdfont big">&#xe742;</span>|dev_drupal|
|<span class="nerdfont big">&#xe79e;</span>|dev_eclipse|
|<span class="nerdfont big">&#xe71b;</span>|dev_ember|
|<span class="nerdfont big">&#xe75d;</span>|dev_envato|
|<span class="nerdfont big">&#xe7b1;</span>|dev_erlang|
|<span class="nerdfont big">&#xe78e;</span>|dev_extjs|
|<span class="nerdfont big">&#xe787;</span>|dev_firebase|
|<span class="nerdfont big">&#xe745;</span>|dev_firefox|
|<span class="nerdfont big">&#xe7a7;</span>|dev_fsharp|
|<span class="nerdfont big">&#xe71f;</span>|dev_ghost|
|<span class="nerdfont big">&#xe714;</span>|dev_ghost_small|
|<span class="nerdfont big">&#xe702;</span>|dev_git|
|<span class="nerdfont big">&#xe725;</span>|dev_git_branch|
|<span class="nerdfont big">&#xe729;</span>|dev_git_commit|
|<span class="nerdfont big">&#xe728;</span>|dev_git_compare|
|<span class="nerdfont big">&#xe727;</span>|dev_git_merge|
|<span class="nerdfont big">&#xe726;</span>|dev_git_pull_request|
|<span class="nerdfont big">&#xe70a;</span>|dev_github|
|<span class="nerdfont big">&#xe708;</span>|dev_github_alt|
|<span class="nerdfont big">&#xe709;</span>|dev_github_badge|
|<span class="nerdfont big">&#xe717;</span>|dev_github_full|
|<span class="nerdfont big">&#xe779;</span>|dev_gnu|
|<span class="nerdfont big">&#xe724;</span>|dev_go|
|<span class="nerdfont big">&#xe7b2;</span>|dev_google_cloud_platform|
|<span class="nerdfont big">&#xe731;</span>|dev_google_drive|
|<span class="nerdfont big">&#xe7b3;</span>|dev_grails|
|<span class="nerdfont big">&#xe775;</span>|dev_groovy|
|<span class="nerdfont big">&#xe74c;</span>|dev_grunt|
|<span class="nerdfont big">&#xe763;</span>|dev_gulp|
|<span class="nerdfont big">&#xe71a;</span>|dev_hackernews|
|<span class="nerdfont big">&#xe777;</span>|dev_haskell|
|<span class="nerdfont big">&#xe77b;</span>|dev_heroku|
|<span class="nerdfont big">&#xe736;</span>|dev_html5|
|<span class="nerdfont big">&#xe735;</span>|dev_html5_3d_effects|
|<span class="nerdfont big">&#xe734;</span>|dev_html5_connectivity|
|<span class="nerdfont big">&#xe733;</span>|dev_html5_device_access|
|<span class="nerdfont big">&#xe732;</span>|dev_html5_multimedia|
|<span class="nerdfont big">&#xe744;</span>|dev_ie|
|<span class="nerdfont big">&#xe7b4;</span>|dev_illustrator|
|<span class="nerdfont big">&#xe7b5;</span>|dev_intellij|
|<span class="nerdfont big">&#xe7a9;</span>|dev_ionic|
|<span class="nerdfont big">&#xe738;</span>|dev_java|
|<span class="nerdfont big">&#xe74e;</span>|dev_javascript|
|<span class="nerdfont big">&#xe781;</span>|dev_javascript_badge|
|<span class="nerdfont big">&#xe74f;</span>|dev_javascript_shield|
|<span class="nerdfont big">&#xe70d;</span>|dev_jekyll_small|
|<span class="nerdfont big">&#xe767;</span>|dev_jenkins|
|<span class="nerdfont big">&#xe75c;</span>|dev_jira|
|<span class="nerdfont big">&#xe741;</span>|dev_joomla|
|<span class="nerdfont big">&#xe750;</span>|dev_jquery|
|<span class="nerdfont big">&#xe754;</span>|dev_jquery_ui|
|<span class="nerdfont big">&#xe792;</span>|dev_komodo|
|<span class="nerdfont big">&#xe785;</span>|dev_krakenjs|
|<span class="nerdfont big">&#xe784;</span>|dev_krakenjs_badge|
|<span class="nerdfont big">&#xe73f;</span>|dev_laravel|
|<span class="nerdfont big">&#xe758;</span>|dev_less|
|<span class="nerdfont big">&#xe712;</span>|dev_linux|
|<span class="nerdfont big">&#xe740;</span>|dev_magento|
|<span class="nerdfont big">&#xe79a;</span>|dev_mailchimp|
|<span class="nerdfont big">&#xe73e;</span>|dev_markdown|
|<span class="nerdfont big">&#xe7b6;</span>|dev_materializecss|
|<span class="nerdfont big">&#xe7a5;</span>|dev_meteor|
|<span class="nerdfont big">&#xe7a6;</span>|dev_meteorfull|
|<span class="nerdfont big">&#xe78b;</span>|dev_mitlicence|
|<span class="nerdfont big">&#xe720;</span>|dev_modernizr|
|<span class="nerdfont big">&#xe7a4;</span>|dev_mongodb|
|<span class="nerdfont big">&#xe790;</span>|dev_mootools|
|<span class="nerdfont big">&#xe78f;</span>|dev_mootools_badge|
|<span class="nerdfont big">&#xe786;</span>|dev_mozilla|
|<span class="nerdfont big">&#xe77c;</span>|dev_msql_server|
|<span class="nerdfont big">&#xe704;</span>|dev_mysql|
|<span class="nerdfont big">&#xe766;</span>|dev_nancy|
|<span class="nerdfont big">&#xe79b;</span>|dev_netbeans|
|<span class="nerdfont big">&#xe72e;</span>|dev_netmagazine|
|<span class="nerdfont big">&#xe776;</span>|dev_nginx|
|<span class="nerdfont big">&#xe719;</span>|dev_nodejs|
|<span class="nerdfont big">&#xe718;</span>|dev_nodejs_small|
|<span class="nerdfont big">&#xe71e;</span>|dev_npm|
|<span class="nerdfont big">&#xe762;</span>|dev_onedrive|
|<span class="nerdfont big">&#xe7b7;</span>|dev_openshift|
|<span class="nerdfont big">&#xe771;</span>|dev_opensource|
|<span class="nerdfont big">&#xe746;</span>|dev_opera|
|<span class="nerdfont big">&#xe769;</span>|dev_perl|
|<span class="nerdfont big">&#xe730;</span>|dev_phonegap|
|<span class="nerdfont big">&#xe7b8;</span>|dev_photoshop|
|<span class="nerdfont big">&#xe73d;</span>|dev_php|
|<span class="nerdfont big">&#xe76e;</span>|dev_postgresql|
|<span class="nerdfont big">&#xe7a1;</span>|dev_prolog|
|<span class="nerdfont big">&#xe73c;</span>|dev_python|
|<span class="nerdfont big">&#xe7b9;</span>|dev_rackspace|
|<span class="nerdfont big">&#xe75f;</span>|dev_raphael|
|<span class="nerdfont big">&#xe722;</span>|dev_rasberry_pi|
|<span class="nerdfont big">&#xe7ba;</span>|dev_react|
|<span class="nerdfont big">&#xe7bb;</span>|dev_redhat|
|<span class="nerdfont big">&#xe76d;</span>|dev_redis|
|<span class="nerdfont big">&#xe770;</span>|dev_requirejs|
|<span class="nerdfont big">&#xe797;</span>|dev_responsive|
|<span class="nerdfont big">&#xe739;</span>|dev_ruby|
|<span class="nerdfont big">&#xe73b;</span>|dev_ruby_on_rails|
|<span class="nerdfont big">&#xe791;</span>|dev_ruby_rough|
|<span class="nerdfont big">&#xe7a8;</span>|dev_rust|
|<span class="nerdfont big">&#xe748;</span>|dev_safari|
|<span class="nerdfont big">&#xe74b;</span>|dev_sass|
|<span class="nerdfont big">&#xe737;</span>|dev_scala|
|<span class="nerdfont big">&#xe7bc;</span>|dev_scriptcs|
|<span class="nerdfont big">&#xe7a0;</span>|dev_scrum|
|<span class="nerdfont big">&#xe78c;</span>|dev_senchatouch|
|<span class="nerdfont big">&#xe788;</span>|dev_sizzlejs|
|<span class="nerdfont big">&#xe72d;</span>|dev_smashing_magazine|
|<span class="nerdfont big">&#xe75e;</span>|dev_snap_svg|
|<span class="nerdfont big">&#xe7c4;</span>|dev_sqllite|
|<span class="nerdfont big">&#xe710;</span>|dev_stackoverflow|
|<span class="nerdfont big">&#xe705;</span>|dev_streamline|
|<span class="nerdfont big">&#xe759;</span>|dev_stylus|
|<span class="nerdfont big">&#xe7aa;</span>|dev_sublime|
|<span class="nerdfont big">&#xe755;</span>|dev_swift|
|<span class="nerdfont big">&#xe756;</span>|dev_symfony|
|<span class="nerdfont big">&#xe757;</span>|dev_symfony_badge|
|<span class="nerdfont big">&#xe72c;</span>|dev_techcrunch|
|<span class="nerdfont big">&#xe795;</span>|dev_terminal|
|<span class="nerdfont big">&#xe7a2;</span>|dev_terminal_badge|
|<span class="nerdfont big">&#xe77e;</span>|dev_travis|
|<span class="nerdfont big">&#xe75a;</span>|dev_trello|
|<span class="nerdfont big">&#xe772;</span>|dev_typo3|
|<span class="nerdfont big">&#xe73a;</span>|dev_ubuntu|
|<span class="nerdfont big">&#xe773;</span>|dev_uikit|
|<span class="nerdfont big">&#xe721;</span>|dev_unity_small|
|<span class="nerdfont big">&#xe7c5;</span>|dev_vim|
|<span class="nerdfont big">&#xe70c;</span>|dev_visualstudio|
|<span class="nerdfont big">&#xe76c;</span>|dev_w3c|
|<span class="nerdfont big">&#xe76f;</span>|dev_webplatform|
|<span class="nerdfont big">&#xe70f;</span>|dev_windows|
|<span class="nerdfont big">&#xe70b;</span>|dev_wordpress|
|<span class="nerdfont big">&#xe715;</span>|dev_yahoo|
|<span class="nerdfont big">&#xe72b;</span>|dev_yahoo_small|
|<span class="nerdfont big">&#xe77a;</span>|dev_yeoman|
|<span class="nerdfont big">&#xe782;</span>|dev_yii|
|<span class="nerdfont big">&#xe778;</span>|dev_zend|
|<span class="nerdfont big">&#xf26e;</span>|fa_500px|
|<span class="nerdfont big">&#xf2b9;</span>|fa_address_book|
|<span class="nerdfont big">&#xf2ba;</span>|fa_address_book_o|
|<span class="nerdfont big">&#xf2bb;</span>|fa_address_card|
|<span class="nerdfont big">&#xf2bc;</span>|fa_address_card_o|
|<span class="nerdfont big">&#xf042;</span>|fa_adjust|
|<span class="nerdfont big">&#xf170;</span>|fa_adn|
|<span class="nerdfont big">&#xf037;</span>|fa_align_center|
|<span class="nerdfont big">&#xf039;</span>|fa_align_justify|
|<span class="nerdfont big">&#xf036;</span>|fa_align_left|
|<span class="nerdfont big">&#xf038;</span>|fa_align_right|
|<span class="nerdfont big">&#xf270;</span>|fa_amazon|
|<span class="nerdfont big">&#xf0f9;</span>|fa_ambulance|
|<span class="nerdfont big">&#xf2a3;</span>|fa_american_sign_language_interpreting|
|<span class="nerdfont big">&#xf13d;</span>|fa_anchor|
|<span class="nerdfont big">&#xf17b;</span>|fa_android|
|<span class="nerdfont big">&#xf209;</span>|fa_angellist|
|<span class="nerdfont big">&#xf103;</span>|fa_angle_double_down|
|<span class="nerdfont big">&#xf100;</span>|fa_angle_double_left|
|<span class="nerdfont big">&#xf101;</span>|fa_angle_double_right|
|<span class="nerdfont big">&#xf102;</span>|fa_angle_double_up|
|<span class="nerdfont big">&#xf107;</span>|fa_angle_down|
|<span class="nerdfont big">&#xf104;</span>|fa_angle_left|
|<span class="nerdfont big">&#xf105;</span>|fa_angle_right|
|<span class="nerdfont big">&#xf106;</span>|fa_angle_up|
|<span class="nerdfont big">&#xf179;</span>|fa_apple|
|<span class="nerdfont big">&#xf187;</span>|fa_archive|
|<span class="nerdfont big">&#xf1fe;</span>|fa_area_chart|
|<span class="nerdfont big">&#xf0ab;</span>|fa_arrow_circle_down|
|<span class="nerdfont big">&#xf0a8;</span>|fa_arrow_circle_left|
|<span class="nerdfont big">&#xf01a;</span>|fa_arrow_circle_o_down|
|<span class="nerdfont big">&#xf190;</span>|fa_arrow_circle_o_left|
|<span class="nerdfont big">&#xf18e;</span>|fa_arrow_circle_o_right|
|<span class="nerdfont big">&#xf01b;</span>|fa_arrow_circle_o_up|
|<span class="nerdfont big">&#xf0a9;</span>|fa_arrow_circle_right|
|<span class="nerdfont big">&#xf0aa;</span>|fa_arrow_circle_up|
|<span class="nerdfont big">&#xf063;</span>|fa_arrow_down|
|<span class="nerdfont big">&#xf060;</span>|fa_arrow_left|
|<span class="nerdfont big">&#xf061;</span>|fa_arrow_right|
|<span class="nerdfont big">&#xf062;</span>|fa_arrow_up|
|<span class="nerdfont big">&#xf047;</span>|fa_arrows|
|<span class="nerdfont big">&#xf0b2;</span>|fa_arrows_alt|
|<span class="nerdfont big">&#xf07e;</span>|fa_arrows_h|
|<span class="nerdfont big">&#xf07d;</span>|fa_arrows_v|
|<span class="nerdfont big">&#xf2a2;</span>|fa_assistive_listening_systems|
|<span class="nerdfont big">&#xf069;</span>|fa_asterisk|
|<span class="nerdfont big">&#xf1fa;</span>|fa_at|
|<span class="nerdfont big">&#xf29e;</span>|fa_audio_description|
|<span class="nerdfont big">&#xf04a;</span>|fa_backward|
|<span class="nerdfont big">&#xf24e;</span>|fa_balance_scale|
|<span class="nerdfont big">&#xf05e;</span>|fa_ban|
|<span class="nerdfont big">&#xf2d5;</span>|fa_bandcamp|
|<span class="nerdfont big">&#xf080;</span>|fa_bar_chart|
|<span class="nerdfont big">&#xf02a;</span>|fa_barcode|
|<span class="nerdfont big">&#xf0c9;</span>|fa_bars|
|<span class="nerdfont big">&#xf2cd;</span>|fa_bath|
|<span class="nerdfont big">&#xf244;</span>|fa_battery_empty|
|<span class="nerdfont big">&#xf240;</span>|fa_battery_full|
|<span class="nerdfont big">&#xf242;</span>|fa_battery_half|
|<span class="nerdfont big">&#xf243;</span>|fa_battery_quarter|
|<span class="nerdfont big">&#xf241;</span>|fa_battery_three_quarters|
|<span class="nerdfont big">&#xf236;</span>|fa_bed|
|<span class="nerdfont big">&#xf0fc;</span>|fa_beer|
|<span class="nerdfont big">&#xf1b4;</span>|fa_behance|
|<span class="nerdfont big">&#xf1b5;</span>|fa_behance_square|
|<span class="nerdfont big">&#xf0f3;</span>|fa_bell|
|<span class="nerdfont big">&#xf0a2;</span>|fa_bell_o|
|<span class="nerdfont big">&#xf1f6;</span>|fa_bell_slash|
|<span class="nerdfont big">&#xf1f7;</span>|fa_bell_slash_o|
|<span class="nerdfont big">&#xf206;</span>|fa_bicycle|
|<span class="nerdfont big">&#xf1e5;</span>|fa_binoculars|
|<span class="nerdfont big">&#xf1fd;</span>|fa_birthday_cake|
|<span class="nerdfont big">&#xf171;</span>|fa_bitbucket|
|<span class="nerdfont big">&#xf172;</span>|fa_bitbucket_square|
|<span class="nerdfont big">&#xf27e;</span>|fa_black_tie|
|<span class="nerdfont big">&#xf29d;</span>|fa_blind|
|<span class="nerdfont big">&#xf293;</span>|fa_bluetooth|
|<span class="nerdfont big">&#xf294;</span>|fa_bluetooth_b|
|<span class="nerdfont big">&#xf032;</span>|fa_bold|
|<span class="nerdfont big">&#xf0e7;</span>|fa_bolt|
|<span class="nerdfont big">&#xf1e2;</span>|fa_bomb|
|<span class="nerdfont big">&#xf02d;</span>|fa_book|
|<span class="nerdfont big">&#xf02e;</span>|fa_bookmark|
|<span class="nerdfont big">&#xf097;</span>|fa_bookmark_o|
|<span class="nerdfont big">&#xf2a1;</span>|fa_braille|
|<span class="nerdfont big">&#xf0b1;</span>|fa_briefcase|
|<span class="nerdfont big">&#xf15a;</span>|fa_btc|
|<span class="nerdfont big">&#xf188;</span>|fa_bug|
|<span class="nerdfont big">&#xf1ad;</span>|fa_building|
|<span class="nerdfont big">&#xf0f7;</span>|fa_building_o|
|<span class="nerdfont big">&#xf0a1;</span>|fa_bullhorn|
|<span class="nerdfont big">&#xf140;</span>|fa_bullseye|
|<span class="nerdfont big">&#xf207;</span>|fa_bus|
|<span class="nerdfont big">&#xf20d;</span>|fa_buysellads|
|<span class="nerdfont big">&#xf1ec;</span>|fa_calculator|
|<span class="nerdfont big">&#xf073;</span>|fa_calendar|
|<span class="nerdfont big">&#xf274;</span>|fa_calendar_check_o|
|<span class="nerdfont big">&#xf272;</span>|fa_calendar_minus_o|
|<span class="nerdfont big">&#xf133;</span>|fa_calendar_o|
|<span class="nerdfont big">&#xf271;</span>|fa_calendar_plus_o|
|<span class="nerdfont big">&#xf273;</span>|fa_calendar_times_o|
|<span class="nerdfont big">&#xf030;</span>|fa_camera|
|<span class="nerdfont big">&#xf083;</span>|fa_camera_retro|
|<span class="nerdfont big">&#xf1b9;</span>|fa_car|
|<span class="nerdfont big">&#xf0d7;</span>|fa_caret_down|
|<span class="nerdfont big">&#xf0d9;</span>|fa_caret_left|
|<span class="nerdfont big">&#xf0da;</span>|fa_caret_right|
|<span class="nerdfont big">&#xf150;</span>|fa_caret_square_o_down|
|<span class="nerdfont big">&#xf191;</span>|fa_caret_square_o_left|
|<span class="nerdfont big">&#xf152;</span>|fa_caret_square_o_right|
|<span class="nerdfont big">&#xf151;</span>|fa_caret_square_o_up|
|<span class="nerdfont big">&#xf0d8;</span>|fa_caret_up|
|<span class="nerdfont big">&#xf218;</span>|fa_cart_arrow_down|
|<span class="nerdfont big">&#xf217;</span>|fa_cart_plus|
|<span class="nerdfont big">&#xf20a;</span>|fa_cc|
|<span class="nerdfont big">&#xf1f3;</span>|fa_cc_amex|
|<span class="nerdfont big">&#xf24c;</span>|fa_cc_diners_club|
|<span class="nerdfont big">&#xf1f2;</span>|fa_cc_discover|
|<span class="nerdfont big">&#xf24b;</span>|fa_cc_jcb|
|<span class="nerdfont big">&#xf1f1;</span>|fa_cc_mastercard|
|<span class="nerdfont big">&#xf1f4;</span>|fa_cc_paypal|
|<span class="nerdfont big">&#xf1f5;</span>|fa_cc_stripe|
|<span class="nerdfont big">&#xf1f0;</span>|fa_cc_visa|
|<span class="nerdfont big">&#xf0a3;</span>|fa_certificate|
|<span class="nerdfont big">&#xf127;</span>|fa_chain_broken|
|<span class="nerdfont big">&#xf00c;</span>|fa_check|
|<span class="nerdfont big">&#xf058;</span>|fa_check_circle|
|<span class="nerdfont big">&#xf05d;</span>|fa_check_circle_o|
|<span class="nerdfont big">&#xf14a;</span>|fa_check_square|
|<span class="nerdfont big">&#xf046;</span>|fa_check_square_o|
|<span class="nerdfont big">&#xf13a;</span>|fa_chevron_circle_down|
|<span class="nerdfont big">&#xf137;</span>|fa_chevron_circle_left|
|<span class="nerdfont big">&#xf138;</span>|fa_chevron_circle_right|
|<span class="nerdfont big">&#xf139;</span>|fa_chevron_circle_up|
|<span class="nerdfont big">&#xf078;</span>|fa_chevron_down|
|<span class="nerdfont big">&#xf053;</span>|fa_chevron_left|
|<span class="nerdfont big">&#xf054;</span>|fa_chevron_right|
|<span class="nerdfont big">&#xf077;</span>|fa_chevron_up|
|<span class="nerdfont big">&#xf1ae;</span>|fa_child|
|<span class="nerdfont big">&#xf268;</span>|fa_chrome|
|<span class="nerdfont big">&#xf111;</span>|fa_circle|
|<span class="nerdfont big">&#xf10c;</span>|fa_circle_o|
|<span class="nerdfont big">&#xf1ce;</span>|fa_circle_o_notch|
|<span class="nerdfont big">&#xf1db;</span>|fa_circle_thin|
|<span class="nerdfont big">&#xf0ea;</span>|fa_clipboard|
|<span class="nerdfont big">&#xf017;</span>|fa_clock_o|
|<span class="nerdfont big">&#xf24d;</span>|fa_clone|
|<span class="nerdfont big">&#xf0c2;</span>|fa_cloud|
|<span class="nerdfont big">&#xf0ed;</span>|fa_cloud_download|
|<span class="nerdfont big">&#xf0ee;</span>|fa_cloud_upload|
|<span class="nerdfont big">&#xf121;</span>|fa_code|
|<span class="nerdfont big">&#xf126;</span>|fa_code_fork|
|<span class="nerdfont big">&#xf1cb;</span>|fa_codepen|
|<span class="nerdfont big">&#xf284;</span>|fa_codiepie|
|<span class="nerdfont big">&#xf0f4;</span>|fa_coffee|
|<span class="nerdfont big">&#xf013;</span>|fa_cog|
|<span class="nerdfont big">&#xf085;</span>|fa_cogs|
|<span class="nerdfont big">&#xf0db;</span>|fa_columns|
|<span class="nerdfont big">&#xf075;</span>|fa_comment|
|<span class="nerdfont big">&#xf0e5;</span>|fa_comment_o|
|<span class="nerdfont big">&#xf27a;</span>|fa_commenting|
|<span class="nerdfont big">&#xf27b;</span>|fa_commenting_o|
|<span class="nerdfont big">&#xf086;</span>|fa_comments|
|<span class="nerdfont big">&#xf0e6;</span>|fa_comments_o|
|<span class="nerdfont big">&#xf14e;</span>|fa_compass|
|<span class="nerdfont big">&#xf066;</span>|fa_compress|
|<span class="nerdfont big">&#xf20e;</span>|fa_connectdevelop|
|<span class="nerdfont big">&#xf26d;</span>|fa_contao|
|<span class="nerdfont big">&#xf1f9;</span>|fa_copyright|
|<span class="nerdfont big">&#xf25e;</span>|fa_creative_commons|
|<span class="nerdfont big">&#xf09d;</span>|fa_credit_card|
|<span class="nerdfont big">&#xf283;</span>|fa_credit_card_alt|
|<span class="nerdfont big">&#xf125;</span>|fa_crop|
|<span class="nerdfont big">&#xf05b;</span>|fa_crosshairs|
|<span class="nerdfont big">&#xf13c;</span>|fa_css3|
|<span class="nerdfont big">&#xf1b2;</span>|fa_cube|
|<span class="nerdfont big">&#xf1b3;</span>|fa_cubes|
|<span class="nerdfont big">&#xf0f5;</span>|fa_cutlery|
|<span class="nerdfont big">&#xf210;</span>|fa_dashcube|
|<span class="nerdfont big">&#xf1c0;</span>|fa_database|
|<span class="nerdfont big">&#xf2a4;</span>|fa_deaf|
|<span class="nerdfont big">&#xf1a5;</span>|fa_delicious|
|<span class="nerdfont big">&#xf108;</span>|fa_desktop|
|<span class="nerdfont big">&#xf1bd;</span>|fa_deviantart|
|<span class="nerdfont big">&#xf219;</span>|fa_diamond|
|<span class="nerdfont big">&#xf1a6;</span>|fa_digg|
|<span class="nerdfont big">&#xf192;</span>|fa_dot_circle_o|
|<span class="nerdfont big">&#xf019;</span>|fa_download|
|<span class="nerdfont big">&#xf17d;</span>|fa_dribbble|
|<span class="nerdfont big">&#xf16b;</span>|fa_dropbox|
|<span class="nerdfont big">&#xf1a9;</span>|fa_drupal|
|<span class="nerdfont big">&#xf282;</span>|fa_edge|
|<span class="nerdfont big">&#xf2da;</span>|fa_eercast|
|<span class="nerdfont big">&#xf052;</span>|fa_eject|
|<span class="nerdfont big">&#xf141;</span>|fa_ellipsis_h|
|<span class="nerdfont big">&#xf142;</span>|fa_ellipsis_v|
|<span class="nerdfont big">&#xf1d1;</span>|fa_empire|
|<span class="nerdfont big">&#xf0e0;</span>|fa_envelope|
|<span class="nerdfont big">&#xf003;</span>|fa_envelope_o|
|<span class="nerdfont big">&#xf2b6;</span>|fa_envelope_open|
|<span class="nerdfont big">&#xf2b7;</span>|fa_envelope_open_o|
|<span class="nerdfont big">&#xf199;</span>|fa_envelope_square|
|<span class="nerdfont big">&#xf299;</span>|fa_envira|
|<span class="nerdfont big">&#xf12d;</span>|fa_eraser|
|<span class="nerdfont big">&#xf2d7;</span>|fa_etsy|
|<span class="nerdfont big">&#xf153;</span>|fa_eur|
|<span class="nerdfont big">&#xf0ec;</span>|fa_exchange|
|<span class="nerdfont big">&#xf12a;</span>|fa_exclamation|
|<span class="nerdfont big">&#xf06a;</span>|fa_exclamation_circle|
|<span class="nerdfont big">&#xf071;</span>|fa_exclamation_triangle|
|<span class="nerdfont big">&#xf065;</span>|fa_expand|
|<span class="nerdfont big">&#xf23e;</span>|fa_expeditedssl|
|<span class="nerdfont big">&#xf08e;</span>|fa_external_link|
|<span class="nerdfont big">&#xf14c;</span>|fa_external_link_square|
|<span class="nerdfont big">&#xf06e;</span>|fa_eye|
|<span class="nerdfont big">&#xf070;</span>|fa_eye_slash|
|<span class="nerdfont big">&#xf1fb;</span>|fa_eyedropper|
|<span class="nerdfont big">&#xf09a;</span>|fa_facebook|
|<span class="nerdfont big">&#xf230;</span>|fa_facebook_official|
|<span class="nerdfont big">&#xf082;</span>|fa_facebook_square|
|<span class="nerdfont big">&#xf049;</span>|fa_fast_backward|
|<span class="nerdfont big">&#xf050;</span>|fa_fast_forward|
|<span class="nerdfont big">&#xf1ac;</span>|fa_fax|
|<span class="nerdfont big">&#xf182;</span>|fa_female|
|<span class="nerdfont big">&#xf0fb;</span>|fa_fighter_jet|
|<span class="nerdfont big">&#xf15b;</span>|fa_file|
|<span class="nerdfont big">&#xf1c6;</span>|fa_file_archive_o|
|<span class="nerdfont big">&#xf1c7;</span>|fa_file_audio_o|
|<span class="nerdfont big">&#xf1c9;</span>|fa_file_code_o|
|<span class="nerdfont big">&#xf1c3;</span>|fa_file_excel_o|
|<span class="nerdfont big">&#xf1c5;</span>|fa_file_image_o|
|<span class="nerdfont big">&#xf016;</span>|fa_file_o|
|<span class="nerdfont big">&#xf1c1;</span>|fa_file_pdf_o|
|<span class="nerdfont big">&#xf1c4;</span>|fa_file_powerpoint_o|
|<span class="nerdfont big">&#xf15c;</span>|fa_file_text|
|<span class="nerdfont big">&#xf0f6;</span>|fa_file_text_o|
|<span class="nerdfont big">&#xf1c8;</span>|fa_file_video_o|
|<span class="nerdfont big">&#xf1c2;</span>|fa_file_word_o|
|<span class="nerdfont big">&#xf0c5;</span>|fa_files_o|
|<span class="nerdfont big">&#xf008;</span>|fa_film|
|<span class="nerdfont big">&#xf0b0;</span>|fa_filter|
|<span class="nerdfont big">&#xf06d;</span>|fa_fire|
|<span class="nerdfont big">&#xf134;</span>|fa_fire_extinguisher|
|<span class="nerdfont big">&#xf269;</span>|fa_firefox|
|<span class="nerdfont big">&#xf2b0;</span>|fa_first_order|
|<span class="nerdfont big">&#xf024;</span>|fa_flag|
|<span class="nerdfont big">&#xf11e;</span>|fa_flag_checkered|
|<span class="nerdfont big">&#xf11d;</span>|fa_flag_o|
|<span class="nerdfont big">&#xf0c3;</span>|fa_flask|
|<span class="nerdfont big">&#xf16e;</span>|fa_flickr|
|<span class="nerdfont big">&#xf0c7;</span>|fa_floppy_o|
|<span class="nerdfont big">&#xf07b;</span>|fa_folder|
|<span class="nerdfont big">&#xf114;</span>|fa_folder_o|
|<span class="nerdfont big">&#xf07c;</span>|fa_folder_open|
|<span class="nerdfont big">&#xf115;</span>|fa_folder_open_o|
|<span class="nerdfont big">&#xf031;</span>|fa_font|
|<span class="nerdfont big">&#xf2b4;</span>|fa_font_awesome|
|<span class="nerdfont big">&#xf280;</span>|fa_fonticons|
|<span class="nerdfont big">&#xf286;</span>|fa_fort_awesome|
|<span class="nerdfont big">&#xf211;</span>|fa_forumbee|
|<span class="nerdfont big">&#xf04e;</span>|fa_forward|
|<span class="nerdfont big">&#xf180;</span>|fa_foursquare|
|<span class="nerdfont big">&#xf2c5;</span>|fa_free_code_camp|
|<span class="nerdfont big">&#xf119;</span>|fa_frown_o|
|<span class="nerdfont big">&#xf1e3;</span>|fa_futbol_o|
|<span class="nerdfont big">&#xf11b;</span>|fa_gamepad|
|<span class="nerdfont big">&#xf0e3;</span>|fa_gavel|
|<span class="nerdfont big">&#xf154;</span>|fa_gbp|
|<span class="nerdfont big">&#xf22d;</span>|fa_genderless|
|<span class="nerdfont big">&#xf265;</span>|fa_get_pocket|
|<span class="nerdfont big">&#xf260;</span>|fa_gg|
|<span class="nerdfont big">&#xf261;</span>|fa_gg_circle|
|<span class="nerdfont big">&#xf06b;</span>|fa_gift|
|<span class="nerdfont big">&#xf1d3;</span>|fa_git|
|<span class="nerdfont big">&#xf1d2;</span>|fa_git_square|
|<span class="nerdfont big">&#xf09b;</span>|fa_github|
|<span class="nerdfont big">&#xf113;</span>|fa_github_alt|
|<span class="nerdfont big">&#xf092;</span>|fa_github_square|
|<span class="nerdfont big">&#xf296;</span>|fa_gitlab|
|<span class="nerdfont big">&#xf000;</span>|fa_glass|
|<span class="nerdfont big">&#xf2a5;</span>|fa_glide|
|<span class="nerdfont big">&#xf2a6;</span>|fa_glide_g|
|<span class="nerdfont big">&#xf0ac;</span>|fa_globe|
|<span class="nerdfont big">&#xf1a0;</span>|fa_google|
|<span class="nerdfont big">&#xf0d5;</span>|fa_google_plus|
|<span class="nerdfont big">&#xf2b3;</span>|fa_google_plus_official|
|<span class="nerdfont big">&#xf0d4;</span>|fa_google_plus_square|
|<span class="nerdfont big">&#xf1ee;</span>|fa_google_wallet|
|<span class="nerdfont big">&#xf19d;</span>|fa_graduation_cap|
|<span class="nerdfont big">&#xf184;</span>|fa_gratipay|
|<span class="nerdfont big">&#xf2d6;</span>|fa_grav|
|<span class="nerdfont big">&#xf0fd;</span>|fa_h_square|
|<span class="nerdfont big">&#xf1d4;</span>|fa_hacker_news|
|<span class="nerdfont big">&#xf258;</span>|fa_hand_lizard_o|
|<span class="nerdfont big">&#xf0a7;</span>|fa_hand_o_down|
|<span class="nerdfont big">&#xf0a5;</span>|fa_hand_o_left|
|<span class="nerdfont big">&#xf0a4;</span>|fa_hand_o_right|
|<span class="nerdfont big">&#xf0a6;</span>|fa_hand_o_up|
|<span class="nerdfont big">&#xf256;</span>|fa_hand_paper_o|
|<span class="nerdfont big">&#xf25b;</span>|fa_hand_peace_o|
|<span class="nerdfont big">&#xf25a;</span>|fa_hand_pointer_o|
|<span class="nerdfont big">&#xf255;</span>|fa_hand_rock_o|
|<span class="nerdfont big">&#xf257;</span>|fa_hand_scissors_o|
|<span class="nerdfont big">&#xf259;</span>|fa_hand_spock_o|
|<span class="nerdfont big">&#xf2b5;</span>|fa_handshake_o|
|<span class="nerdfont big">&#xf292;</span>|fa_hashtag|
|<span class="nerdfont big">&#xf0a0;</span>|fa_hdd_o|
|<span class="nerdfont big">&#xf1dc;</span>|fa_header|
|<span class="nerdfont big">&#xf025;</span>|fa_headphones|
|<span class="nerdfont big">&#xf004;</span>|fa_heart|
|<span class="nerdfont big">&#xf08a;</span>|fa_heart_o|
|<span class="nerdfont big">&#xf21e;</span>|fa_heartbeat|
|<span class="nerdfont big">&#xf1da;</span>|fa_history|
|<span class="nerdfont big">&#xf015;</span>|fa_home|
|<span class="nerdfont big">&#xf0f8;</span>|fa_hospital_o|
|<span class="nerdfont big">&#xf254;</span>|fa_hourglass|
|<span class="nerdfont big">&#xf253;</span>|fa_hourglass_end|
|<span class="nerdfont big">&#xf252;</span>|fa_hourglass_half|
|<span class="nerdfont big">&#xf250;</span>|fa_hourglass_o|
|<span class="nerdfont big">&#xf251;</span>|fa_hourglass_start|
|<span class="nerdfont big">&#xf27c;</span>|fa_houzz|
|<span class="nerdfont big">&#xf13b;</span>|fa_html5|
|<span class="nerdfont big">&#xf246;</span>|fa_i_cursor|
|<span class="nerdfont big">&#xf2c1;</span>|fa_id_badge|
|<span class="nerdfont big">&#xf2c2;</span>|fa_id_card|
|<span class="nerdfont big">&#xf2c3;</span>|fa_id_card_o|
|<span class="nerdfont big">&#xf20b;</span>|fa_ils|
|<span class="nerdfont big">&#xf2d8;</span>|fa_imdb|
|<span class="nerdfont big">&#xf01c;</span>|fa_inbox|
|<span class="nerdfont big">&#xf03c;</span>|fa_indent|
|<span class="nerdfont big">&#xf275;</span>|fa_industry|
|<span class="nerdfont big">&#xf129;</span>|fa_info|
|<span class="nerdfont big">&#xf05a;</span>|fa_info_circle|
|<span class="nerdfont big">&#xf156;</span>|fa_inr|
|<span class="nerdfont big">&#xf16d;</span>|fa_instagram|
|<span class="nerdfont big">&#xf26b;</span>|fa_internet_explorer|
|<span class="nerdfont big">&#xf208;</span>|fa_ioxhost|
|<span class="nerdfont big">&#xf033;</span>|fa_italic|
|<span class="nerdfont big">&#xf1aa;</span>|fa_joomla|
|<span class="nerdfont big">&#xf157;</span>|fa_jpy|
|<span class="nerdfont big">&#xf1cc;</span>|fa_jsfiddle|
|<span class="nerdfont big">&#xf084;</span>|fa_key|
|<span class="nerdfont big">&#xf11c;</span>|fa_keyboard_o|
|<span class="nerdfont big">&#xf159;</span>|fa_krw|
|<span class="nerdfont big">&#xf1ab;</span>|fa_language|
|<span class="nerdfont big">&#xf109;</span>|fa_laptop|
|<span class="nerdfont big">&#xf202;</span>|fa_lastfm|
|<span class="nerdfont big">&#xf203;</span>|fa_lastfm_square|
|<span class="nerdfont big">&#xf06c;</span>|fa_leaf|
|<span class="nerdfont big">&#xf212;</span>|fa_leanpub|
|<span class="nerdfont big">&#xf094;</span>|fa_lemon_o|
|<span class="nerdfont big">&#xf149;</span>|fa_level_down|
|<span class="nerdfont big">&#xf148;</span>|fa_level_up|
|<span class="nerdfont big">&#xf1cd;</span>|fa_life_ring|
|<span class="nerdfont big">&#xf0eb;</span>|fa_lightbulb_o|
|<span class="nerdfont big">&#xf201;</span>|fa_line_chart|
|<span class="nerdfont big">&#xf0c1;</span>|fa_link|
|<span class="nerdfont big">&#xf0e1;</span>|fa_linkedin|
|<span class="nerdfont big">&#xf08c;</span>|fa_linkedin_square|
|<span class="nerdfont big">&#xf2b8;</span>|fa_linode|
|<span class="nerdfont big">&#xf17c;</span>|fa_linux|
|<span class="nerdfont big">&#xf03a;</span>|fa_list|
|<span class="nerdfont big">&#xf022;</span>|fa_list_alt|
|<span class="nerdfont big">&#xf0cb;</span>|fa_list_ol|
|<span class="nerdfont big">&#xf0ca;</span>|fa_list_ul|
|<span class="nerdfont big">&#xf124;</span>|fa_location_arrow|
|<span class="nerdfont big">&#xf023;</span>|fa_lock|
|<span class="nerdfont big">&#xf175;</span>|fa_long_arrow_down|
|<span class="nerdfont big">&#xf177;</span>|fa_long_arrow_left|
|<span class="nerdfont big">&#xf178;</span>|fa_long_arrow_right|
|<span class="nerdfont big">&#xf176;</span>|fa_long_arrow_up|
|<span class="nerdfont big">&#xf2a8;</span>|fa_low_vision|
|<span class="nerdfont big">&#xf0d0;</span>|fa_magic|
|<span class="nerdfont big">&#xf076;</span>|fa_magnet|
|<span class="nerdfont big">&#xf183;</span>|fa_male|
|<span class="nerdfont big">&#xf279;</span>|fa_map|
|<span class="nerdfont big">&#xf041;</span>|fa_map_marker|
|<span class="nerdfont big">&#xf278;</span>|fa_map_o|
|<span class="nerdfont big">&#xf276;</span>|fa_map_pin|
|<span class="nerdfont big">&#xf277;</span>|fa_map_signs|
|<span class="nerdfont big">&#xf222;</span>|fa_mars|
|<span class="nerdfont big">&#xf227;</span>|fa_mars_double|
|<span class="nerdfont big">&#xf229;</span>|fa_mars_stroke|
|<span class="nerdfont big">&#xf22b;</span>|fa_mars_stroke_h|
|<span class="nerdfont big">&#xf22a;</span>|fa_mars_stroke_v|
|<span class="nerdfont big">&#xf136;</span>|fa_maxcdn|
|<span class="nerdfont big">&#xf20c;</span>|fa_meanpath|
|<span class="nerdfont big">&#xf23a;</span>|fa_medium|
|<span class="nerdfont big">&#xf0fa;</span>|fa_medkit|
|<span class="nerdfont big">&#xf2e0;</span>|fa_meetup|
|<span class="nerdfont big">&#xf11a;</span>|fa_meh_o|
|<span class="nerdfont big">&#xf223;</span>|fa_mercury|
|<span class="nerdfont big">&#xf2db;</span>|fa_microchip|
|<span class="nerdfont big">&#xf130;</span>|fa_microphone|
|<span class="nerdfont big">&#xf131;</span>|fa_microphone_slash|
|<span class="nerdfont big">&#xf068;</span>|fa_minus|
|<span class="nerdfont big">&#xf056;</span>|fa_minus_circle|
|<span class="nerdfont big">&#xf146;</span>|fa_minus_square|
|<span class="nerdfont big">&#xf147;</span>|fa_minus_square_o|
|<span class="nerdfont big">&#xf289;</span>|fa_mixcloud|
|<span class="nerdfont big">&#xf10b;</span>|fa_mobile|
|<span class="nerdfont big">&#xf285;</span>|fa_modx|
|<span class="nerdfont big">&#xf0d6;</span>|fa_money|
|<span class="nerdfont big">&#xf186;</span>|fa_moon_o|
|<span class="nerdfont big">&#xf21c;</span>|fa_motorcycle|
|<span class="nerdfont big">&#xf245;</span>|fa_mouse_pointer|
|<span class="nerdfont big">&#xf001;</span>|fa_music|
|<span class="nerdfont big">&#xf22c;</span>|fa_neuter|
|<span class="nerdfont big">&#xf1ea;</span>|fa_newspaper_o|
|<span class="nerdfont big">&#xf247;</span>|fa_object_group|
|<span class="nerdfont big">&#xf248;</span>|fa_object_ungroup|
|<span class="nerdfont big">&#xf263;</span>|fa_odnoklassniki|
|<span class="nerdfont big">&#xf264;</span>|fa_odnoklassniki_square|
|<span class="nerdfont big">&#xf23d;</span>|fa_opencart|
|<span class="nerdfont big">&#xf19b;</span>|fa_openid|
|<span class="nerdfont big">&#xf26a;</span>|fa_opera|
|<span class="nerdfont big">&#xf23c;</span>|fa_optin_monster|
|<span class="nerdfont big">&#xf03b;</span>|fa_outdent|
|<span class="nerdfont big">&#xf18c;</span>|fa_pagelines|
|<span class="nerdfont big">&#xf1fc;</span>|fa_paint_brush|
|<span class="nerdfont big">&#xf1d8;</span>|fa_paper_plane|
|<span class="nerdfont big">&#xf1d9;</span>|fa_paper_plane_o|
|<span class="nerdfont big">&#xf0c6;</span>|fa_paperclip|
|<span class="nerdfont big">&#xf1dd;</span>|fa_paragraph|
|<span class="nerdfont big">&#xf04c;</span>|fa_pause|
|<span class="nerdfont big">&#xf28b;</span>|fa_pause_circle|
|<span class="nerdfont big">&#xf28c;</span>|fa_pause_circle_o|
|<span class="nerdfont big">&#xf1b0;</span>|fa_paw|
|<span class="nerdfont big">&#xf1ed;</span>|fa_paypal|
|<span class="nerdfont big">&#xf040;</span>|fa_pencil|
|<span class="nerdfont big">&#xf14b;</span>|fa_pencil_square|
|<span class="nerdfont big">&#xf044;</span>|fa_pencil_square_o|
|<span class="nerdfont big">&#xf295;</span>|fa_percent|
|<span class="nerdfont big">&#xf095;</span>|fa_phone|
|<span class="nerdfont big">&#xf098;</span>|fa_phone_square|
|<span class="nerdfont big">&#xf03e;</span>|fa_picture_o|
|<span class="nerdfont big">&#xf200;</span>|fa_pie_chart|
|<span class="nerdfont big">&#xf2ae;</span>|fa_pied_piper|
|<span class="nerdfont big">&#xf1a8;</span>|fa_pied_piper_alt|
|<span class="nerdfont big">&#xf1a7;</span>|fa_pied_piper_pp|
|<span class="nerdfont big">&#xf0d2;</span>|fa_pinterest|
|<span class="nerdfont big">&#xf231;</span>|fa_pinterest_p|
|<span class="nerdfont big">&#xf0d3;</span>|fa_pinterest_square|
|<span class="nerdfont big">&#xf072;</span>|fa_plane|
|<span class="nerdfont big">&#xf04b;</span>|fa_play|
|<span class="nerdfont big">&#xf144;</span>|fa_play_circle|
|<span class="nerdfont big">&#xf01d;</span>|fa_play_circle_o|
|<span class="nerdfont big">&#xf1e6;</span>|fa_plug|
|<span class="nerdfont big">&#xf067;</span>|fa_plus|
|<span class="nerdfont big">&#xf055;</span>|fa_plus_circle|
|<span class="nerdfont big">&#xf0fe;</span>|fa_plus_square|
|<span class="nerdfont big">&#xf196;</span>|fa_plus_square_o|
|<span class="nerdfont big">&#xf2ce;</span>|fa_podcast|
|<span class="nerdfont big">&#xf011;</span>|fa_power_off|
|<span class="nerdfont big">&#xf02f;</span>|fa_print|
|<span class="nerdfont big">&#xf288;</span>|fa_product_hunt|
|<span class="nerdfont big">&#xf12e;</span>|fa_puzzle_piece|
|<span class="nerdfont big">&#xf1d6;</span>|fa_qq|
|<span class="nerdfont big">&#xf029;</span>|fa_qrcode|
|<span class="nerdfont big">&#xf128;</span>|fa_question|
|<span class="nerdfont big">&#xf059;</span>|fa_question_circle|
|<span class="nerdfont big">&#xf29c;</span>|fa_question_circle_o|
|<span class="nerdfont big">&#xf2c4;</span>|fa_quora|
|<span class="nerdfont big">&#xf10d;</span>|fa_quote_left|
|<span class="nerdfont big">&#xf10e;</span>|fa_quote_right|
|<span class="nerdfont big">&#xf074;</span>|fa_random|
|<span class="nerdfont big">&#xf2d9;</span>|fa_ravelry|
|<span class="nerdfont big">&#xf1d0;</span>|fa_rebel|
|<span class="nerdfont big">&#xf1b8;</span>|fa_recycle|
|<span class="nerdfont big">&#xf1a1;</span>|fa_reddit|
|<span class="nerdfont big">&#xf281;</span>|fa_reddit_alien|
|<span class="nerdfont big">&#xf1a2;</span>|fa_reddit_square|
|<span class="nerdfont big">&#xf021;</span>|fa_refresh|
|<span class="nerdfont big">&#xf25d;</span>|fa_registered|
|<span class="nerdfont big">&#xf18b;</span>|fa_renren|
|<span class="nerdfont big">&#xf01e;</span>|fa_repeat|
|<span class="nerdfont big">&#xf112;</span>|fa_reply|
|<span class="nerdfont big">&#xf122;</span>|fa_reply_all|
|<span class="nerdfont big">&#xf079;</span>|fa_retweet|
|<span class="nerdfont big">&#xf018;</span>|fa_road|
|<span class="nerdfont big">&#xf135;</span>|fa_rocket|
|<span class="nerdfont big">&#xf09e;</span>|fa_rss|
|<span class="nerdfont big">&#xf143;</span>|fa_rss_square|
|<span class="nerdfont big">&#xf158;</span>|fa_rub|
|<span class="nerdfont big">&#xf267;</span>|fa_safari|
|<span class="nerdfont big">&#xf0c4;</span>|fa_scissors|
|<span class="nerdfont big">&#xf28a;</span>|fa_scribd|
|<span class="nerdfont big">&#xf002;</span>|fa_search|
|<span class="nerdfont big">&#xf010;</span>|fa_search_minus|
|<span class="nerdfont big">&#xf00e;</span>|fa_search_plus|
|<span class="nerdfont big">&#xf213;</span>|fa_sellsy|
|<span class="nerdfont big">&#xf233;</span>|fa_server|
|<span class="nerdfont big">&#xf064;</span>|fa_share|
|<span class="nerdfont big">&#xf1e0;</span>|fa_share_alt|
|<span class="nerdfont big">&#xf1e1;</span>|fa_share_alt_square|
|<span class="nerdfont big">&#xf14d;</span>|fa_share_square|
|<span class="nerdfont big">&#xf045;</span>|fa_share_square_o|
|<span class="nerdfont big">&#xf132;</span>|fa_shield|
|<span class="nerdfont big">&#xf21a;</span>|fa_ship|
|<span class="nerdfont big">&#xf214;</span>|fa_shirtsinbulk|
|<span class="nerdfont big">&#xf290;</span>|fa_shopping_bag|
|<span class="nerdfont big">&#xf291;</span>|fa_shopping_basket|
|<span class="nerdfont big">&#xf07a;</span>|fa_shopping_cart|
|<span class="nerdfont big">&#xf2cc;</span>|fa_shower|
|<span class="nerdfont big">&#xf090;</span>|fa_sign_in|
|<span class="nerdfont big">&#xf2a7;</span>|fa_sign_language|
|<span class="nerdfont big">&#xf08b;</span>|fa_sign_out|
|<span class="nerdfont big">&#xf012;</span>|fa_signal|
|<span class="nerdfont big">&#xf215;</span>|fa_simplybuilt|
|<span class="nerdfont big">&#xf0e8;</span>|fa_sitemap|
|<span class="nerdfont big">&#xf216;</span>|fa_skyatlas|
|<span class="nerdfont big">&#xf17e;</span>|fa_skype|
|<span class="nerdfont big">&#xf198;</span>|fa_slack|
|<span class="nerdfont big">&#xf1de;</span>|fa_sliders|
|<span class="nerdfont big">&#xf1e7;</span>|fa_slideshare|
|<span class="nerdfont big">&#xf118;</span>|fa_smile_o|
|<span class="nerdfont big">&#xf2ab;</span>|fa_snapchat|
|<span class="nerdfont big">&#xf2ac;</span>|fa_snapchat_ghost|
|<span class="nerdfont big">&#xf2ad;</span>|fa_snapchat_square|
|<span class="nerdfont big">&#xf2dc;</span>|fa_snowflake_o|
|<span class="nerdfont big">&#xf0dc;</span>|fa_sort|
|<span class="nerdfont big">&#xf15d;</span>|fa_sort_alpha_asc|
|<span class="nerdfont big">&#xf15e;</span>|fa_sort_alpha_desc|
|<span class="nerdfont big">&#xf160;</span>|fa_sort_amount_asc|
|<span class="nerdfont big">&#xf161;</span>|fa_sort_amount_desc|
|<span class="nerdfont big">&#xf0de;</span>|fa_sort_asc|
|<span class="nerdfont big">&#xf0dd;</span>|fa_sort_desc|
|<span class="nerdfont big">&#xf162;</span>|fa_sort_numeric_asc|
|<span class="nerdfont big">&#xf163;</span>|fa_sort_numeric_desc|
|<span class="nerdfont big">&#xf1be;</span>|fa_soundcloud|
|<span class="nerdfont big">&#xf197;</span>|fa_space_shuttle|
|<span class="nerdfont big">&#xf110;</span>|fa_spinner|
|<span class="nerdfont big">&#xf1b1;</span>|fa_spoon|
|<span class="nerdfont big">&#xf1bc;</span>|fa_spotify|
|<span class="nerdfont big">&#xf0c8;</span>|fa_square|
|<span class="nerdfont big">&#xf096;</span>|fa_square_o|
|<span class="nerdfont big">&#xf18d;</span>|fa_stack_exchange|
|<span class="nerdfont big">&#xf16c;</span>|fa_stack_overflow|
|<span class="nerdfont big">&#xf005;</span>|fa_star|
|<span class="nerdfont big">&#xf089;</span>|fa_star_half|
|<span class="nerdfont big">&#xf123;</span>|fa_star_half_o|
|<span class="nerdfont big">&#xf006;</span>|fa_star_o|
|<span class="nerdfont big">&#xf1b6;</span>|fa_steam|
|<span class="nerdfont big">&#xf1b7;</span>|fa_steam_square|
|<span class="nerdfont big">&#xf048;</span>|fa_step_backward|
|<span class="nerdfont big">&#xf051;</span>|fa_step_forward|
|<span class="nerdfont big">&#xf0f1;</span>|fa_stethoscope|
|<span class="nerdfont big">&#xf249;</span>|fa_sticky_note|
|<span class="nerdfont big">&#xf24a;</span>|fa_sticky_note_o|
|<span class="nerdfont big">&#xf04d;</span>|fa_stop|
|<span class="nerdfont big">&#xf28d;</span>|fa_stop_circle|
|<span class="nerdfont big">&#xf28e;</span>|fa_stop_circle_o|
|<span class="nerdfont big">&#xf21d;</span>|fa_street_view|
|<span class="nerdfont big">&#xf0cc;</span>|fa_strikethrough|
|<span class="nerdfont big">&#xf1a4;</span>|fa_stumbleupon|
|<span class="nerdfont big">&#xf1a3;</span>|fa_stumbleupon_circle|
|<span class="nerdfont big">&#xf12c;</span>|fa_subscript|
|<span class="nerdfont big">&#xf239;</span>|fa_subway|
|<span class="nerdfont big">&#xf0f2;</span>|fa_suitcase|
|<span class="nerdfont big">&#xf185;</span>|fa_sun_o|
|<span class="nerdfont big">&#xf2dd;</span>|fa_superpowers|
|<span class="nerdfont big">&#xf12b;</span>|fa_superscript|
|<span class="nerdfont big">&#xf0ce;</span>|fa_table|
|<span class="nerdfont big">&#xf10a;</span>|fa_tablet|
|<span class="nerdfont big">&#xf0e4;</span>|fa_tachometer|
|<span class="nerdfont big">&#xf02b;</span>|fa_tag|
|<span class="nerdfont big">&#xf02c;</span>|fa_tags|
|<span class="nerdfont big">&#xf0ae;</span>|fa_tasks|
|<span class="nerdfont big">&#xf1ba;</span>|fa_taxi|
|<span class="nerdfont big">&#xf2c6;</span>|fa_telegram|
|<span class="nerdfont big">&#xf26c;</span>|fa_television|
|<span class="nerdfont big">&#xf1d5;</span>|fa_tencent_weibo|
|<span class="nerdfont big">&#xf120;</span>|fa_terminal|
|<span class="nerdfont big">&#xf034;</span>|fa_text_height|
|<span class="nerdfont big">&#xf035;</span>|fa_text_width|
|<span class="nerdfont big">&#xf00a;</span>|fa_th|
|<span class="nerdfont big">&#xf009;</span>|fa_th_large|
|<span class="nerdfont big">&#xf00b;</span>|fa_th_list|
|<span class="nerdfont big">&#xf2b2;</span>|fa_themeisle|
|<span class="nerdfont big">&#xf2cb;</span>|fa_thermometer_empty|
|<span class="nerdfont big">&#xf2c7;</span>|fa_thermometer_full|
|<span class="nerdfont big">&#xf2c9;</span>|fa_thermometer_half|
|<span class="nerdfont big">&#xf2ca;</span>|fa_thermometer_quarter|
|<span class="nerdfont big">&#xf2c8;</span>|fa_thermometer_three_quarters|
|<span class="nerdfont big">&#xf08d;</span>|fa_thumb_tack|
|<span class="nerdfont big">&#xf165;</span>|fa_thumbs_down|
|<span class="nerdfont big">&#xf088;</span>|fa_thumbs_o_down|
|<span class="nerdfont big">&#xf087;</span>|fa_thumbs_o_up|
|<span class="nerdfont big">&#xf164;</span>|fa_thumbs_up|
|<span class="nerdfont big">&#xf145;</span>|fa_ticket|
|<span class="nerdfont big">&#xf00d;</span>|fa_times|
|<span class="nerdfont big">&#xf057;</span>|fa_times_circle|
|<span class="nerdfont big">&#xf05c;</span>|fa_times_circle_o|
|<span class="nerdfont big">&#xf043;</span>|fa_tint|
|<span class="nerdfont big">&#xf204;</span>|fa_toggle_off|
|<span class="nerdfont big">&#xf205;</span>|fa_toggle_on|
|<span class="nerdfont big">&#xf25c;</span>|fa_trademark|
|<span class="nerdfont big">&#xf238;</span>|fa_train|
|<span class="nerdfont big">&#xf224;</span>|fa_transgender|
|<span class="nerdfont big">&#xf225;</span>|fa_transgender_alt|
|<span class="nerdfont big">&#xf1f8;</span>|fa_trash|
|<span class="nerdfont big">&#xf014;</span>|fa_trash_o|
|<span class="nerdfont big">&#xf1bb;</span>|fa_tree|
|<span class="nerdfont big">&#xf181;</span>|fa_trello|
|<span class="nerdfont big">&#xf262;</span>|fa_tripadvisor|
|<span class="nerdfont big">&#xf091;</span>|fa_trophy|
|<span class="nerdfont big">&#xf0d1;</span>|fa_truck|
|<span class="nerdfont big">&#xf195;</span>|fa_try|
|<span class="nerdfont big">&#xf1e4;</span>|fa_tty|
|<span class="nerdfont big">&#xf173;</span>|fa_tumblr|
|<span class="nerdfont big">&#xf174;</span>|fa_tumblr_square|
|<span class="nerdfont big">&#xf1e8;</span>|fa_twitch|
|<span class="nerdfont big">&#xf099;</span>|fa_twitter|
|<span class="nerdfont big">&#xf081;</span>|fa_twitter_square|
|<span class="nerdfont big">&#xf0e9;</span>|fa_umbrella|
|<span class="nerdfont big">&#xf0cd;</span>|fa_underline|
|<span class="nerdfont big">&#xf0e2;</span>|fa_undo|
|<span class="nerdfont big">&#xf29a;</span>|fa_universal_access|
|<span class="nerdfont big">&#xf19c;</span>|fa_university|
|<span class="nerdfont big">&#xf09c;</span>|fa_unlock|
|<span class="nerdfont big">&#xf13e;</span>|fa_unlock_alt|
|<span class="nerdfont big">&#xf093;</span>|fa_upload|
|<span class="nerdfont big">&#xf287;</span>|fa_usb|
|<span class="nerdfont big">&#xf155;</span>|fa_usd|
|<span class="nerdfont big">&#xf007;</span>|fa_user|
|<span class="nerdfont big">&#xf2bd;</span>|fa_user_circle|
|<span class="nerdfont big">&#xf2be;</span>|fa_user_circle_o|
|<span class="nerdfont big">&#xf0f0;</span>|fa_user_md|
|<span class="nerdfont big">&#xf2c0;</span>|fa_user_o|
|<span class="nerdfont big">&#xf234;</span>|fa_user_plus|
|<span class="nerdfont big">&#xf21b;</span>|fa_user_secret|
|<span class="nerdfont big">&#xf235;</span>|fa_user_times|
|<span class="nerdfont big">&#xf0c0;</span>|fa_users|
|<span class="nerdfont big">&#xf221;</span>|fa_venus|
|<span class="nerdfont big">&#xf226;</span>|fa_venus_double|
|<span class="nerdfont big">&#xf228;</span>|fa_venus_mars|
|<span class="nerdfont big">&#xf237;</span>|fa_viacoin|
|<span class="nerdfont big">&#xf2a9;</span>|fa_viadeo|
|<span class="nerdfont big">&#xf2aa;</span>|fa_viadeo_square|
|<span class="nerdfont big">&#xf03d;</span>|fa_video_camera|
|<span class="nerdfont big">&#xf27d;</span>|fa_vimeo|
|<span class="nerdfont big">&#xf194;</span>|fa_vimeo_square|
|<span class="nerdfont big">&#xf1ca;</span>|fa_vine|
|<span class="nerdfont big">&#xf189;</span>|fa_vk|
|<span class="nerdfont big">&#xf2a0;</span>|fa_volume_control_phone|
|<span class="nerdfont big">&#xf027;</span>|fa_volume_down|
|<span class="nerdfont big">&#xf026;</span>|fa_volume_off|
|<span class="nerdfont big">&#xf028;</span>|fa_volume_up|
|<span class="nerdfont big">&#xf18a;</span>|fa_weibo|
|<span class="nerdfont big">&#xf1d7;</span>|fa_weixin|
|<span class="nerdfont big">&#xf232;</span>|fa_whatsapp|
|<span class="nerdfont big">&#xf193;</span>|fa_wheelchair|
|<span class="nerdfont big">&#xf29b;</span>|fa_wheelchair_alt|
|<span class="nerdfont big">&#xf1eb;</span>|fa_wifi|
|<span class="nerdfont big">&#xf266;</span>|fa_wikipedia_w|
|<span class="nerdfont big">&#xf2d3;</span>|fa_window_close|
|<span class="nerdfont big">&#xf2d4;</span>|fa_window_close_o|
|<span class="nerdfont big">&#xf2d0;</span>|fa_window_maximize|
|<span class="nerdfont big">&#xf2d1;</span>|fa_window_minimize|
|<span class="nerdfont big">&#xf2d2;</span>|fa_window_restore|
|<span class="nerdfont big">&#xf17a;</span>|fa_windows|
|<span class="nerdfont big">&#xf19a;</span>|fa_wordpress|
|<span class="nerdfont big">&#xf297;</span>|fa_wpbeginner|
|<span class="nerdfont big">&#xf2de;</span>|fa_wpexplorer|
|<span class="nerdfont big">&#xf298;</span>|fa_wpforms|
|<span class="nerdfont big">&#xf0ad;</span>|fa_wrench|
|<span class="nerdfont big">&#xf168;</span>|fa_xing|
|<span class="nerdfont big">&#xf169;</span>|fa_xing_square|
|<span class="nerdfont big">&#xf23b;</span>|fa_y_combinator|
|<span class="nerdfont big">&#xf19e;</span>|fa_yahoo|
|<span class="nerdfont big">&#xf1e9;</span>|fa_yelp|
|<span class="nerdfont big">&#xf2b1;</span>|fa_yoast|
|<span class="nerdfont big">&#xf167;</span>|fa_youtube|
|<span class="nerdfont big">&#xf16a;</span>|fa_youtube_play|
|<span class="nerdfont big">&#xf166;</span>|fa_youtube_square|
|<span class="nerdfont big">&#xe29e;</span>|fae_apple_fruit|
|<span class="nerdfont big">&#xe27f;</span>|fae_atom|
|<span class="nerdfont big">&#xe280;</span>|fae_bacteria|
|<span class="nerdfont big">&#xe281;</span>|fae_banana|
|<span class="nerdfont big">&#xe282;</span>|fae_bath|
|<span class="nerdfont big">&#xe283;</span>|fae_bed|
|<span class="nerdfont big">&#xe284;</span>|fae_benzene|
|<span class="nerdfont big">&#xe285;</span>|fae_bigger|
|<span class="nerdfont big">&#xe286;</span>|fae_biohazard|
|<span class="nerdfont big">&#xe287;</span>|fae_blogger_circle|
|<span class="nerdfont big">&#xe288;</span>|fae_blogger_square|
|<span class="nerdfont big">&#xe289;</span>|fae_bones|
|<span class="nerdfont big">&#xe28a;</span>|fae_book_open|
|<span class="nerdfont big">&#xe28b;</span>|fae_book_open_o|
|<span class="nerdfont big">&#xe28c;</span>|fae_brain|
|<span class="nerdfont big">&#xe28d;</span>|fae_bread|
|<span class="nerdfont big">&#xe28e;</span>|fae_butterfly|
|<span class="nerdfont big">&#xe28f;</span>|fae_carot|
|<span class="nerdfont big">&#xe290;</span>|fae_cc_by|
|<span class="nerdfont big">&#xe291;</span>|fae_cc_cc|
|<span class="nerdfont big">&#xe292;</span>|fae_cc_nc|
|<span class="nerdfont big">&#xe293;</span>|fae_cc_nc_eu|
|<span class="nerdfont big">&#xe294;</span>|fae_cc_nc_jp|
|<span class="nerdfont big">&#xe295;</span>|fae_cc_nd|
|<span class="nerdfont big">&#xe296;</span>|fae_cc_remix|
|<span class="nerdfont big">&#xe297;</span>|fae_cc_sa|
|<span class="nerdfont big">&#xe298;</span>|fae_cc_share|
|<span class="nerdfont big">&#xe299;</span>|fae_cc_zero|
|<span class="nerdfont big">&#xe29a;</span>|fae_checklist_o|
|<span class="nerdfont big">&#xe264;</span>|fae_cheese|
|<span class="nerdfont big">&#xe29b;</span>|fae_cherry|
|<span class="nerdfont big">&#xe29c;</span>|fae_chess_bishop|
|<span class="nerdfont big">&#xe25f;</span>|fae_chess_horse|
|<span class="nerdfont big">&#xe260;</span>|fae_chess_king|
|<span class="nerdfont big">&#xe261;</span>|fae_chess_pawn|
|<span class="nerdfont big">&#xe262;</span>|fae_chess_queen|
|<span class="nerdfont big">&#xe263;</span>|fae_chess_tower|
|<span class="nerdfont big">&#xe29f;</span>|fae_chicken_thigh|
|<span class="nerdfont big">&#xe265;</span>|fae_chilli|
|<span class="nerdfont big">&#xe266;</span>|fae_chip|
|<span class="nerdfont big">&#xe267;</span>|fae_cicling|
|<span class="nerdfont big">&#xe268;</span>|fae_cloud|
|<span class="nerdfont big">&#xe269;</span>|fae_cockroach|
|<span class="nerdfont big">&#xe26a;</span>|fae_coffe_beans|
|<span class="nerdfont big">&#xe26b;</span>|fae_coins|
|<span class="nerdfont big">&#xe26c;</span>|fae_comb|
|<span class="nerdfont big">&#xe26d;</span>|fae_comet|
|<span class="nerdfont big">&#xe26e;</span>|fae_crown|
|<span class="nerdfont big">&#xe26f;</span>|fae_cup_coffe|
|<span class="nerdfont big">&#xe270;</span>|fae_dice|
|<span class="nerdfont big">&#xe271;</span>|fae_disco|
|<span class="nerdfont big">&#xe272;</span>|fae_dna|
|<span class="nerdfont big">&#xe273;</span>|fae_donut|
|<span class="nerdfont big">&#xe274;</span>|fae_dress|
|<span class="nerdfont big">&#xe275;</span>|fae_drop|
|<span class="nerdfont big">&#xe276;</span>|fae_ello|
|<span class="nerdfont big">&#xe277;</span>|fae_envelope_open|
|<span class="nerdfont big">&#xe278;</span>|fae_envelope_open_o|
|<span class="nerdfont big">&#xe279;</span>|fae_equal|
|<span class="nerdfont big">&#xe27a;</span>|fae_equal_bigger|
|<span class="nerdfont big">&#xe27b;</span>|fae_feedly|
|<span class="nerdfont big">&#xe27c;</span>|fae_file_export|
|<span class="nerdfont big">&#xe27d;</span>|fae_file_import|
|<span class="nerdfont big">&#xe23f;</span>|fae_fingerprint|
|<span class="nerdfont big">&#xe240;</span>|fae_floppy|
|<span class="nerdfont big">&#xe241;</span>|fae_footprint|
|<span class="nerdfont big">&#xe242;</span>|fae_freecodecamp|
|<span class="nerdfont big">&#xe243;</span>|fae_galaxy|
|<span class="nerdfont big">&#xe244;</span>|fae_galery|
|<span class="nerdfont big">&#xe2a0;</span>|fae_gift_card|
|<span class="nerdfont big">&#xe245;</span>|fae_glass|
|<span class="nerdfont big">&#xe246;</span>|fae_google_drive|
|<span class="nerdfont big">&#xe247;</span>|fae_google_play|
|<span class="nerdfont big">&#xe248;</span>|fae_gps|
|<span class="nerdfont big">&#xe249;</span>|fae_grav|
|<span class="nerdfont big">&#xe24a;</span>|fae_guitar|
|<span class="nerdfont big">&#xe24b;</span>|fae_gut|
|<span class="nerdfont big">&#xe24c;</span>|fae_halter|
|<span class="nerdfont big">&#xe24d;</span>|fae_hamburger|
|<span class="nerdfont big">&#xe24e;</span>|fae_hat|
|<span class="nerdfont big">&#xe24f;</span>|fae_hexagon|
|<span class="nerdfont big">&#xe250;</span>|fae_high_heel|
|<span class="nerdfont big">&#xe251;</span>|fae_hotdog|
|<span class="nerdfont big">&#xe252;</span>|fae_ice_cream|
|<span class="nerdfont big">&#xe253;</span>|fae_id_card|
|<span class="nerdfont big">&#xe254;</span>|fae_imdb|
|<span class="nerdfont big">&#xe255;</span>|fae_infinity|
|<span class="nerdfont big">&#xe2a1;</span>|fae_injection|
|<span class="nerdfont big">&#xe2a2;</span>|fae_isle|
|<span class="nerdfont big">&#xe256;</span>|fae_java|
|<span class="nerdfont big">&#xe257;</span>|fae_layers|
|<span class="nerdfont big">&#xe258;</span>|fae_lips|
|<span class="nerdfont big">&#xe259;</span>|fae_lipstick|
|<span class="nerdfont big">&#xe25a;</span>|fae_liver|
|<span class="nerdfont big">&#xe2a3;</span>|fae_lollipop|
|<span class="nerdfont big">&#xe2a4;</span>|fae_loyalty_card|
|<span class="nerdfont big">&#xe25b;</span>|fae_lung|
|<span class="nerdfont big">&#xe25c;</span>|fae_makeup_brushes|
|<span class="nerdfont big">&#xe25d;</span>|fae_maximize|
|<span class="nerdfont big">&#xe2a5;</span>|fae_meat|
|<span class="nerdfont big">&#xe221;</span>|fae_medicine|
|<span class="nerdfont big">&#xe222;</span>|fae_microscope|
|<span class="nerdfont big">&#xe223;</span>|fae_milk_bottle|
|<span class="nerdfont big">&#xe224;</span>|fae_minimize|
|<span class="nerdfont big">&#xe225;</span>|fae_molecule|
|<span class="nerdfont big">&#xe226;</span>|fae_moon_cloud|
|<span class="nerdfont big">&#xe2a6;</span>|fae_mountains|
|<span class="nerdfont big">&#xe227;</span>|fae_mushroom|
|<span class="nerdfont big">&#xe228;</span>|fae_mustache|
|<span class="nerdfont big">&#xe229;</span>|fae_mysql|
|<span class="nerdfont big">&#xe22a;</span>|fae_nintendo|
|<span class="nerdfont big">&#xe2a7;</span>|fae_orange|
|<span class="nerdfont big">&#xe22b;</span>|fae_palette_color|
|<span class="nerdfont big">&#xe2a8;</span>|fae_peach|
|<span class="nerdfont big">&#xe2a9;</span>|fae_pear|
|<span class="nerdfont big">&#xe22c;</span>|fae_pi|
|<span class="nerdfont big">&#xe22d;</span>|fae_pizza|
|<span class="nerdfont big">&#xe22e;</span>|fae_planet|
|<span class="nerdfont big">&#xe22f;</span>|fae_plant|
|<span class="nerdfont big">&#xe230;</span>|fae_playstation|
|<span class="nerdfont big">&#xe231;</span>|fae_poison|
|<span class="nerdfont big">&#xe232;</span>|fae_popcorn|
|<span class="nerdfont big">&#xe233;</span>|fae_popsicle|
|<span class="nerdfont big">&#xe234;</span>|fae_pulse|
|<span class="nerdfont big">&#xe235;</span>|fae_python|
|<span class="nerdfont big">&#xe236;</span>|fae_quora_circle|
|<span class="nerdfont big">&#xe237;</span>|fae_quora_square|
|<span class="nerdfont big">&#xe238;</span>|fae_radioactive|
|<span class="nerdfont big">&#xe239;</span>|fae_raining|
|<span class="nerdfont big">&#xe23a;</span>|fae_real_heart|
|<span class="nerdfont big">&#xe23b;</span>|fae_refrigerator|
|<span class="nerdfont big">&#xe23c;</span>|fae_restore|
|<span class="nerdfont big">&#xe23d;</span>|fae_ring|
|<span class="nerdfont big">&#xe23e;</span>|fae_ruby|
|<span class="nerdfont big">&#xe21e;</span>|fae_ruby_o|
|<span class="nerdfont big">&#xe21f;</span>|fae_ruler|
|<span class="nerdfont big">&#xe218;</span>|fae_shirt|
|<span class="nerdfont big">&#xe216;</span>|fae_slash|
|<span class="nerdfont big">&#xe200;</span>|fae_smaller|
|<span class="nerdfont big">&#xe201;</span>|fae_snowing|
|<span class="nerdfont big">&#xe202;</span>|fae_soda|
|<span class="nerdfont big">&#xe203;</span>|fae_sofa|
|<span class="nerdfont big">&#xe204;</span>|fae_soup|
|<span class="nerdfont big">&#xe205;</span>|fae_spermatozoon|
|<span class="nerdfont big">&#xe206;</span>|fae_spin_double|
|<span class="nerdfont big">&#xe207;</span>|fae_stomach|
|<span class="nerdfont big">&#xe208;</span>|fae_storm|
|<span class="nerdfont big">&#xe21d;</span>|fae_sun_cloud|
|<span class="nerdfont big">&#xe21a;</span>|fae_sushi|
|<span class="nerdfont big">&#xe219;</span>|fae_tacos|
|<span class="nerdfont big">&#xe217;</span>|fae_telegram|
|<span class="nerdfont big">&#xe215;</span>|fae_telegram_circle|
|<span class="nerdfont big">&#xe209;</span>|fae_telescope|
|<span class="nerdfont big">&#xe20a;</span>|fae_thermometer|
|<span class="nerdfont big">&#xe20b;</span>|fae_thermometer_high|
|<span class="nerdfont big">&#xe20c;</span>|fae_thermometer_low|
|<span class="nerdfont big">&#xe20d;</span>|fae_thin_close|
|<span class="nerdfont big">&#xe20e;</span>|fae_toilet|
|<span class="nerdfont big">&#xe20f;</span>|fae_tools|
|<span class="nerdfont big">&#xe210;</span>|fae_tooth|
|<span class="nerdfont big">&#xe21c;</span>|fae_tree|
|<span class="nerdfont big">&#xe21b;</span>|fae_triangle_ruler|
|<span class="nerdfont big">&#xe220;</span>|fae_umbrella|
|<span class="nerdfont big">&#xe211;</span>|fae_uterus|
|<span class="nerdfont big">&#xe214;</span>|fae_virus|
|<span class="nerdfont big">&#xe212;</span>|fae_w3c|
|<span class="nerdfont big">&#xe213;</span>|fae_walking|
|<span class="nerdfont big">&#xe25e;</span>|fae_wallet|
|<span class="nerdfont big">&#xe27e;</span>|fae_wind|
|<span class="nerdfont big">&#xe29d;</span>|fae_xbox|
|<span class="nerdfont big">&#x23fb;</span>|iec_power|
|<span class="nerdfont big">&#x2b58;</span>|iec_power_off|
|<span class="nerdfont big">&#x23fd;</span>|iec_power_on|
|<span class="nerdfont big">&#x23fe;</span>|iec_sleep_mode|
|<span class="nerdfont big">&#x23fc;</span>|iec_toggle_power|
|<span class="nerdfont big">&#xe621;</span>|indent_line|
|<span class="nerdfont big">&#xf31d;</span>|linux_almalinux|
|<span class="nerdfont big">&#xf300;</span>|linux_alpine|
|<span class="nerdfont big">&#xf301;</span>|linux_aosc|
|<span class="nerdfont big">&#xf302;</span>|linux_apple|
|<span class="nerdfont big">&#xf31e;</span>|linux_archlabs|
|<span class="nerdfont big">&#xf303;</span>|linux_archlinux|
|<span class="nerdfont big">&#xf31f;</span>|linux_artix|
|<span class="nerdfont big">&#xf320;</span>|linux_budgie|
|<span class="nerdfont big">&#xf304;</span>|linux_centos|
|<span class="nerdfont big">&#xf305;</span>|linux_coreos|
|<span class="nerdfont big">&#xf306;</span>|linux_debian|
|<span class="nerdfont big">&#xf321;</span>|linux_deepin|
|<span class="nerdfont big">&#xf307;</span>|linux_devuan|
|<span class="nerdfont big">&#xf308;</span>|linux_docker|
|<span class="nerdfont big">&#xf309;</span>|linux_elementary|
|<span class="nerdfont big">&#xf322;</span>|linux_endeavour|
|<span class="nerdfont big">&#xf30a;</span>|linux_fedora|
|<span class="nerdfont big">&#xf30b;</span>|linux_fedora_inverse|
|<span class="nerdfont big">&#xf323;</span>|linux_ferris|
|<span class="nerdfont big">&#xf324;</span>|linux_flathub|
|<span class="nerdfont big">&#xf30c;</span>|linux_freebsd|
|<span class="nerdfont big">&#xf30d;</span>|linux_gentoo|
|<span class="nerdfont big">&#xf325;</span>|linux_gnu_guix|
|<span class="nerdfont big">&#xf326;</span>|linux_illumos|
|<span class="nerdfont big">&#xf327;</span>|linux_kali_linux|
|<span class="nerdfont big">&#xf30e;</span>|linux_linuxmint|
|<span class="nerdfont big">&#xf30f;</span>|linux_linuxmint_inverse|
|<span class="nerdfont big">&#xf310;</span>|linux_mageia|
|<span class="nerdfont big">&#xf311;</span>|linux_mandriva|
|<span class="nerdfont big">&#xf312;</span>|linux_manjaro|
|<span class="nerdfont big">&#xf313;</span>|linux_nixos|
|<span class="nerdfont big">&#xf328;</span>|linux_openbsd|
|<span class="nerdfont big">&#xf314;</span>|linux_opensuse|
|<span class="nerdfont big">&#xf329;</span>|linux_parrot|
|<span class="nerdfont big">&#xf32a;</span>|linux_pop_os|
|<span class="nerdfont big">&#xf315;</span>|linux_raspberry_pi|
|<span class="nerdfont big">&#xf316;</span>|linux_redhat|
|<span class="nerdfont big">&#xf32b;</span>|linux_rocky_linux|
|<span class="nerdfont big">&#xf317;</span>|linux_sabayon|
|<span class="nerdfont big">&#xf318;</span>|linux_slackware|
|<span class="nerdfont big">&#xf319;</span>|linux_slackware_inverse|
|<span class="nerdfont big">&#xf32c;</span>|linux_snappy|
|<span class="nerdfont big">&#xf32d;</span>|linux_solus|
|<span class="nerdfont big">&#xf31a;</span>|linux_tux|
|<span class="nerdfont big">&#xf31b;</span>|linux_ubuntu|
|<span class="nerdfont big">&#xf31c;</span>|linux_ubuntu_inverse|
|<span class="nerdfont big">&#xf32e;</span>|linux_void|
|<span class="nerdfont big">&#xf32f;</span>|linux_zorin|
|<span class="nerdfont big">&#xf501;</span>|mdi_access_point|
|<span class="nerdfont big">&#xf502;</span>|mdi_access_point_network|
|<span class="nerdfont big">&#xf503;</span>|mdi_account|
|<span class="nerdfont big">&#xf504;</span>|mdi_account_alert|
|<span class="nerdfont big">&#xf505;</span>|mdi_account_box|
|<span class="nerdfont big">&#xf506;</span>|mdi_account_box_outline|
|<span class="nerdfont big">&#xfad1;</span>|mdi_account_card_details|
|<span class="nerdfont big">&#xf507;</span>|mdi_account_check|
|<span class="nerdfont big">&#xf508;</span>|mdi_account_circle|
|<span class="nerdfont big">&#xf509;</span>|mdi_account_convert|
|<span class="nerdfont big">&#xfbba;</span>|mdi_account_edit|
|<span class="nerdfont big">&#xf50a;</span>|mdi_account_key|
|<span class="nerdfont big">&#xf50b;</span>|mdi_account_location|
|<span class="nerdfont big">&#xf50c;</span>|mdi_account_minus|
|<span class="nerdfont big">&#xf50d;</span>|mdi_account_multiple|
|<span class="nerdfont big">&#xfad2;</span>|mdi_account_multiple_minus|
|<span class="nerdfont big">&#xf50e;</span>|mdi_account_multiple_outline|
|<span class="nerdfont big">&#xf50f;</span>|mdi_account_multiple_plus|
|<span class="nerdfont big">&#xfcfe;</span>|mdi_account_multiple_plus_outline|
|<span class="nerdfont big">&#xf510;</span>|mdi_account_network|
|<span class="nerdfont big">&#xf511;</span>|mdi_account_off|
|<span class="nerdfont big">&#xf512;</span>|mdi_account_outline|
|<span class="nerdfont big">&#xf513;</span>|mdi_account_plus|
|<span class="nerdfont big">&#xfcff;</span>|mdi_account_plus_outline|
|<span class="nerdfont big">&#xf514;</span>|mdi_account_remove|
|<span class="nerdfont big">&#xf515;</span>|mdi_account_search|
|<span class="nerdfont big">&#xfb2f;</span>|mdi_account_settings|
|<span class="nerdfont big">&#xfb30;</span>|mdi_account_settings_variant|
|<span class="nerdfont big">&#xf516;</span>|mdi_account_star|
|<span class="nerdfont big">&#xf518;</span>|mdi_account_switch|
|<span class="nerdfont big">&#xf519;</span>|mdi_adjust|
|<span class="nerdfont big">&#xf51a;</span>|mdi_air_conditioner|
|<span class="nerdfont big">&#xf51b;</span>|mdi_airballoon|
|<span class="nerdfont big">&#xf51c;</span>|mdi_airplane|
|<span class="nerdfont big">&#xfad3;</span>|mdi_airplane_landing|
|<span class="nerdfont big">&#xf51d;</span>|mdi_airplane_off|
|<span class="nerdfont big">&#xfad4;</span>|mdi_airplane_takeoff|
|<span class="nerdfont big">&#xf51e;</span>|mdi_airplay|
|<span class="nerdfont big">&#xf51f;</span>|mdi_alarm|
|<span class="nerdfont big">&#xfc8c;</span>|mdi_alarm_bell|
|<span class="nerdfont big">&#xf520;</span>|mdi_alarm_check|
|<span class="nerdfont big">&#xfc8d;</span>|mdi_alarm_light|
|<span class="nerdfont big">&#xf521;</span>|mdi_alarm_multiple|
|<span class="nerdfont big">&#xf522;</span>|mdi_alarm_off|
|<span class="nerdfont big">&#xf523;</span>|mdi_alarm_plus|
|<span class="nerdfont big">&#xfb8c;</span>|mdi_alarm_snooze|
|<span class="nerdfont big">&#xf524;</span>|mdi_album|
|<span class="nerdfont big">&#xf525;</span>|mdi_alert|
|<span class="nerdfont big">&#xf526;</span>|mdi_alert_box|
|<span class="nerdfont big">&#xf527;</span>|mdi_alert_circle|
|<span class="nerdfont big">&#xfad5;</span>|mdi_alert_circle_outline|
|<span class="nerdfont big">&#xfbbb;</span>|mdi_alert_decagram|
|<span class="nerdfont big">&#xf528;</span>|mdi_alert_octagon|
|<span class="nerdfont big">&#xfc65;</span>|mdi_alert_octagram|
|<span class="nerdfont big">&#xf529;</span>|mdi_alert_outline|
|<span class="nerdfont big">&#xfbbc;</span>|mdi_all_inclusive|
|<span class="nerdfont big">&#xfd00;</span>|mdi_allo|
|<span class="nerdfont big">&#xf52a;</span>|mdi_alpha|
|<span class="nerdfont big">&#xf52b;</span>|mdi_alphabetical|
|<span class="nerdfont big">&#xfad6;</span>|mdi_altimeter|
|<span class="nerdfont big">&#xf52c;</span>|mdi_amazon|
|<span class="nerdfont big">&#xf52d;</span>|mdi_amazon_clouddrive|
|<span class="nerdfont big">&#xf52e;</span>|mdi_ambulance|
|<span class="nerdfont big">&#xf52f;</span>|mdi_amplifier|
|<span class="nerdfont big">&#xf530;</span>|mdi_anchor|
|<span class="nerdfont big">&#xf531;</span>|mdi_android|
|<span class="nerdfont big">&#xf532;</span>|mdi_android_debug_bridge|
|<span class="nerdfont big">&#xfc8e;</span>|mdi_android_head|
|<span class="nerdfont big">&#xf533;</span>|mdi_android_studio|
|<span class="nerdfont big">&#xfbb0;</span>|mdi_angular|
|<span class="nerdfont big">&#xfbbd;</span>|mdi_angularjs|
|<span class="nerdfont big">&#xfad7;</span>|mdi_animation|
|<span class="nerdfont big">&#xf534;</span>|mdi_apple|
|<span class="nerdfont big">&#xf535;</span>|mdi_apple_finder|
|<span class="nerdfont big">&#xf536;</span>|mdi_apple_ios|
|<span class="nerdfont big">&#xfb31;</span>|mdi_apple_keyboard_caps|
|<span class="nerdfont big">&#xfb32;</span>|mdi_apple_keyboard_command|
|<span class="nerdfont big">&#xfb33;</span>|mdi_apple_keyboard_control|
|<span class="nerdfont big">&#xfb34;</span>|mdi_apple_keyboard_option|
|<span class="nerdfont big">&#xfb35;</span>|mdi_apple_keyboard_shift|
|<span class="nerdfont big">&#xf537;</span>|mdi_apple_mobileme|
|<span class="nerdfont big">&#xf538;</span>|mdi_apple_safari|
|<span class="nerdfont big">&#xfb13;</span>|mdi_application|
|<span class="nerdfont big">&#xfc8f;</span>|mdi_approval|
|<span class="nerdfont big">&#xf53a;</span>|mdi_apps|
|<span class="nerdfont big">&#xf53b;</span>|mdi_archive|
|<span class="nerdfont big">&#xf53c;</span>|mdi_arrange_bring_forward|
|<span class="nerdfont big">&#xf53d;</span>|mdi_arrange_bring_to_front|
|<span class="nerdfont big">&#xf53e;</span>|mdi_arrange_send_backward|
|<span class="nerdfont big">&#xf53f;</span>|mdi_arrange_send_to_back|
|<span class="nerdfont big">&#xf540;</span>|mdi_arrow_all|
|<span class="nerdfont big">&#xf541;</span>|mdi_arrow_bottom_left|
|<span class="nerdfont big">&#xf542;</span>|mdi_arrow_bottom_right|
|<span class="nerdfont big">&#xfb14;</span>|mdi_arrow_collapse|
|<span class="nerdfont big">&#xf543;</span>|mdi_arrow_collapse_all|
|<span class="nerdfont big">&#xfc90;</span>|mdi_arrow_collapse_down|
|<span class="nerdfont big">&#xfc91;</span>|mdi_arrow_collapse_left|
|<span class="nerdfont big">&#xfc92;</span>|mdi_arrow_collapse_right|
|<span class="nerdfont big">&#xfc93;</span>|mdi_arrow_collapse_up|
|<span class="nerdfont big">&#xf544;</span>|mdi_arrow_down|
|<span class="nerdfont big">&#xfc2c;</span>|mdi_arrow_down_bold|
|<span class="nerdfont big">&#xfc2d;</span>|mdi_arrow_down_bold_box|
|<span class="nerdfont big">&#xfc2e;</span>|mdi_arrow_down_bold_box_outline|
|<span class="nerdfont big">&#xf546;</span>|mdi_arrow_down_bold_circle|
|<span class="nerdfont big">&#xf547;</span>|mdi_arrow_down_bold_circle_outline|
|<span class="nerdfont big">&#xf548;</span>|mdi_arrow_down_bold_hexagon_outline|
|<span class="nerdfont big">&#xfbbe;</span>|mdi_arrow_down_box|
|<span class="nerdfont big">&#xf549;</span>|mdi_arrow_down_drop_circle|
|<span class="nerdfont big">&#xf54a;</span>|mdi_arrow_down_drop_circle_outline|
|<span class="nerdfont big">&#xf545;</span>|mdi_arrow_down_thick|
|<span class="nerdfont big">&#xfb15;</span>|mdi_arrow_expand|
|<span class="nerdfont big">&#xf54b;</span>|mdi_arrow_expand_all|
|<span class="nerdfont big">&#xfc94;</span>|mdi_arrow_expand_down|
|<span class="nerdfont big">&#xfc95;</span>|mdi_arrow_expand_left|
|<span class="nerdfont big">&#xfc96;</span>|mdi_arrow_expand_right|
|<span class="nerdfont big">&#xfc97;</span>|mdi_arrow_expand_up|
|<span class="nerdfont big">&#xf54c;</span>|mdi_arrow_left|
|<span class="nerdfont big">&#xfc2f;</span>|mdi_arrow_left_bold|
|<span class="nerdfont big">&#xfc30;</span>|mdi_arrow_left_bold_box|
|<span class="nerdfont big">&#xfc31;</span>|mdi_arrow_left_bold_box_outline|
|<span class="nerdfont big">&#xf54e;</span>|mdi_arrow_left_bold_circle|
|<span class="nerdfont big">&#xf54f;</span>|mdi_arrow_left_bold_circle_outline|
|<span class="nerdfont big">&#xf550;</span>|mdi_arrow_left_bold_hexagon_outline|
|<span class="nerdfont big">&#xfbbf;</span>|mdi_arrow_left_box|
|<span class="nerdfont big">&#xf551;</span>|mdi_arrow_left_drop_circle|
|<span class="nerdfont big">&#xf552;</span>|mdi_arrow_left_drop_circle_outline|
|<span class="nerdfont big">&#xf54d;</span>|mdi_arrow_left_thick|
|<span class="nerdfont big">&#xf553;</span>|mdi_arrow_right|
|<span class="nerdfont big">&#xfc32;</span>|mdi_arrow_right_bold|
|<span class="nerdfont big">&#xfc33;</span>|mdi_arrow_right_bold_box|
|<span class="nerdfont big">&#xfc34;</span>|mdi_arrow_right_bold_box_outline|
|<span class="nerdfont big">&#xf555;</span>|mdi_arrow_right_bold_circle|
|<span class="nerdfont big">&#xf556;</span>|mdi_arrow_right_bold_circle_outline|
|<span class="nerdfont big">&#xf557;</span>|mdi_arrow_right_bold_hexagon_outline|
|<span class="nerdfont big">&#xfbc0;</span>|mdi_arrow_right_box|
|<span class="nerdfont big">&#xf558;</span>|mdi_arrow_right_drop_circle|
|<span class="nerdfont big">&#xf559;</span>|mdi_arrow_right_drop_circle_outline|
|<span class="nerdfont big">&#xf554;</span>|mdi_arrow_right_thick|
|<span class="nerdfont big">&#xf55a;</span>|mdi_arrow_top_left|
|<span class="nerdfont big">&#xf55b;</span>|mdi_arrow_top_right|
|<span class="nerdfont big">&#xf55c;</span>|mdi_arrow_up|
|<span class="nerdfont big">&#xfc35;</span>|mdi_arrow_up_bold|
|<span class="nerdfont big">&#xfc36;</span>|mdi_arrow_up_bold_box|
|<span class="nerdfont big">&#xfc37;</span>|mdi_arrow_up_bold_box_outline|
|<span class="nerdfont big">&#xf55e;</span>|mdi_arrow_up_bold_circle|
|<span class="nerdfont big">&#xf55f;</span>|mdi_arrow_up_bold_circle_outline|
|<span class="nerdfont big">&#xf560;</span>|mdi_arrow_up_bold_hexagon_outline|
|<span class="nerdfont big">&#xfbc1;</span>|mdi_arrow_up_box|
|<span class="nerdfont big">&#xf561;</span>|mdi_arrow_up_drop_circle|
|<span class="nerdfont big">&#xf562;</span>|mdi_arrow_up_drop_circle_outline|
|<span class="nerdfont big">&#xf55d;</span>|mdi_arrow_up_thick|
|<span class="nerdfont big">&#xfd01;</span>|mdi_artist|
|<span class="nerdfont big">&#xf563;</span>|mdi_assistant|
|<span class="nerdfont big">&#xfbc2;</span>|mdi_asterisk|
|<span class="nerdfont big">&#xf564;</span>|mdi_at|
|<span class="nerdfont big">&#xfd02;</span>|mdi_atlassian|
|<span class="nerdfont big">&#xfc66;</span>|mdi_atom|
|<span class="nerdfont big">&#xf565;</span>|mdi_attachment|
|<span class="nerdfont big">&#xf566;</span>|mdi_audiobook|
|<span class="nerdfont big">&#xf567;</span>|mdi_auto_fix|
|<span class="nerdfont big">&#xf568;</span>|mdi_auto_upload|
|<span class="nerdfont big">&#xf569;</span>|mdi_autorenew|
|<span class="nerdfont big">&#xf56a;</span>|mdi_av_timer|
|<span class="nerdfont big">&#xfd03;</span>|mdi_azure|
|<span class="nerdfont big">&#xf56b;</span>|mdi_baby|
|<span class="nerdfont big">&#xfb8d;</span>|mdi_baby_buggy|
|<span class="nerdfont big">&#xf56c;</span>|mdi_backburger|
|<span class="nerdfont big">&#xf56d;</span>|mdi_backspace|
|<span class="nerdfont big">&#xf56e;</span>|mdi_backup_restore|
|<span class="nerdfont big">&#xfb73;</span>|mdi_bandcamp|
|<span class="nerdfont big">&#xf56f;</span>|mdi_bank|
|<span class="nerdfont big">&#xf570;</span>|mdi_barcode|
|<span class="nerdfont big">&#xf571;</span>|mdi_barcode_scan|
|<span class="nerdfont big">&#xf572;</span>|mdi_barley|
|<span class="nerdfont big">&#xf573;</span>|mdi_barrel|
|<span class="nerdfont big">&#xf574;</span>|mdi_basecamp|
|<span class="nerdfont big">&#xf575;</span>|mdi_basket|
|<span class="nerdfont big">&#xf576;</span>|mdi_basket_fill|
|<span class="nerdfont big">&#xf577;</span>|mdi_basket_unfill|
|<span class="nerdfont big">&#xfd04;</span>|mdi_basketball|
|<span class="nerdfont big">&#xf578;</span>|mdi_battery|
|<span class="nerdfont big">&#xf579;</span>|mdi_battery_10|
|<span class="nerdfont big">&#xf57a;</span>|mdi_battery_20|
|<span class="nerdfont big">&#xf57b;</span>|mdi_battery_30|
|<span class="nerdfont big">&#xf57c;</span>|mdi_battery_40|
|<span class="nerdfont big">&#xf57d;</span>|mdi_battery_50|
|<span class="nerdfont big">&#xf57e;</span>|mdi_battery_60|
|<span class="nerdfont big">&#xf57f;</span>|mdi_battery_70|
|<span class="nerdfont big">&#xf580;</span>|mdi_battery_80|
|<span class="nerdfont big">&#xf581;</span>|mdi_battery_90|
|<span class="nerdfont big">&#xf582;</span>|mdi_battery_alert|
|<span class="nerdfont big">&#xf583;</span>|mdi_battery_charging|
|<span class="nerdfont big">&#xf585;</span>|mdi_battery_charging_20|
|<span class="nerdfont big">&#xf586;</span>|mdi_battery_charging_30|
|<span class="nerdfont big">&#xf587;</span>|mdi_battery_charging_40|
|<span class="nerdfont big">&#xf588;</span>|mdi_battery_charging_60|
|<span class="nerdfont big">&#xf589;</span>|mdi_battery_charging_80|
|<span class="nerdfont big">&#xf58a;</span>|mdi_battery_charging_90|
|<span class="nerdfont big">&#xf584;</span>|mdi_battery_charging_100|
|<span class="nerdfont big">&#xfd05;</span>|mdi_battery_charging_wireless|
|<span class="nerdfont big">&#xfd06;</span>|mdi_battery_charging_wireless_10|
|<span class="nerdfont big">&#xfd07;</span>|mdi_battery_charging_wireless_20|
|<span class="nerdfont big">&#xfd08;</span>|mdi_battery_charging_wireless_30|
|<span class="nerdfont big">&#xfd09;</span>|mdi_battery_charging_wireless_40|
|<span class="nerdfont big">&#xfd0a;</span>|mdi_battery_charging_wireless_50|
|<span class="nerdfont big">&#xfd0b;</span>|mdi_battery_charging_wireless_60|
|<span class="nerdfont big">&#xfd0c;</span>|mdi_battery_charging_wireless_70|
|<span class="nerdfont big">&#xfd0d;</span>|mdi_battery_charging_wireless_80|
|<span class="nerdfont big">&#xfd0e;</span>|mdi_battery_charging_wireless_90|
|<span class="nerdfont big">&#xfd0f;</span>|mdi_battery_charging_wireless_alert|
|<span class="nerdfont big">&#xfd10;</span>|mdi_battery_charging_wireless_outline|
|<span class="nerdfont big">&#xf58b;</span>|mdi_battery_minus|
|<span class="nerdfont big">&#xf58c;</span>|mdi_battery_negative|
|<span class="nerdfont big">&#xf58d;</span>|mdi_battery_outline|
|<span class="nerdfont big">&#xf58e;</span>|mdi_battery_plus|
|<span class="nerdfont big">&#xf58f;</span>|mdi_battery_positive|
|<span class="nerdfont big">&#xf590;</span>|mdi_battery_unknown|
|<span class="nerdfont big">&#xf591;</span>|mdi_beach|
|<span class="nerdfont big">&#xfb8e;</span>|mdi_beaker|
|<span class="nerdfont big">&#xf596;</span>|mdi_beats|
|<span class="nerdfont big">&#xf597;</span>|mdi_beer|
|<span class="nerdfont big">&#xf598;</span>|mdi_behance|
|<span class="nerdfont big">&#xf599;</span>|mdi_bell|
|<span class="nerdfont big">&#xf59a;</span>|mdi_bell_off|
|<span class="nerdfont big">&#xf59b;</span>|mdi_bell_outline|
|<span class="nerdfont big">&#xf59c;</span>|mdi_bell_plus|
|<span class="nerdfont big">&#xf59d;</span>|mdi_bell_ring|
|<span class="nerdfont big">&#xf59e;</span>|mdi_bell_ring_outline|
|<span class="nerdfont big">&#xf59f;</span>|mdi_bell_sleep|
|<span class="nerdfont big">&#xf5a0;</span>|mdi_beta|
|<span class="nerdfont big">&#xf5a1;</span>|mdi_bible|
|<span class="nerdfont big">&#xf5a2;</span>|mdi_bike|
|<span class="nerdfont big">&#xf5a3;</span>|mdi_bing|
|<span class="nerdfont big">&#xf5a4;</span>|mdi_binoculars|
|<span class="nerdfont big">&#xf5a5;</span>|mdi_bio|
|<span class="nerdfont big">&#xf5a6;</span>|mdi_biohazard|
|<span class="nerdfont big">&#xf5a7;</span>|mdi_bitbucket|
|<span class="nerdfont big">&#xfd11;</span>|mdi_bitcoin|
|<span class="nerdfont big">&#xf5a8;</span>|mdi_black_mesa|
|<span class="nerdfont big">&#xf5a9;</span>|mdi_blackberry|
|<span class="nerdfont big">&#xf5aa;</span>|mdi_blender|
|<span class="nerdfont big">&#xf5ab;</span>|mdi_blinds|
|<span class="nerdfont big">&#xf5ac;</span>|mdi_block_helper|
|<span class="nerdfont big">&#xf5ad;</span>|mdi_blogger|
|<span class="nerdfont big">&#xf5ae;</span>|mdi_bluetooth|
|<span class="nerdfont big">&#xf5af;</span>|mdi_bluetooth_audio|
|<span class="nerdfont big">&#xf5b0;</span>|mdi_bluetooth_connect|
|<span class="nerdfont big">&#xf5b1;</span>|mdi_bluetooth_off|
|<span class="nerdfont big">&#xf5b2;</span>|mdi_bluetooth_settings|
|<span class="nerdfont big">&#xf5b3;</span>|mdi_bluetooth_transfer|
|<span class="nerdfont big">&#xf5b4;</span>|mdi_blur|
|<span class="nerdfont big">&#xf5b5;</span>|mdi_blur_linear|
|<span class="nerdfont big">&#xf5b6;</span>|mdi_blur_off|
|<span class="nerdfont big">&#xf5b7;</span>|mdi_blur_radial|
|<span class="nerdfont big">&#xfb8f;</span>|mdi_bomb|
|<span class="nerdfont big">&#xfbc3;</span>|mdi_bomb_off|
|<span class="nerdfont big">&#xf5b8;</span>|mdi_bone|
|<span class="nerdfont big">&#xf5b9;</span>|mdi_book|
|<span class="nerdfont big">&#xfad8;</span>|mdi_book_minus|
|<span class="nerdfont big">&#xf5ba;</span>|mdi_book_multiple|
|<span class="nerdfont big">&#xf5bb;</span>|mdi_book_multiple_variant|
|<span class="nerdfont big">&#xf5bc;</span>|mdi_book_open|
|<span class="nerdfont big">&#xfad9;</span>|mdi_book_open_page_variant|
|<span class="nerdfont big">&#xf5bd;</span>|mdi_book_open_variant|
|<span class="nerdfont big">&#xfada;</span>|mdi_book_plus|
|<span class="nerdfont big">&#xfc98;</span>|mdi_book_secure|
|<span class="nerdfont big">&#xfc99;</span>|mdi_book_unsecure|
|<span class="nerdfont big">&#xf5be;</span>|mdi_book_variant|
|<span class="nerdfont big">&#xf5bf;</span>|mdi_bookmark|
|<span class="nerdfont big">&#xf5c0;</span>|mdi_bookmark_check|
|<span class="nerdfont big">&#xf5c1;</span>|mdi_bookmark_music|
|<span class="nerdfont big">&#xf5c2;</span>|mdi_bookmark_outline|
|<span class="nerdfont big">&#xf5c4;</span>|mdi_bookmark_plus|
|<span class="nerdfont big">&#xf5c3;</span>|mdi_bookmark_plus_outline|
|<span class="nerdfont big">&#xf5c5;</span>|mdi_bookmark_remove|
|<span class="nerdfont big">&#xfadb;</span>|mdi_boombox|
|<span class="nerdfont big">&#xfbc4;</span>|mdi_bootstrap|
|<span class="nerdfont big">&#xf5c6;</span>|mdi_border_all|
|<span class="nerdfont big">&#xf5c7;</span>|mdi_border_bottom|
|<span class="nerdfont big">&#xf5c8;</span>|mdi_border_color|
|<span class="nerdfont big">&#xf5c9;</span>|mdi_border_horizontal|
|<span class="nerdfont big">&#xf5ca;</span>|mdi_border_inside|
|<span class="nerdfont big">&#xf5cb;</span>|mdi_border_left|
|<span class="nerdfont big">&#xf5cc;</span>|mdi_border_none|
|<span class="nerdfont big">&#xf5cd;</span>|mdi_border_outside|
|<span class="nerdfont big">&#xf5ce;</span>|mdi_border_right|
|<span class="nerdfont big">&#xf5cf;</span>|mdi_border_style|
|<span class="nerdfont big">&#xf5d0;</span>|mdi_border_top|
|<span class="nerdfont big">&#xf5d1;</span>|mdi_border_vertical|
|<span class="nerdfont big">&#xfb76;</span>|mdi_bow_tie|
|<span class="nerdfont big">&#xfb16;</span>|mdi_bowl|
|<span class="nerdfont big">&#xf5d2;</span>|mdi_bowling|
|<span class="nerdfont big">&#xf5d3;</span>|mdi_box|
|<span class="nerdfont big">&#xf5d4;</span>|mdi_box_cutter|
|<span class="nerdfont big">&#xfb36;</span>|mdi_box_shadow|
|<span class="nerdfont big">&#xfb17;</span>|mdi_bridge|
|<span class="nerdfont big">&#xf5d5;</span>|mdi_briefcase|
|<span class="nerdfont big">&#xf5d6;</span>|mdi_briefcase_check|
|<span class="nerdfont big">&#xf5d7;</span>|mdi_briefcase_download|
|<span class="nerdfont big">&#xfd12;</span>|mdi_briefcase_outline|
|<span class="nerdfont big">&#xf5d8;</span>|mdi_briefcase_upload|
|<span class="nerdfont big">&#xf5d9;</span>|mdi_brightness_1|
|<span class="nerdfont big">&#xf5da;</span>|mdi_brightness_2|
|<span class="nerdfont big">&#xf5db;</span>|mdi_brightness_3|
|<span class="nerdfont big">&#xf5dc;</span>|mdi_brightness_4|
|<span class="nerdfont big">&#xf5dd;</span>|mdi_brightness_5|
|<span class="nerdfont big">&#xf5de;</span>|mdi_brightness_6|
|<span class="nerdfont big">&#xf5df;</span>|mdi_brightness_7|
|<span class="nerdfont big">&#xf5e0;</span>|mdi_brightness_auto|
|<span class="nerdfont big">&#xf5e1;</span>|mdi_broom|
|<span class="nerdfont big">&#xf5e2;</span>|mdi_brush|
|<span class="nerdfont big">&#xfb18;</span>|mdi_buffer|
|<span class="nerdfont big">&#xf5e3;</span>|mdi_bug|
|<span class="nerdfont big">&#xf5e4;</span>|mdi_bulletin_board|
|<span class="nerdfont big">&#xf5e5;</span>|mdi_bullhorn|
|<span class="nerdfont big">&#xfadc;</span>|mdi_bullseye|
|<span class="nerdfont big">&#xf5e6;</span>|mdi_bus|
|<span class="nerdfont big">&#xfc9a;</span>|mdi_bus_articulated_end|
|<span class="nerdfont big">&#xfc9b;</span>|mdi_bus_articulated_front|
|<span class="nerdfont big">&#xfc9c;</span>|mdi_bus_double_decker|
|<span class="nerdfont big">&#xfc9d;</span>|mdi_bus_school|
|<span class="nerdfont big">&#xfc9e;</span>|mdi_bus_side|
|<span class="nerdfont big">&#xf5e7;</span>|mdi_cached|
|<span class="nerdfont big">&#xf5e8;</span>|mdi_cake|
|<span class="nerdfont big">&#xf5e9;</span>|mdi_cake_layered|
|<span class="nerdfont big">&#xf5ea;</span>|mdi_cake_variant|
|<span class="nerdfont big">&#xf5eb;</span>|mdi_calculator|
|<span class="nerdfont big">&#xf5ec;</span>|mdi_calendar|
|<span class="nerdfont big">&#xf5ed;</span>|mdi_calendar_blank|
|<span class="nerdfont big">&#xf5ee;</span>|mdi_calendar_check|
|<span class="nerdfont big">&#xf5ef;</span>|mdi_calendar_clock|
|<span class="nerdfont big">&#xf5f0;</span>|mdi_calendar_multiple|
|<span class="nerdfont big">&#xf5f1;</span>|mdi_calendar_multiple_check|
|<span class="nerdfont big">&#xf5f2;</span>|mdi_calendar_plus|
|<span class="nerdfont big">&#xfb90;</span>|mdi_calendar_question|
|<span class="nerdfont big">&#xfb77;</span>|mdi_calendar_range|
|<span class="nerdfont big">&#xf5f3;</span>|mdi_calendar_remove|
|<span class="nerdfont big">&#xf5f4;</span>|mdi_calendar_text|
|<span class="nerdfont big">&#xf5f5;</span>|mdi_calendar_today|
|<span class="nerdfont big">&#xf5f6;</span>|mdi_call_made|
|<span class="nerdfont big">&#xf5f7;</span>|mdi_call_merge|
|<span class="nerdfont big">&#xf5f8;</span>|mdi_call_missed|
|<span class="nerdfont big">&#xf5f9;</span>|mdi_call_received|
|<span class="nerdfont big">&#xf5fa;</span>|mdi_call_split|
|<span class="nerdfont big">&#xf5fb;</span>|mdi_camcorder|
|<span class="nerdfont big">&#xf5fc;</span>|mdi_camcorder_box|
|<span class="nerdfont big">&#xf5fd;</span>|mdi_camcorder_box_off|
|<span class="nerdfont big">&#xf5fe;</span>|mdi_camcorder_off|
|<span class="nerdfont big">&#xf5ff;</span>|mdi_camera|
|<span class="nerdfont big">&#xfb91;</span>|mdi_camera_burst|
|<span class="nerdfont big">&#xf600;</span>|mdi_camera_enhance|
|<span class="nerdfont big">&#xf601;</span>|mdi_camera_front|
|<span class="nerdfont big">&#xf602;</span>|mdi_camera_front_variant|
|<span class="nerdfont big">&#xfc9f;</span>|mdi_camera_gopro|
|<span class="nerdfont big">&#xf603;</span>|mdi_camera_iris|
|<span class="nerdfont big">&#xfca0;</span>|mdi_camera_metering_center|
|<span class="nerdfont big">&#xfca1;</span>|mdi_camera_metering_matrix|
|<span class="nerdfont big">&#xfca2;</span>|mdi_camera_metering_partial|
|<span class="nerdfont big">&#xfca3;</span>|mdi_camera_metering_spot|
|<span class="nerdfont big">&#xfade;</span>|mdi_camera_off|
|<span class="nerdfont big">&#xf604;</span>|mdi_camera_party_mode|
|<span class="nerdfont big">&#xf605;</span>|mdi_camera_rear|
|<span class="nerdfont big">&#xf606;</span>|mdi_camera_rear_variant|
|<span class="nerdfont big">&#xf607;</span>|mdi_camera_switch|
|<span class="nerdfont big">&#xf608;</span>|mdi_camera_timer|
|<span class="nerdfont big">&#xfc38;</span>|mdi_cancel|
|<span class="nerdfont big">&#xfae1;</span>|mdi_candle|
|<span class="nerdfont big">&#xf609;</span>|mdi_candycane|
|<span class="nerdfont big">&#xfca4;</span>|mdi_cannabis|
|<span class="nerdfont big">&#xf60a;</span>|mdi_car|
|<span class="nerdfont big">&#xf60b;</span>|mdi_car_battery|
|<span class="nerdfont big">&#xf60c;</span>|mdi_car_connected|
|<span class="nerdfont big">&#xfca5;</span>|mdi_car_convertible|
|<span class="nerdfont big">&#xfca6;</span>|mdi_car_estate|
|<span class="nerdfont big">&#xfca7;</span>|mdi_car_hatchback|
|<span class="nerdfont big">&#xfca8;</span>|mdi_car_pickup|
|<span class="nerdfont big">&#xfca9;</span>|mdi_car_side|
|<span class="nerdfont big">&#xfcaa;</span>|mdi_car_sports|
|<span class="nerdfont big">&#xf60d;</span>|mdi_car_wash|
|<span class="nerdfont big">&#xfcab;</span>|mdi_caravan|
|<span class="nerdfont big">&#xfb37;</span>|mdi_cards|
|<span class="nerdfont big">&#xfb38;</span>|mdi_cards_outline|
|<span class="nerdfont big">&#xfb39;</span>|mdi_cards_playing_outline|
|<span class="nerdfont big">&#xfbc5;</span>|mdi_cards_variant|
|<span class="nerdfont big">&#xf60e;</span>|mdi_carrot|
|<span class="nerdfont big">&#xf60f;</span>|mdi_cart|
|<span class="nerdfont big">&#xfb6a;</span>|mdi_cart_off|
|<span class="nerdfont big">&#xf610;</span>|mdi_cart_outline|
|<span class="nerdfont big">&#xf611;</span>|mdi_cart_plus|
|<span class="nerdfont big">&#xf612;</span>|mdi_case_sensitive_alt|
|<span class="nerdfont big">&#xf613;</span>|mdi_cash|
|<span class="nerdfont big">&#xf614;</span>|mdi_cash_100|
|<span class="nerdfont big">&#xf615;</span>|mdi_cash_multiple|
|<span class="nerdfont big">&#xf616;</span>|mdi_cash_usd|
|<span class="nerdfont big">&#xf617;</span>|mdi_cast|
|<span class="nerdfont big">&#xf618;</span>|mdi_cast_connected|
|<span class="nerdfont big">&#xfc88;</span>|mdi_cast_off|
|<span class="nerdfont big">&#xf619;</span>|mdi_castle|
|<span class="nerdfont big">&#xf61a;</span>|mdi_cat|
|<span class="nerdfont big">&#xfcac;</span>|mdi_cctv|
|<span class="nerdfont big">&#xfc67;</span>|mdi_ceiling_light|
|<span class="nerdfont big">&#xf61b;</span>|mdi_cellphone|
|<span class="nerdfont big">&#xf61c;</span>|mdi_cellphone_android|
|<span class="nerdfont big">&#xf61d;</span>|mdi_cellphone_basic|
|<span class="nerdfont big">&#xf61e;</span>|mdi_cellphone_dock|
|<span class="nerdfont big">&#xf61f;</span>|mdi_cellphone_iphone|
|<span class="nerdfont big">&#xf620;</span>|mdi_cellphone_link|
|<span class="nerdfont big">&#xf621;</span>|mdi_cellphone_link_off|
|<span class="nerdfont big">&#xf622;</span>|mdi_cellphone_settings|
|<span class="nerdfont big">&#xfd13;</span>|mdi_cellphone_wireless|
|<span class="nerdfont big">&#xf623;</span>|mdi_certificate|
|<span class="nerdfont big">&#xf624;</span>|mdi_chair_school|
|<span class="nerdfont big">&#xf625;</span>|mdi_chart_arc|
|<span class="nerdfont big">&#xf626;</span>|mdi_chart_areaspline|
|<span class="nerdfont big">&#xf627;</span>|mdi_chart_bar|
|<span class="nerdfont big">&#xfc68;</span>|mdi_chart_bar_stacked|
|<span class="nerdfont big">&#xfae2;</span>|mdi_chart_bubble|
|<span class="nerdfont big">&#xfcad;</span>|mdi_chart_donut|
|<span class="nerdfont big">&#xfcae;</span>|mdi_chart_donut_variant|
|<span class="nerdfont big">&#xfb6b;</span>|mdi_chart_gantt|
|<span class="nerdfont big">&#xf628;</span>|mdi_chart_histogram|
|<span class="nerdfont big">&#xf629;</span>|mdi_chart_line|
|<span class="nerdfont big">&#xfc69;</span>|mdi_chart_line_stacked|
|<span class="nerdfont big">&#xfcaf;</span>|mdi_chart_line_variant|
|<span class="nerdfont big">&#xf62a;</span>|mdi_chart_pie|
|<span class="nerdfont big">&#xfb6c;</span>|mdi_chart_scatterplot_hexbin|
|<span class="nerdfont big">&#xfb6d;</span>|mdi_chart_timeline|
|<span class="nerdfont big">&#xf62b;</span>|mdi_check|
|<span class="nerdfont big">&#xf62c;</span>|mdi_check_all|
|<span class="nerdfont big">&#xfadf;</span>|mdi_check_circle|
|<span class="nerdfont big">&#xfae0;</span>|mdi_check_circle_outline|
|<span class="nerdfont big">&#xf62d;</span>|mdi_checkbox_blank|
|<span class="nerdfont big">&#xf62e;</span>|mdi_checkbox_blank_circle|
|<span class="nerdfont big">&#xf62f;</span>|mdi_checkbox_blank_circle_outline|
|<span class="nerdfont big">&#xf630;</span>|mdi_checkbox_blank_outline|
|<span class="nerdfont big">&#xf631;</span>|mdi_checkbox_marked|
|<span class="nerdfont big">&#xf632;</span>|mdi_checkbox_marked_circle|
|<span class="nerdfont big">&#xf633;</span>|mdi_checkbox_marked_circle_outline|
|<span class="nerdfont big">&#xf634;</span>|mdi_checkbox_marked_outline|
|<span class="nerdfont big">&#xf635;</span>|mdi_checkbox_multiple_blank|
|<span class="nerdfont big">&#xfb3a;</span>|mdi_checkbox_multiple_blank_circle|
|<span class="nerdfont big">&#xfb3b;</span>|mdi_checkbox_multiple_blank_circle_outline|
|<span class="nerdfont big">&#xf636;</span>|mdi_checkbox_multiple_blank_outline|
|<span class="nerdfont big">&#xf637;</span>|mdi_checkbox_multiple_marked|
|<span class="nerdfont big">&#xfb3c;</span>|mdi_checkbox_multiple_marked_circle|
|<span class="nerdfont big">&#xfb3d;</span>|mdi_checkbox_multiple_marked_circle_outline|
|<span class="nerdfont big">&#xf638;</span>|mdi_checkbox_multiple_marked_outline|
|<span class="nerdfont big">&#xf639;</span>|mdi_checkerboard|
|<span class="nerdfont big">&#xf63a;</span>|mdi_chemical_weapon|
|<span class="nerdfont big">&#xf63b;</span>|mdi_chevron_double_down|
|<span class="nerdfont big">&#xf63c;</span>|mdi_chevron_double_left|
|<span class="nerdfont big">&#xf63d;</span>|mdi_chevron_double_right|
|<span class="nerdfont big">&#xf63e;</span>|mdi_chevron_double_up|
|<span class="nerdfont big">&#xf63f;</span>|mdi_chevron_down|
|<span class="nerdfont big">&#xf640;</span>|mdi_chevron_left|
|<span class="nerdfont big">&#xf641;</span>|mdi_chevron_right|
|<span class="nerdfont big">&#xf642;</span>|mdi_chevron_up|
|<span class="nerdfont big">&#xfcb0;</span>|mdi_chili_hot|
|<span class="nerdfont big">&#xfcb1;</span>|mdi_chili_medium|
|<span class="nerdfont big">&#xfcb2;</span>|mdi_chili_mild|
|<span class="nerdfont big">&#xfb19;</span>|mdi_chip|
|<span class="nerdfont big">&#xf643;</span>|mdi_church|
|<span class="nerdfont big">&#xfc63;</span>|mdi_circle|
|<span class="nerdfont big">&#xfc64;</span>|mdi_circle_outline|
|<span class="nerdfont big">&#xf644;</span>|mdi_cisco_webex|
|<span class="nerdfont big">&#xf645;</span>|mdi_city|
|<span class="nerdfont big">&#xf646;</span>|mdi_clipboard|
|<span class="nerdfont big">&#xf647;</span>|mdi_clipboard_account|
|<span class="nerdfont big">&#xf648;</span>|mdi_clipboard_alert|
|<span class="nerdfont big">&#xf649;</span>|mdi_clipboard_arrow_down|
|<span class="nerdfont big">&#xf64a;</span>|mdi_clipboard_arrow_left|
|<span class="nerdfont big">&#xf64b;</span>|mdi_clipboard_check|
|<span class="nerdfont big">&#xfbc6;</span>|mdi_clipboard_flow|
|<span class="nerdfont big">&#xf64c;</span>|mdi_clipboard_outline|
|<span class="nerdfont big">&#xfc4f;</span>|mdi_clipboard_plus|
|<span class="nerdfont big">&#xf64d;</span>|mdi_clipboard_text|
|<span class="nerdfont big">&#xf64e;</span>|mdi_clippy|
|<span class="nerdfont big">&#xf64f;</span>|mdi_clock|
|<span class="nerdfont big">&#xfacd;</span>|mdi_clock_alert|
|<span class="nerdfont big">&#xf650;</span>|mdi_clock_end|
|<span class="nerdfont big">&#xf651;</span>|mdi_clock_fast|
|<span class="nerdfont big">&#xf652;</span>|mdi_clock_in|
|<span class="nerdfont big">&#xf653;</span>|mdi_clock_out|
|<span class="nerdfont big">&#xf654;</span>|mdi_clock_start|
|<span class="nerdfont big">&#xf655;</span>|mdi_close|
|<span class="nerdfont big">&#xf656;</span>|mdi_close_box|
|<span class="nerdfont big">&#xf657;</span>|mdi_close_box_outline|
|<span class="nerdfont big">&#xf658;</span>|mdi_close_circle|
|<span class="nerdfont big">&#xf659;</span>|mdi_close_circle_outline|
|<span class="nerdfont big">&#xf65a;</span>|mdi_close_network|
|<span class="nerdfont big">&#xf65b;</span>|mdi_close_octagon|
|<span class="nerdfont big">&#xf65c;</span>|mdi_close_octagon_outline|
|<span class="nerdfont big">&#xfbc7;</span>|mdi_close_outline|
|<span class="nerdfont big">&#xf65d;</span>|mdi_closed_caption|
|<span class="nerdfont big">&#xf65e;</span>|mdi_cloud|
|<span class="nerdfont big">&#xfcb3;</span>|mdi_cloud_braces|
|<span class="nerdfont big">&#xf65f;</span>|mdi_cloud_check|
|<span class="nerdfont big">&#xf660;</span>|mdi_cloud_circle|
|<span class="nerdfont big">&#xf661;</span>|mdi_cloud_download|
|<span class="nerdfont big">&#xf663;</span>|mdi_cloud_off_outline|
|<span class="nerdfont big">&#xf662;</span>|mdi_cloud_outline|
|<span class="nerdfont big">&#xf664;</span>|mdi_cloud_print|
|<span class="nerdfont big">&#xf665;</span>|mdi_cloud_print_outline|
|<span class="nerdfont big">&#xfb3e;</span>|mdi_cloud_sync|
|<span class="nerdfont big">&#xfcb4;</span>|mdi_cloud_tags|
|<span class="nerdfont big">&#xf666;</span>|mdi_cloud_upload|
|<span class="nerdfont big">&#xfd14;</span>|mdi_clover|
|<span class="nerdfont big">&#xf667;</span>|mdi_code_array|
|<span class="nerdfont big">&#xf668;</span>|mdi_code_braces|
|<span class="nerdfont big">&#xf669;</span>|mdi_code_brackets|
|<span class="nerdfont big">&#xf66a;</span>|mdi_code_equal|
|<span class="nerdfont big">&#xf66b;</span>|mdi_code_greater_than|
|<span class="nerdfont big">&#xf66c;</span>|mdi_code_greater_than_or_equal|
|<span class="nerdfont big">&#xf66d;</span>|mdi_code_less_than|
|<span class="nerdfont big">&#xf66e;</span>|mdi_code_less_than_or_equal|
|<span class="nerdfont big">&#xf66f;</span>|mdi_code_not_equal|
|<span class="nerdfont big">&#xf670;</span>|mdi_code_not_equal_variant|
|<span class="nerdfont big">&#xf671;</span>|mdi_code_parentheses|
|<span class="nerdfont big">&#xf672;</span>|mdi_code_string|
|<span class="nerdfont big">&#xf673;</span>|mdi_code_tags|
|<span class="nerdfont big">&#xfb92;</span>|mdi_code_tags_check|
|<span class="nerdfont big">&#xf674;</span>|mdi_codepen|
|<span class="nerdfont big">&#xf675;</span>|mdi_coffee|
|<span class="nerdfont big">&#xfbc8;</span>|mdi_coffee_outline|
|<span class="nerdfont big">&#xf676;</span>|mdi_coffee_to_go|
|<span class="nerdfont big">&#xf677;</span>|mdi_coin|
|<span class="nerdfont big">&#xfb93;</span>|mdi_coins|
|<span class="nerdfont big">&#xfb3f;</span>|mdi_collage|
|<span class="nerdfont big">&#xf678;</span>|mdi_color_helper|
|<span class="nerdfont big">&#xf679;</span>|mdi_comment|
|<span class="nerdfont big">&#xf67a;</span>|mdi_comment_account|
|<span class="nerdfont big">&#xf67b;</span>|mdi_comment_account_outline|
|<span class="nerdfont big">&#xf67c;</span>|mdi_comment_alert|
|<span class="nerdfont big">&#xf67d;</span>|mdi_comment_alert_outline|
|<span class="nerdfont big">&#xf67e;</span>|mdi_comment_check|
|<span class="nerdfont big">&#xf67f;</span>|mdi_comment_check_outline|
|<span class="nerdfont big">&#xf680;</span>|mdi_comment_multiple_outline|
|<span class="nerdfont big">&#xf681;</span>|mdi_comment_outline|
|<span class="nerdfont big">&#xf682;</span>|mdi_comment_plus_outline|
|<span class="nerdfont big">&#xf683;</span>|mdi_comment_processing|
|<span class="nerdfont big">&#xf684;</span>|mdi_comment_processing_outline|
|<span class="nerdfont big">&#xfd15;</span>|mdi_comment_question|
|<span class="nerdfont big">&#xf685;</span>|mdi_comment_question_outline|
|<span class="nerdfont big">&#xfadd;</span>|mdi_comment_remove|
|<span class="nerdfont big">&#xf686;</span>|mdi_comment_remove_outline|
|<span class="nerdfont big">&#xf687;</span>|mdi_comment_text|
|<span class="nerdfont big">&#xf688;</span>|mdi_comment_text_outline|
|<span class="nerdfont big">&#xf689;</span>|mdi_compare|
|<span class="nerdfont big">&#xf68a;</span>|mdi_compass|
|<span class="nerdfont big">&#xf68b;</span>|mdi_compass_outline|
|<span class="nerdfont big">&#xf68c;</span>|mdi_console|
|<span class="nerdfont big">&#xfcb5;</span>|mdi_console_line|
|<span class="nerdfont big">&#xf68d;</span>|mdi_contact_mail|
|<span class="nerdfont big">&#xfbc9;</span>|mdi_contacts|
|<span class="nerdfont big">&#xf68e;</span>|mdi_content_copy|
|<span class="nerdfont big">&#xf68f;</span>|mdi_content_cut|
|<span class="nerdfont big">&#xf690;</span>|mdi_content_duplicate|
|<span class="nerdfont big">&#xf691;</span>|mdi_content_paste|
|<span class="nerdfont big">&#xf692;</span>|mdi_content_save|
|<span class="nerdfont big">&#xf693;</span>|mdi_content_save_all|
|<span class="nerdfont big">&#xfd16;</span>|mdi_content_save_outline|
|<span class="nerdfont big">&#xfb1a;</span>|mdi_content_save_settings|
|<span class="nerdfont big">&#xf694;</span>|mdi_contrast|
|<span class="nerdfont big">&#xf695;</span>|mdi_contrast_box|
|<span class="nerdfont big">&#xf696;</span>|mdi_contrast_circle|
|<span class="nerdfont big">&#xf697;</span>|mdi_cookie|
|<span class="nerdfont big">&#xfae5;</span>|mdi_copyright|
|<span class="nerdfont big">&#xfcb6;</span>|mdi_corn|
|<span class="nerdfont big">&#xf698;</span>|mdi_counter|
|<span class="nerdfont big">&#xf699;</span>|mdi_cow|
|<span class="nerdfont big">&#xf6c8;</span>|mdi_creation|
|<span class="nerdfont big">&#xf69a;</span>|mdi_credit_card|
|<span class="nerdfont big">&#xf69b;</span>|mdi_credit_card_multiple|
|<span class="nerdfont big">&#xfae3;</span>|mdi_credit_card_off|
|<span class="nerdfont big">&#xfb74;</span>|mdi_credit_card_plus|
|<span class="nerdfont big">&#xf69c;</span>|mdi_credit_card_scan|
|<span class="nerdfont big">&#xf69d;</span>|mdi_crop|
|<span class="nerdfont big">&#xf69e;</span>|mdi_crop_free|
|<span class="nerdfont big">&#xf69f;</span>|mdi_crop_landscape|
|<span class="nerdfont big">&#xf6a0;</span>|mdi_crop_portrait|
|<span class="nerdfont big">&#xfb94;</span>|mdi_crop_rotate|
|<span class="nerdfont big">&#xf6a1;</span>|mdi_crop_square|
|<span class="nerdfont big">&#xf6a2;</span>|mdi_crosshairs|
|<span class="nerdfont big">&#xf6a3;</span>|mdi_crosshairs_gps|
|<span class="nerdfont big">&#xf6a4;</span>|mdi_crown|
|<span class="nerdfont big">&#xf6a5;</span>|mdi_cube|
|<span class="nerdfont big">&#xf6a6;</span>|mdi_cube_outline|
|<span class="nerdfont big">&#xf6a7;</span>|mdi_cube_send|
|<span class="nerdfont big">&#xf6a8;</span>|mdi_cube_unfolded|
|<span class="nerdfont big">&#xf6a9;</span>|mdi_cup|
|<span class="nerdfont big">&#xfae4;</span>|mdi_cup_off|
|<span class="nerdfont big">&#xf6aa;</span>|mdi_cup_water|
|<span class="nerdfont big">&#xf6ab;</span>|mdi_currency_btc|
|<span class="nerdfont big">&#xfcb7;</span>|mdi_currency_chf|
|<span class="nerdfont big">&#xfcb8;</span>|mdi_currency_cny|
|<span class="nerdfont big">&#xfcb9;</span>|mdi_currency_eth|
|<span class="nerdfont big">&#xf6ac;</span>|mdi_currency_eur|
|<span class="nerdfont big">&#xf6ad;</span>|mdi_currency_gbp|
|<span class="nerdfont big">&#xf6ae;</span>|mdi_currency_inr|
|<span class="nerdfont big">&#xfcba;</span>|mdi_currency_jpy|
|<span class="nerdfont big">&#xfcbb;</span>|mdi_currency_krw|
|<span class="nerdfont big">&#xf6af;</span>|mdi_currency_ngn|
|<span class="nerdfont big">&#xf6b0;</span>|mdi_currency_rub|
|<span class="nerdfont big">&#xfcbc;</span>|mdi_currency_sign|
|<span class="nerdfont big">&#xf6b1;</span>|mdi_currency_try|
|<span class="nerdfont big">&#xfcbd;</span>|mdi_currency_twd|
|<span class="nerdfont big">&#xf6b2;</span>|mdi_currency_usd|
|<span class="nerdfont big">&#xfb78;</span>|mdi_currency_usd_off|
|<span class="nerdfont big">&#xf6b3;</span>|mdi_cursor_default|
|<span class="nerdfont big">&#xf6b4;</span>|mdi_cursor_default_outline|
|<span class="nerdfont big">&#xf6b5;</span>|mdi_cursor_move|
|<span class="nerdfont big">&#xf6b6;</span>|mdi_cursor_pointer|
|<span class="nerdfont big">&#xfae6;</span>|mdi_cursor_text|
|<span class="nerdfont big">&#xf6b7;</span>|mdi_database|
|<span class="nerdfont big">&#xf6b8;</span>|mdi_database_minus|
|<span class="nerdfont big">&#xf6b9;</span>|mdi_database_plus|
|<span class="nerdfont big">&#xf6ba;</span>|mdi_debug_step_into|
|<span class="nerdfont big">&#xf6bb;</span>|mdi_debug_step_out|
|<span class="nerdfont big">&#xf6bc;</span>|mdi_debug_step_over|
|<span class="nerdfont big">&#xfc6a;</span>|mdi_decagram|
|<span class="nerdfont big">&#xfc6b;</span>|mdi_decagram_outline|
|<span class="nerdfont big">&#xf6bd;</span>|mdi_decimal_decrease|
|<span class="nerdfont big">&#xf6be;</span>|mdi_decimal_increase|
|<span class="nerdfont big">&#xf6bf;</span>|mdi_delete|
|<span class="nerdfont big">&#xfb81;</span>|mdi_delete_circle|
|<span class="nerdfont big">&#xfbca;</span>|mdi_delete_empty|
|<span class="nerdfont big">&#xfae7;</span>|mdi_delete_forever|
|<span class="nerdfont big">&#xfd17;</span>|mdi_delete_restore|
|<span class="nerdfont big">&#xfae8;</span>|mdi_delete_sweep|
|<span class="nerdfont big">&#xf6c0;</span>|mdi_delete_variant|
|<span class="nerdfont big">&#xf6c1;</span>|mdi_delta|
|<span class="nerdfont big">&#xf6c2;</span>|mdi_deskphone|
|<span class="nerdfont big">&#xfcbe;</span>|mdi_desktop_classic|
|<span class="nerdfont big">&#xf6c3;</span>|mdi_desktop_mac|
|<span class="nerdfont big">&#xf6c4;</span>|mdi_desktop_tower|
|<span class="nerdfont big">&#xf6c5;</span>|mdi_details|
|<span class="nerdfont big">&#xfb95;</span>|mdi_developer_board|
|<span class="nerdfont big">&#xf6c6;</span>|mdi_deviantart|
|<span class="nerdfont big">&#xfb1b;</span>|mdi_dialpad|
|<span class="nerdfont big">&#xf6c7;</span>|mdi_diamond|
|<span class="nerdfont big">&#xf6c9;</span>|mdi_dice_1|
|<span class="nerdfont big">&#xf6ca;</span>|mdi_dice_2|
|<span class="nerdfont big">&#xf6cb;</span>|mdi_dice_3|
|<span class="nerdfont big">&#xf6cc;</span>|mdi_dice_4|
|<span class="nerdfont big">&#xf6cd;</span>|mdi_dice_5|
|<span class="nerdfont big">&#xf6ce;</span>|mdi_dice_6|
|<span class="nerdfont big">&#xfaea;</span>|mdi_dice_d4|
|<span class="nerdfont big">&#xfaeb;</span>|mdi_dice_d6|
|<span class="nerdfont big">&#xfaec;</span>|mdi_dice_d8|
|<span class="nerdfont big">&#xfc6d;</span>|mdi_dice_d10|
|<span class="nerdfont big">&#xfae9;</span>|mdi_dice_d20|
|<span class="nerdfont big">&#xfc6c;</span>|mdi_dice_multiple|
|<span class="nerdfont big">&#xfb1c;</span>|mdi_dictionary|
|<span class="nerdfont big">&#xfcbf;</span>|mdi_dip_switch|
|<span class="nerdfont big">&#xf6cf;</span>|mdi_directions|
|<span class="nerdfont big">&#xfb40;</span>|mdi_directions_fork|
|<span class="nerdfont big">&#xfb6e;</span>|mdi_discord|
|<span class="nerdfont big">&#xfaed;</span>|mdi_disk|
|<span class="nerdfont big">&#xf6d0;</span>|mdi_disk_alert|
|<span class="nerdfont big">&#xf6d1;</span>|mdi_disqus|
|<span class="nerdfont big">&#xf6d2;</span>|mdi_disqus_outline|
|<span class="nerdfont big">&#xf6d3;</span>|mdi_division|
|<span class="nerdfont big">&#xf6d4;</span>|mdi_division_box|
|<span class="nerdfont big">&#xfb82;</span>|mdi_dna|
|<span class="nerdfont big">&#xf6d5;</span>|mdi_dns|
|<span class="nerdfont big">&#xfb96;</span>|mdi_do_not_disturb|
|<span class="nerdfont big">&#xfb97;</span>|mdi_do_not_disturb_off|
|<span class="nerdfont big">&#xfbb1;</span>|mdi_dolby|
|<span class="nerdfont big">&#xf6d6;</span>|mdi_domain|
|<span class="nerdfont big">&#xfcc0;</span>|mdi_donkey|
|<span class="nerdfont big">&#xfd18;</span>|mdi_door|
|<span class="nerdfont big">&#xfd19;</span>|mdi_door_closed|
|<span class="nerdfont big">&#xfd1a;</span>|mdi_door_open|
|<span class="nerdfont big">&#xf6d7;</span>|mdi_dots_horizontal|
|<span class="nerdfont big">&#xfcc1;</span>|mdi_dots_horizontal_circle|
|<span class="nerdfont big">&#xf6d8;</span>|mdi_dots_vertical|
|<span class="nerdfont big">&#xfcc2;</span>|mdi_dots_vertical_circle|
|<span class="nerdfont big">&#xfb98;</span>|mdi_douban|
|<span class="nerdfont big">&#xf6d9;</span>|mdi_download|
|<span class="nerdfont big">&#xfbf2;</span>|mdi_download_network|
|<span class="nerdfont big">&#xf6da;</span>|mdi_drag|
|<span class="nerdfont big">&#xf6db;</span>|mdi_drag_horizontal|
|<span class="nerdfont big">&#xf6dc;</span>|mdi_drag_vertical|
|<span class="nerdfont big">&#xf6dd;</span>|mdi_drawing|
|<span class="nerdfont big">&#xf6de;</span>|mdi_drawing_box|
|<span class="nerdfont big">&#xf6df;</span>|mdi_dribbble|
|<span class="nerdfont big">&#xf6e0;</span>|mdi_dribbble_box|
|<span class="nerdfont big">&#xf6e1;</span>|mdi_drone|
|<span class="nerdfont big">&#xf6e2;</span>|mdi_dropbox|
|<span class="nerdfont big">&#xf6e3;</span>|mdi_drupal|
|<span class="nerdfont big">&#xf6e4;</span>|mdi_duck|
|<span class="nerdfont big">&#xf6e5;</span>|mdi_dumbbell|
|<span class="nerdfont big">&#xfcc3;</span>|mdi_ear_hearing|
|<span class="nerdfont big">&#xf6e6;</span>|mdi_earth|
|<span class="nerdfont big">&#xfbcb;</span>|mdi_earth_box|
|<span class="nerdfont big">&#xfbcc;</span>|mdi_earth_box_off|
|<span class="nerdfont big">&#xf6e7;</span>|mdi_earth_off|
|<span class="nerdfont big">&#xf6e8;</span>|mdi_edge|
|<span class="nerdfont big">&#xf6e9;</span>|mdi_eject|
|<span class="nerdfont big">&#xfcc4;</span>|mdi_elephant|
|<span class="nerdfont big">&#xf6ea;</span>|mdi_elevation_decline|
|<span class="nerdfont big">&#xf6eb;</span>|mdi_elevation_rise|
|<span class="nerdfont big">&#xf6ec;</span>|mdi_elevator|
|<span class="nerdfont big">&#xf6ed;</span>|mdi_email|
|<span class="nerdfont big">&#xfbcd;</span>|mdi_email_alert|
|<span class="nerdfont big">&#xf6ee;</span>|mdi_email_open|
|<span class="nerdfont big">&#xfaee;</span>|mdi_email_open_outline|
|<span class="nerdfont big">&#xf6ef;</span>|mdi_email_outline|
|<span class="nerdfont big">&#xf6f0;</span>|mdi_email_secure|
|<span class="nerdfont big">&#xfaef;</span>|mdi_email_variant|
|<span class="nerdfont big">&#xfbb2;</span>|mdi_emby|
|<span class="nerdfont big">&#xf6f1;</span>|mdi_emoticon|
|<span class="nerdfont big">&#xf6f2;</span>|mdi_emoticon_cool|
|<span class="nerdfont big">&#xfb99;</span>|mdi_emoticon_dead|
|<span class="nerdfont big">&#xf6f3;</span>|mdi_emoticon_devil|
|<span class="nerdfont big">&#xfb9a;</span>|mdi_emoticon_excited|
|<span class="nerdfont big">&#xf6f4;</span>|mdi_emoticon_happy|
|<span class="nerdfont big">&#xf6f5;</span>|mdi_emoticon_neutral|
|<span class="nerdfont big">&#xf6f6;</span>|mdi_emoticon_poop|
|<span class="nerdfont big">&#xf6f7;</span>|mdi_emoticon_sad|
|<span class="nerdfont big">&#xf6f8;</span>|mdi_emoticon_tongue|
|<span class="nerdfont big">&#xf6f9;</span>|mdi_engine|
|<span class="nerdfont big">&#xf6fa;</span>|mdi_engine_outline|
|<span class="nerdfont big">&#xf6fb;</span>|mdi_equal|
|<span class="nerdfont big">&#xf6fc;</span>|mdi_equal_box|
|<span class="nerdfont big">&#xf6fd;</span>|mdi_eraser|
|<span class="nerdfont big">&#xfb41;</span>|mdi_eraser_variant|
|<span class="nerdfont big">&#xf6fe;</span>|mdi_escalator|
|<span class="nerdfont big">&#xf6ff;</span>|mdi_ethernet|
|<span class="nerdfont big">&#xf700;</span>|mdi_ethernet_cable|
|<span class="nerdfont big">&#xf701;</span>|mdi_ethernet_cable_off|
|<span class="nerdfont big">&#xf702;</span>|mdi_etsy|
|<span class="nerdfont big">&#xfaf0;</span>|mdi_ev_station|
|<span class="nerdfont big">&#xfcc5;</span>|mdi_eventbrite|
|<span class="nerdfont big">&#xf703;</span>|mdi_evernote|
|<span class="nerdfont big">&#xf704;</span>|mdi_exclamation|
|<span class="nerdfont big">&#xf705;</span>|mdi_exit_to_app|
|<span class="nerdfont big">&#xf706;</span>|mdi_export|
|<span class="nerdfont big">&#xf707;</span>|mdi_eye|
|<span class="nerdfont big">&#xf708;</span>|mdi_eye_off|
|<span class="nerdfont big">&#xfbcf;</span>|mdi_eye_off_outline|
|<span class="nerdfont big">&#xfbce;</span>|mdi_eye_outline|
|<span class="nerdfont big">&#xf709;</span>|mdi_eyedropper|
|<span class="nerdfont big">&#xf70a;</span>|mdi_eyedropper_variant|
|<span class="nerdfont big">&#xfb42;</span>|mdi_face|
|<span class="nerdfont big">&#xfb43;</span>|mdi_face_profile|
|<span class="nerdfont big">&#xf70b;</span>|mdi_facebook|
|<span class="nerdfont big">&#xf70c;</span>|mdi_facebook_box|
|<span class="nerdfont big">&#xf70d;</span>|mdi_facebook_messenger|
|<span class="nerdfont big">&#xf70e;</span>|mdi_factory|
|<span class="nerdfont big">&#xf70f;</span>|mdi_fan|
|<span class="nerdfont big">&#xfd1b;</span>|mdi_fan_off|
|<span class="nerdfont big">&#xf710;</span>|mdi_fast_forward|
|<span class="nerdfont big">&#xfbd0;</span>|mdi_fast_forward_outline|
|<span class="nerdfont big">&#xf711;</span>|mdi_fax|
|<span class="nerdfont big">&#xfbd1;</span>|mdi_feather|
|<span class="nerdfont big">&#xf712;</span>|mdi_ferry|
|<span class="nerdfont big">&#xf713;</span>|mdi_file|
|<span class="nerdfont big">&#xfc39;</span>|mdi_file_account|
|<span class="nerdfont big">&#xf714;</span>|mdi_file_chart|
|<span class="nerdfont big">&#xf715;</span>|mdi_file_check|
|<span class="nerdfont big">&#xf716;</span>|mdi_file_cloud|
|<span class="nerdfont big">&#xf717;</span>|mdi_file_delimited|
|<span class="nerdfont big">&#xf718;</span>|mdi_file_document|
|<span class="nerdfont big">&#xf719;</span>|mdi_file_document_box|
|<span class="nerdfont big">&#xf71a;</span>|mdi_file_excel|
|<span class="nerdfont big">&#xf71b;</span>|mdi_file_excel_box|
|<span class="nerdfont big">&#xf71c;</span>|mdi_file_export|
|<span class="nerdfont big">&#xf71d;</span>|mdi_file_find|
|<span class="nerdfont big">&#xfb12;</span>|mdi_file_hidden|
|<span class="nerdfont big">&#xf71e;</span>|mdi_file_image|
|<span class="nerdfont big">&#xf71f;</span>|mdi_file_import|
|<span class="nerdfont big">&#xf720;</span>|mdi_file_lock|
|<span class="nerdfont big">&#xf721;</span>|mdi_file_multiple|
|<span class="nerdfont big">&#xf722;</span>|mdi_file_music|
|<span class="nerdfont big">&#xf723;</span>|mdi_file_outline|
|<span class="nerdfont big">&#xf724;</span>|mdi_file_pdf|
|<span class="nerdfont big">&#xf725;</span>|mdi_file_pdf_box|
|<span class="nerdfont big">&#xfd1c;</span>|mdi_file_percent|
|<span class="nerdfont big">&#xfc50;</span>|mdi_file_plus|
|<span class="nerdfont big">&#xf726;</span>|mdi_file_powerpoint|
|<span class="nerdfont big">&#xf727;</span>|mdi_file_powerpoint_box|
|<span class="nerdfont big">&#xf728;</span>|mdi_file_presentation_box|
|<span class="nerdfont big">&#xfb6f;</span>|mdi_file_restore|
|<span class="nerdfont big">&#xf729;</span>|mdi_file_send|
|<span class="nerdfont big">&#xfb44;</span>|mdi_file_tree|
|<span class="nerdfont big">&#xf72a;</span>|mdi_file_video|
|<span class="nerdfont big">&#xf72b;</span>|mdi_file_word|
|<span class="nerdfont big">&#xf72c;</span>|mdi_file_word_box|
|<span class="nerdfont big">&#xf72d;</span>|mdi_file_xml|
|<span class="nerdfont big">&#xf72e;</span>|mdi_film|
|<span class="nerdfont big">&#xf72f;</span>|mdi_filmstrip|
|<span class="nerdfont big">&#xf730;</span>|mdi_filmstrip_off|
|<span class="nerdfont big">&#xf731;</span>|mdi_filter|
|<span class="nerdfont big">&#xf732;</span>|mdi_filter_outline|
|<span class="nerdfont big">&#xf733;</span>|mdi_filter_remove|
|<span class="nerdfont big">&#xf734;</span>|mdi_filter_remove_outline|
|<span class="nerdfont big">&#xf735;</span>|mdi_filter_variant|
|<span class="nerdfont big">&#xfd1d;</span>|mdi_finance|
|<span class="nerdfont big">&#xfbd2;</span>|mdi_find_replace|
|<span class="nerdfont big">&#xf736;</span>|mdi_fingerprint|
|<span class="nerdfont big">&#xf737;</span>|mdi_fire|
|<span class="nerdfont big">&#xf738;</span>|mdi_firefox|
|<span class="nerdfont big">&#xf739;</span>|mdi_fish|
|<span class="nerdfont big">&#xf73a;</span>|mdi_flag|
|<span class="nerdfont big">&#xf73b;</span>|mdi_flag_checkered|
|<span class="nerdfont big">&#xf73c;</span>|mdi_flag_outline|
|<span class="nerdfont big">&#xf73e;</span>|mdi_flag_triangle|
|<span class="nerdfont big">&#xf73f;</span>|mdi_flag_variant|
|<span class="nerdfont big">&#xf73d;</span>|mdi_flag_variant_outline|
|<span class="nerdfont big">&#xf740;</span>|mdi_flash|
|<span class="nerdfont big">&#xf741;</span>|mdi_flash_auto|
|<span class="nerdfont big">&#xfd1e;</span>|mdi_flash_circle|
|<span class="nerdfont big">&#xf742;</span>|mdi_flash_off|
|<span class="nerdfont big">&#xfbd3;</span>|mdi_flash_outline|
|<span class="nerdfont big">&#xfb79;</span>|mdi_flash_red_eye|
|<span class="nerdfont big">&#xf743;</span>|mdi_flashlight|
|<span class="nerdfont big">&#xf744;</span>|mdi_flashlight_off|
|<span class="nerdfont big">&#xf592;</span>|mdi_flask|
|<span class="nerdfont big">&#xf593;</span>|mdi_flask_empty|
|<span class="nerdfont big">&#xf594;</span>|mdi_flask_empty_outline|
|<span class="nerdfont big">&#xf595;</span>|mdi_flask_outline|
|<span class="nerdfont big">&#xf745;</span>|mdi_flattr|
|<span class="nerdfont big">&#xf746;</span>|mdi_flip_to_back|
|<span class="nerdfont big">&#xf747;</span>|mdi_flip_to_front|
|<span class="nerdfont big">&#xfd1f;</span>|mdi_floor_plan|
|<span class="nerdfont big">&#xf748;</span>|mdi_floppy|
|<span class="nerdfont big">&#xf749;</span>|mdi_flower|
|<span class="nerdfont big">&#xf74a;</span>|mdi_folder|
|<span class="nerdfont big">&#xf74b;</span>|mdi_folder_account|
|<span class="nerdfont big">&#xf74c;</span>|mdi_folder_download|
|<span class="nerdfont big">&#xf74d;</span>|mdi_folder_google_drive|
|<span class="nerdfont big">&#xf74e;</span>|mdi_folder_image|
|<span class="nerdfont big">&#xf74f;</span>|mdi_folder_lock|
|<span class="nerdfont big">&#xf750;</span>|mdi_folder_lock_open|
|<span class="nerdfont big">&#xf751;</span>|mdi_folder_move|
|<span class="nerdfont big">&#xf752;</span>|mdi_folder_multiple|
|<span class="nerdfont big">&#xf753;</span>|mdi_folder_multiple_image|
|<span class="nerdfont big">&#xf754;</span>|mdi_folder_multiple_outline|
|<span class="nerdfont big">&#xfc6e;</span>|mdi_folder_open|
|<span class="nerdfont big">&#xf755;</span>|mdi_folder_outline|
|<span class="nerdfont big">&#xf756;</span>|mdi_folder_plus|
|<span class="nerdfont big">&#xf757;</span>|mdi_folder_remove|
|<span class="nerdfont big">&#xfb9b;</span>|mdi_folder_star|
|<span class="nerdfont big">&#xf758;</span>|mdi_folder_upload|
|<span class="nerdfont big">&#xf539;</span>|mdi_font_awesome|
|<span class="nerdfont big">&#xf759;</span>|mdi_food|
|<span class="nerdfont big">&#xf75a;</span>|mdi_food_apple|
|<span class="nerdfont big">&#xfcc6;</span>|mdi_food_croissant|
|<span class="nerdfont big">&#xfaf1;</span>|mdi_food_fork_drink|
|<span class="nerdfont big">&#xfaf2;</span>|mdi_food_off|
|<span class="nerdfont big">&#xf75b;</span>|mdi_food_variant|
|<span class="nerdfont big">&#xf75c;</span>|mdi_football|
|<span class="nerdfont big">&#xf75d;</span>|mdi_football_australian|
|<span class="nerdfont big">&#xf75e;</span>|mdi_football_helmet|
|<span class="nerdfont big">&#xfcc7;</span>|mdi_forklift|
|<span class="nerdfont big">&#xfc51;</span>|mdi_format_align_bottom|
|<span class="nerdfont big">&#xf75f;</span>|mdi_format_align_center|
|<span class="nerdfont big">&#xf760;</span>|mdi_format_align_justify|
|<span class="nerdfont big">&#xf761;</span>|mdi_format_align_left|
|<span class="nerdfont big">&#xfc52;</span>|mdi_format_align_middle|
|<span class="nerdfont big">&#xf762;</span>|mdi_format_align_right|
|<span class="nerdfont big">&#xfc53;</span>|mdi_format_align_top|
|<span class="nerdfont big">&#xfb45;</span>|mdi_format_annotation_plus|
|<span class="nerdfont big">&#xf763;</span>|mdi_format_bold|
|<span class="nerdfont big">&#xf764;</span>|mdi_format_clear|
|<span class="nerdfont big">&#xf765;</span>|mdi_format_color_fill|
|<span class="nerdfont big">&#xfb9c;</span>|mdi_format_color_text|
|<span class="nerdfont big">&#xf766;</span>|mdi_format_float_center|
|<span class="nerdfont big">&#xf767;</span>|mdi_format_float_left|
|<span class="nerdfont big">&#xf768;</span>|mdi_format_float_none|
|<span class="nerdfont big">&#xf769;</span>|mdi_format_float_right|
|<span class="nerdfont big">&#xfbd4;</span>|mdi_format_font|
|<span class="nerdfont big">&#xf76a;</span>|mdi_format_header_1|
|<span class="nerdfont big">&#xf76b;</span>|mdi_format_header_2|
|<span class="nerdfont big">&#xf76c;</span>|mdi_format_header_3|
|<span class="nerdfont big">&#xf76d;</span>|mdi_format_header_4|
|<span class="nerdfont big">&#xf76e;</span>|mdi_format_header_5|
|<span class="nerdfont big">&#xf76f;</span>|mdi_format_header_6|
|<span class="nerdfont big">&#xf770;</span>|mdi_format_header_decrease|
|<span class="nerdfont big">&#xf771;</span>|mdi_format_header_equal|
|<span class="nerdfont big">&#xf772;</span>|mdi_format_header_increase|
|<span class="nerdfont big">&#xf773;</span>|mdi_format_header_pound|
|<span class="nerdfont big">&#xfb1d;</span>|mdi_format_horizontal_align_center|
|<span class="nerdfont big">&#xfb1e;</span>|mdi_format_horizontal_align_left|
|<span class="nerdfont big">&#xfb1f;</span>|mdi_format_horizontal_align_right|
|<span class="nerdfont big">&#xf774;</span>|mdi_format_indent_decrease|
|<span class="nerdfont big">&#xf775;</span>|mdi_format_indent_increase|
|<span class="nerdfont big">&#xf776;</span>|mdi_format_italic|
|<span class="nerdfont big">&#xf777;</span>|mdi_format_line_spacing|
|<span class="nerdfont big">&#xfac7;</span>|mdi_format_line_style|
|<span class="nerdfont big">&#xfac8;</span>|mdi_format_line_weight|
|<span class="nerdfont big">&#xf778;</span>|mdi_format_list_bulleted|
|<span class="nerdfont big">&#xf779;</span>|mdi_format_list_bulleted_type|
|<span class="nerdfont big">&#xfc54;</span>|mdi_format_list_checks|
|<span class="nerdfont big">&#xf77a;</span>|mdi_format_list_numbers|
|<span class="nerdfont big">&#xfbd5;</span>|mdi_format_page_break|
|<span class="nerdfont big">&#xf77b;</span>|mdi_format_paint|
|<span class="nerdfont big">&#xf77c;</span>|mdi_format_paragraph|
|<span class="nerdfont big">&#xfbd6;</span>|mdi_format_pilcrow|
|<span class="nerdfont big">&#xf77d;</span>|mdi_format_quote_close|
|<span class="nerdfont big">&#xfc55;</span>|mdi_format_quote_open|
|<span class="nerdfont big">&#xfba8;</span>|mdi_format_rotate_90|
|<span class="nerdfont big">&#xfb9d;</span>|mdi_format_section|
|<span class="nerdfont big">&#xf77e;</span>|mdi_format_size|
|<span class="nerdfont big">&#xf77f;</span>|mdi_format_strikethrough|
|<span class="nerdfont big">&#xf780;</span>|mdi_format_strikethrough_variant|
|<span class="nerdfont big">&#xf781;</span>|mdi_format_subscript|
|<span class="nerdfont big">&#xf782;</span>|mdi_format_superscript|
|<span class="nerdfont big">&#xf783;</span>|mdi_format_text|
|<span class="nerdfont big">&#xf784;</span>|mdi_format_textdirection_l_to_r|
|<span class="nerdfont big">&#xf785;</span>|mdi_format_textdirection_r_to_l|
|<span class="nerdfont big">&#xfaf3;</span>|mdi_format_title|
|<span class="nerdfont big">&#xf786;</span>|mdi_format_underline|
|<span class="nerdfont big">&#xfb20;</span>|mdi_format_vertical_align_bottom|
|<span class="nerdfont big">&#xfb21;</span>|mdi_format_vertical_align_center|
|<span class="nerdfont big">&#xfb22;</span>|mdi_format_vertical_align_top|
|<span class="nerdfont big">&#xf787;</span>|mdi_format_wrap_inline|
|<span class="nerdfont big">&#xf788;</span>|mdi_format_wrap_square|
|<span class="nerdfont big">&#xf789;</span>|mdi_format_wrap_tight|
|<span class="nerdfont big">&#xf78a;</span>|mdi_format_wrap_top_bottom|
|<span class="nerdfont big">&#xf78b;</span>|mdi_forum|
|<span class="nerdfont big">&#xfd20;</span>|mdi_forum_outline|
|<span class="nerdfont big">&#xf78c;</span>|mdi_forward|
|<span class="nerdfont big">&#xf78d;</span>|mdi_foursquare|
|<span class="nerdfont big">&#xf78e;</span>|mdi_fridge|
|<span class="nerdfont big">&#xf78f;</span>|mdi_fridge_filled|
|<span class="nerdfont big">&#xf790;</span>|mdi_fridge_filled_bottom|
|<span class="nerdfont big">&#xf791;</span>|mdi_fridge_filled_top|
|<span class="nerdfont big">&#xfcc8;</span>|mdi_fuel|
|<span class="nerdfont big">&#xf792;</span>|mdi_fullscreen|
|<span class="nerdfont big">&#xf793;</span>|mdi_fullscreen_exit|
|<span class="nerdfont big">&#xf794;</span>|mdi_function|
|<span class="nerdfont big">&#xf795;</span>|mdi_gamepad|
|<span class="nerdfont big">&#xf796;</span>|mdi_gamepad_variant|
|<span class="nerdfont big">&#xfbd7;</span>|mdi_garage|
|<span class="nerdfont big">&#xfbd8;</span>|mdi_garage_open|
|<span class="nerdfont big">&#xfb46;</span>|mdi_gas_cylinder|
|<span class="nerdfont big">&#xf797;</span>|mdi_gas_station|
|<span class="nerdfont big">&#xf798;</span>|mdi_gate|
|<span class="nerdfont big">&#xf799;</span>|mdi_gauge|
|<span class="nerdfont big">&#xf79a;</span>|mdi_gavel|
|<span class="nerdfont big">&#xf79b;</span>|mdi_gender_female|
|<span class="nerdfont big">&#xf79c;</span>|mdi_gender_male|
|<span class="nerdfont big">&#xf79d;</span>|mdi_gender_male_female|
|<span class="nerdfont big">&#xf79e;</span>|mdi_gender_transgender|
|<span class="nerdfont big">&#xfcc9;</span>|mdi_gesture|
|<span class="nerdfont big">&#xfc3a;</span>|mdi_gesture_double_tap|
|<span class="nerdfont big">&#xfc3b;</span>|mdi_gesture_swipe_down|
|<span class="nerdfont big">&#xfc3c;</span>|mdi_gesture_swipe_left|
|<span class="nerdfont big">&#xfc3d;</span>|mdi_gesture_swipe_right|
|<span class="nerdfont big">&#xfc3e;</span>|mdi_gesture_swipe_up|
|<span class="nerdfont big">&#xfc3f;</span>|mdi_gesture_tap|
|<span class="nerdfont big">&#xfc40;</span>|mdi_gesture_two_double_tap|
|<span class="nerdfont big">&#xfc41;</span>|mdi_gesture_two_tap|
|<span class="nerdfont big">&#xf79f;</span>|mdi_ghost|
|<span class="nerdfont big">&#xf7a0;</span>|mdi_gift|
|<span class="nerdfont big">&#xf7a1;</span>|mdi_git|
|<span class="nerdfont big">&#xf7a2;</span>|mdi_github_box|
|<span class="nerdfont big">&#xf7a3;</span>|mdi_github_circle|
|<span class="nerdfont big">&#xfbd9;</span>|mdi_github_face|
|<span class="nerdfont big">&#xf7a4;</span>|mdi_glass_flute|
|<span class="nerdfont big">&#xf7a5;</span>|mdi_glass_mug|
|<span class="nerdfont big">&#xf7a6;</span>|mdi_glass_stange|
|<span class="nerdfont big">&#xf7a7;</span>|mdi_glass_tulip|
|<span class="nerdfont big">&#xf7a8;</span>|mdi_glassdoor|
|<span class="nerdfont big">&#xf7a9;</span>|mdi_glasses|
|<span class="nerdfont big">&#xf7aa;</span>|mdi_gmail|
|<span class="nerdfont big">&#xf7ab;</span>|mdi_gnome|
|<span class="nerdfont big">&#xfd21;</span>|mdi_golf|
|<span class="nerdfont big">&#xfb84;</span>|mdi_gondola|
|<span class="nerdfont big">&#xf7ac;</span>|mdi_google|
|<span class="nerdfont big">&#xfcca;</span>|mdi_google_analytics|
|<span class="nerdfont big">&#xfccb;</span>|mdi_google_assistant|
|<span class="nerdfont big">&#xf7ad;</span>|mdi_google_cardboard|
|<span class="nerdfont big">&#xf7ae;</span>|mdi_google_chrome|
|<span class="nerdfont big">&#xf7af;</span>|mdi_google_circles|
|<span class="nerdfont big">&#xf7b0;</span>|mdi_google_circles_communities|
|<span class="nerdfont big">&#xf7b1;</span>|mdi_google_circles_extended|
|<span class="nerdfont big">&#xf7b2;</span>|mdi_google_circles_group|
|<span class="nerdfont big">&#xf7b3;</span>|mdi_google_controller|
|<span class="nerdfont big">&#xf7b4;</span>|mdi_google_controller_off|
|<span class="nerdfont big">&#xf7b5;</span>|mdi_google_drive|
|<span class="nerdfont big">&#xf7b6;</span>|mdi_google_earth|
|<span class="nerdfont big">&#xf7b7;</span>|mdi_google_glass|
|<span class="nerdfont big">&#xfd22;</span>|mdi_google_home|
|<span class="nerdfont big">&#xfbda;</span>|mdi_google_keep|
|<span class="nerdfont big">&#xfaf4;</span>|mdi_google_maps|
|<span class="nerdfont big">&#xf7b8;</span>|mdi_google_nearby|
|<span class="nerdfont big">&#xf7b9;</span>|mdi_google_pages|
|<span class="nerdfont big">&#xfbdb;</span>|mdi_google_photos|
|<span class="nerdfont big">&#xf7ba;</span>|mdi_google_physical_web|
|<span class="nerdfont big">&#xf7bb;</span>|mdi_google_play|
|<span class="nerdfont big">&#xf7bc;</span>|mdi_google_plus|
|<span class="nerdfont big">&#xf7bd;</span>|mdi_google_plus_box|
|<span class="nerdfont big">&#xf7be;</span>|mdi_google_translate|
|<span class="nerdfont big">&#xf7bf;</span>|mdi_google_wallet|
|<span class="nerdfont big">&#xfb9e;</span>|mdi_gradient|
|<span class="nerdfont big">&#xfb47;</span>|mdi_grease_pencil|
|<span class="nerdfont big">&#xf7c0;</span>|mdi_grid|
|<span class="nerdfont big">&#xfc56;</span>|mdi_grid_large|
|<span class="nerdfont big">&#xf7c1;</span>|mdi_grid_off|
|<span class="nerdfont big">&#xf7c2;</span>|mdi_group|
|<span class="nerdfont big">&#xfc6f;</span>|mdi_guitar_acoustic|
|<span class="nerdfont big">&#xf7c3;</span>|mdi_guitar_electric|
|<span class="nerdfont big">&#xf7c4;</span>|mdi_guitar_pick|
|<span class="nerdfont big">&#xf7c5;</span>|mdi_guitar_pick_outline|
|<span class="nerdfont big">&#xfd23;</span>|mdi_guy_fawkes_mask|
|<span class="nerdfont big">&#xfb23;</span>|mdi_hackernews|
|<span class="nerdfont big">&#xfb83;</span>|mdi_hamburger|
|<span class="nerdfont big">&#xf7c6;</span>|mdi_hand_pointing_right|
|<span class="nerdfont big">&#xf7c7;</span>|mdi_hanger|
|<span class="nerdfont big">&#xf7c8;</span>|mdi_hangouts|
|<span class="nerdfont big">&#xf7c9;</span>|mdi_harddisk|
|<span class="nerdfont big">&#xf7ca;</span>|mdi_headphones|
|<span class="nerdfont big">&#xf7cb;</span>|mdi_headphones_box|
|<span class="nerdfont big">&#xfccc;</span>|mdi_headphones_off|
|<span class="nerdfont big">&#xf7cc;</span>|mdi_headphones_settings|
|<span class="nerdfont big">&#xf7cd;</span>|mdi_headset|
|<span class="nerdfont big">&#xf7ce;</span>|mdi_headset_dock|
|<span class="nerdfont big">&#xf7cf;</span>|mdi_headset_off|
|<span class="nerdfont big">&#xf7d0;</span>|mdi_heart|
|<span class="nerdfont big">&#xf7d1;</span>|mdi_heart_box|
|<span class="nerdfont big">&#xf7d2;</span>|mdi_heart_box_outline|
|<span class="nerdfont big">&#xf7d3;</span>|mdi_heart_broken|
|<span class="nerdfont big">&#xfbdd;</span>|mdi_heart_half|
|<span class="nerdfont big">&#xfbdc;</span>|mdi_heart_half_full|
|<span class="nerdfont big">&#xfbde;</span>|mdi_heart_half_outline|
|<span class="nerdfont big">&#xfc57;</span>|mdi_heart_off|
|<span class="nerdfont big">&#xf7d4;</span>|mdi_heart_outline|
|<span class="nerdfont big">&#xfaf5;</span>|mdi_heart_pulse|
|<span class="nerdfont big">&#xf7d5;</span>|mdi_help|
|<span class="nerdfont big">&#xfc89;</span>|mdi_help_box|
|<span class="nerdfont big">&#xf7d6;</span>|mdi_help_circle|
|<span class="nerdfont big">&#xfb24;</span>|mdi_help_circle_outline|
|<span class="nerdfont big">&#xfbf3;</span>|mdi_help_network|
|<span class="nerdfont big">&#xf7d7;</span>|mdi_hexagon|
|<span class="nerdfont big">&#xfbdf;</span>|mdi_hexagon_multiple|
|<span class="nerdfont big">&#xf7d8;</span>|mdi_hexagon_outline|
|<span class="nerdfont big">&#xfccd;</span>|mdi_high_definition|
|<span class="nerdfont big">&#xfaf6;</span>|mdi_highway|
|<span class="nerdfont big">&#xf7d9;</span>|mdi_history|
|<span class="nerdfont big">&#xf7da;</span>|mdi_hololens|
|<span class="nerdfont big">&#xf7db;</span>|mdi_home|
|<span class="nerdfont big">&#xfd24;</span>|mdi_home_account|
|<span class="nerdfont big">&#xfcce;</span>|mdi_home_assistant|
|<span class="nerdfont big">&#xfccf;</span>|mdi_home_automation|
|<span class="nerdfont big">&#xfcd0;</span>|mdi_home_circle|
|<span class="nerdfont big">&#xfd25;</span>|mdi_home_heart|
|<span class="nerdfont big">&#xfaf7;</span>|mdi_home_map_marker|
|<span class="nerdfont big">&#xf7dc;</span>|mdi_home_modern|
|<span class="nerdfont big">&#xfb9f;</span>|mdi_home_outline|
|<span class="nerdfont big">&#xf7dd;</span>|mdi_home_variant|
|<span class="nerdfont big">&#xfbe0;</span>|mdi_hook|
|<span class="nerdfont big">&#xfbe1;</span>|mdi_hook_off|
|<span class="nerdfont big">&#xf7de;</span>|mdi_hops|
|<span class="nerdfont big">&#xf7df;</span>|mdi_hospital|
|<span class="nerdfont big">&#xf7e0;</span>|mdi_hospital_building|
|<span class="nerdfont big">&#xf7e1;</span>|mdi_hospital_marker|
|<span class="nerdfont big">&#xfd26;</span>|mdi_hot_tub|
|<span class="nerdfont big">&#xf7e2;</span>|mdi_hotel|
|<span class="nerdfont big">&#xf7e3;</span>|mdi_houzz|
|<span class="nerdfont big">&#xf7e4;</span>|mdi_houzz_box|
|<span class="nerdfont big">&#xfd27;</span>|mdi_hulu|
|<span class="nerdfont big">&#xf7e5;</span>|mdi_human|
|<span class="nerdfont big">&#xf7e6;</span>|mdi_human_child|
|<span class="nerdfont big">&#xfb48;</span>|mdi_human_female|
|<span class="nerdfont big">&#xfb49;</span>|mdi_human_greeting|
|<span class="nerdfont big">&#xfb4a;</span>|mdi_human_handsdown|
|<span class="nerdfont big">&#xfb4b;</span>|mdi_human_handsup|
|<span class="nerdfont big">&#xfb4c;</span>|mdi_human_male|
|<span class="nerdfont big">&#xf7e7;</span>|mdi_human_male_female|
|<span class="nerdfont big">&#xface;</span>|mdi_human_pregnant|
|<span class="nerdfont big">&#xfc42;</span>|mdi_humble_bundle|
|<span class="nerdfont big">&#xfd28;</span>|mdi_ice_cream|
|<span class="nerdfont big">&#xf7e8;</span>|mdi_image|
|<span class="nerdfont big">&#xf7e9;</span>|mdi_image_album|
|<span class="nerdfont big">&#xf7ea;</span>|mdi_image_area|
|<span class="nerdfont big">&#xf7eb;</span>|mdi_image_area_close|
|<span class="nerdfont big">&#xf7ec;</span>|mdi_image_broken|
|<span class="nerdfont big">&#xf7ed;</span>|mdi_image_broken_variant|
|<span class="nerdfont big">&#xf7ee;</span>|mdi_image_filter|
|<span class="nerdfont big">&#xf7ef;</span>|mdi_image_filter_black_white|
|<span class="nerdfont big">&#xf7f0;</span>|mdi_image_filter_center_focus|
|<span class="nerdfont big">&#xf7f1;</span>|mdi_image_filter_center_focus_weak|
|<span class="nerdfont big">&#xf7f2;</span>|mdi_image_filter_drama|
|<span class="nerdfont big">&#xf7f3;</span>|mdi_image_filter_frames|
|<span class="nerdfont big">&#xf7f4;</span>|mdi_image_filter_hdr|
|<span class="nerdfont big">&#xf7f5;</span>|mdi_image_filter_none|
|<span class="nerdfont big">&#xf7f6;</span>|mdi_image_filter_tilt_shift|
|<span class="nerdfont big">&#xf7f7;</span>|mdi_image_filter_vintage|
|<span class="nerdfont big">&#xf7f8;</span>|mdi_image_multiple|
|<span class="nerdfont big">&#xfd29;</span>|mdi_image_off|
|<span class="nerdfont big">&#xf7f9;</span>|mdi_import|
|<span class="nerdfont big">&#xfb85;</span>|mdi_inbox|
|<span class="nerdfont big">&#xf7fa;</span>|mdi_inbox_arrow_down|
|<span class="nerdfont big">&#xf8d0;</span>|mdi_inbox_arrow_up|
|<span class="nerdfont big">&#xfaf8;</span>|mdi_incognito|
|<span class="nerdfont big">&#xfbe2;</span>|mdi_infinity|
|<span class="nerdfont big">&#xf7fb;</span>|mdi_information|
|<span class="nerdfont big">&#xf7fc;</span>|mdi_information_outline|
|<span class="nerdfont big">&#xfb4d;</span>|mdi_information_variant|
|<span class="nerdfont big">&#xf7fd;</span>|mdi_instagram|
|<span class="nerdfont big">&#xf7fe;</span>|mdi_instapaper|
|<span class="nerdfont big">&#xf7ff;</span>|mdi_internet_explorer|
|<span class="nerdfont big">&#xf800;</span>|mdi_invert_colors|
|<span class="nerdfont big">&#xfb75;</span>|mdi_itunes|
|<span class="nerdfont big">&#xf801;</span>|mdi_jeepney|
|<span class="nerdfont big">&#xf802;</span>|mdi_jira|
|<span class="nerdfont big">&#xf803;</span>|mdi_jsfiddle|
|<span class="nerdfont big">&#xfb25;</span>|mdi_json|
|<span class="nerdfont big">&#xfd2a;</span>|mdi_karate|
|<span class="nerdfont big">&#xf804;</span>|mdi_keg|
|<span class="nerdfont big">&#xfaf9;</span>|mdi_kettle|
|<span class="nerdfont big">&#xf805;</span>|mdi_key|
|<span class="nerdfont big">&#xf806;</span>|mdi_key_change|
|<span class="nerdfont big">&#xf807;</span>|mdi_key_minus|
|<span class="nerdfont big">&#xf808;</span>|mdi_key_plus|
|<span class="nerdfont big">&#xf809;</span>|mdi_key_remove|
|<span class="nerdfont big">&#xf80a;</span>|mdi_key_variant|
|<span class="nerdfont big">&#xf80b;</span>|mdi_keyboard|
|<span class="nerdfont big">&#xf80c;</span>|mdi_keyboard_backspace|
|<span class="nerdfont big">&#xf80d;</span>|mdi_keyboard_caps|
|<span class="nerdfont big">&#xf80e;</span>|mdi_keyboard_close|
|<span class="nerdfont big">&#xf80f;</span>|mdi_keyboard_off|
|<span class="nerdfont big">&#xf810;</span>|mdi_keyboard_return|
|<span class="nerdfont big">&#xf811;</span>|mdi_keyboard_tab|
|<span class="nerdfont big">&#xf812;</span>|mdi_keyboard_variant|
|<span class="nerdfont big">&#xfc43;</span>|mdi_kickstarter|
|<span class="nerdfont big">&#xf813;</span>|mdi_kodi|
|<span class="nerdfont big">&#xf814;</span>|mdi_label|
|<span class="nerdfont big">&#xf815;</span>|mdi_label_outline|
|<span class="nerdfont big">&#xfd2b;</span>|mdi_ladybug|
|<span class="nerdfont big">&#xfb26;</span>|mdi_lambda|
|<span class="nerdfont big">&#xfbb3;</span>|mdi_lamp|
|<span class="nerdfont big">&#xf816;</span>|mdi_lan|
|<span class="nerdfont big">&#xf817;</span>|mdi_lan_connect|
|<span class="nerdfont big">&#xf818;</span>|mdi_lan_disconnect|
|<span class="nerdfont big">&#xf819;</span>|mdi_lan_pending|
|<span class="nerdfont big">&#xfb70;</span>|mdi_language_c|
|<span class="nerdfont big">&#xfb71;</span>|mdi_language_cpp|
|<span class="nerdfont big">&#xf81a;</span>|mdi_language_csharp|
|<span class="nerdfont big">&#xf81b;</span>|mdi_language_css3|
|<span class="nerdfont big">&#xfcd1;</span>|mdi_language_go|
|<span class="nerdfont big">&#xf81c;</span>|mdi_language_html5|
|<span class="nerdfont big">&#xf81d;</span>|mdi_language_javascript|
|<span class="nerdfont big">&#xf81e;</span>|mdi_language_php|
|<span class="nerdfont big">&#xf81f;</span>|mdi_language_python|
|<span class="nerdfont big">&#xf820;</span>|mdi_language_python_text|
|<span class="nerdfont big">&#xfcd2;</span>|mdi_language_r|
|<span class="nerdfont big">&#xfbe3;</span>|mdi_language_swift|
|<span class="nerdfont big">&#xfbe4;</span>|mdi_language_typescript|
|<span class="nerdfont big">&#xf821;</span>|mdi_laptop|
|<span class="nerdfont big">&#xf822;</span>|mdi_laptop_chromebook|
|<span class="nerdfont big">&#xf823;</span>|mdi_laptop_mac|
|<span class="nerdfont big">&#xfbe5;</span>|mdi_laptop_off|
|<span class="nerdfont big">&#xf824;</span>|mdi_laptop_windows|
|<span class="nerdfont big">&#xf825;</span>|mdi_lastfm|
|<span class="nerdfont big">&#xf945;</span>|mdi_lastpass|
|<span class="nerdfont big">&#xf826;</span>|mdi_launch|
|<span class="nerdfont big">&#xfcd3;</span>|mdi_lava_lamp|
|<span class="nerdfont big">&#xf827;</span>|mdi_layers|
|<span class="nerdfont big">&#xf828;</span>|mdi_layers_off|
|<span class="nerdfont big">&#xfb4e;</span>|mdi_lead_pencil|
|<span class="nerdfont big">&#xf829;</span>|mdi_leaf|
|<span class="nerdfont big">&#xf82a;</span>|mdi_led_off|
|<span class="nerdfont big">&#xf82b;</span>|mdi_led_on|
|<span class="nerdfont big">&#xf82c;</span>|mdi_led_outline|
|<span class="nerdfont big">&#xfcd4;</span>|mdi_led_strip|
|<span class="nerdfont big">&#xf82d;</span>|mdi_led_variant_off|
|<span class="nerdfont big">&#xf82e;</span>|mdi_led_variant_on|
|<span class="nerdfont big">&#xf82f;</span>|mdi_led_variant_outline|
|<span class="nerdfont big">&#xf830;</span>|mdi_library|
|<span class="nerdfont big">&#xf831;</span>|mdi_library_books|
|<span class="nerdfont big">&#xf832;</span>|mdi_library_music|
|<span class="nerdfont big">&#xf833;</span>|mdi_library_plus|
|<span class="nerdfont big">&#xf834;</span>|mdi_lightbulb|
|<span class="nerdfont big">&#xfbe6;</span>|mdi_lightbulb_on|
|<span class="nerdfont big">&#xfbe7;</span>|mdi_lightbulb_on_outline|
|<span class="nerdfont big">&#xf835;</span>|mdi_lightbulb_outline|
|<span class="nerdfont big">&#xf836;</span>|mdi_link|
|<span class="nerdfont big">&#xf837;</span>|mdi_link_off|
|<span class="nerdfont big">&#xf838;</span>|mdi_link_variant|
|<span class="nerdfont big">&#xf839;</span>|mdi_link_variant_off|
|<span class="nerdfont big">&#xf83a;</span>|mdi_linkedin|
|<span class="nerdfont big">&#xf83b;</span>|mdi_linkedin_box|
|<span class="nerdfont big">&#xf83c;</span>|mdi_linux|
|<span class="nerdfont big">&#xfc70;</span>|mdi_loading|
|<span class="nerdfont big">&#xf83d;</span>|mdi_lock|
|<span class="nerdfont big">&#xf83e;</span>|mdi_lock_open|
|<span class="nerdfont big">&#xf83f;</span>|mdi_lock_open_outline|
|<span class="nerdfont big">&#xf840;</span>|mdi_lock_outline|
|<span class="nerdfont big">&#xfbe8;</span>|mdi_lock_pattern|
|<span class="nerdfont big">&#xfafa;</span>|mdi_lock_plus|
|<span class="nerdfont big">&#xfc71;</span>|mdi_lock_reset|
|<span class="nerdfont big">&#xfcd5;</span>|mdi_locker|
|<span class="nerdfont big">&#xfcd6;</span>|mdi_locker_multiple|
|<span class="nerdfont big">&#xf841;</span>|mdi_login|
|<span class="nerdfont big">&#xfafb;</span>|mdi_login_variant|
|<span class="nerdfont big">&#xf842;</span>|mdi_logout|
|<span class="nerdfont big">&#xfafc;</span>|mdi_logout_variant|
|<span class="nerdfont big">&#xf843;</span>|mdi_looks|
|<span class="nerdfont big">&#xfbe9;</span>|mdi_loop|
|<span class="nerdfont big">&#xf844;</span>|mdi_loupe|
|<span class="nerdfont big">&#xf845;</span>|mdi_lumx|
|<span class="nerdfont big">&#xf846;</span>|mdi_magnet|
|<span class="nerdfont big">&#xf847;</span>|mdi_magnet_on|
|<span class="nerdfont big">&#xf848;</span>|mdi_magnify|
|<span class="nerdfont big">&#xf849;</span>|mdi_magnify_minus|
|<span class="nerdfont big">&#xfbea;</span>|mdi_magnify_minus_outline|
|<span class="nerdfont big">&#xf84a;</span>|mdi_magnify_plus|
|<span class="nerdfont big">&#xfbeb;</span>|mdi_magnify_plus_outline|
|<span class="nerdfont big">&#xf84b;</span>|mdi_mail_ru|
|<span class="nerdfont big">&#xfbec;</span>|mdi_mailbox|
|<span class="nerdfont big">&#xf84c;</span>|mdi_map|
|<span class="nerdfont big">&#xf84d;</span>|mdi_map_marker|
|<span class="nerdfont big">&#xf84e;</span>|mdi_map_marker_circle|
|<span class="nerdfont big">&#xfb4f;</span>|mdi_map_marker_minus|
|<span class="nerdfont big">&#xf84f;</span>|mdi_map_marker_multiple|
|<span class="nerdfont big">&#xf850;</span>|mdi_map_marker_off|
|<span class="nerdfont big">&#xfcd7;</span>|mdi_map_marker_outline|
|<span class="nerdfont big">&#xfb50;</span>|mdi_map_marker_plus|
|<span class="nerdfont big">&#xf851;</span>|mdi_map_marker_radius|
|<span class="nerdfont big">&#xf852;</span>|mdi_margin|
|<span class="nerdfont big">&#xf853;</span>|mdi_markdown|
|<span class="nerdfont big">&#xfb51;</span>|mdi_marker|
|<span class="nerdfont big">&#xf854;</span>|mdi_marker_check|
|<span class="nerdfont big">&#xf855;</span>|mdi_martini|
|<span class="nerdfont big">&#xf856;</span>|mdi_material_ui|
|<span class="nerdfont big">&#xf857;</span>|mdi_math_compass|
|<span class="nerdfont big">&#xfb27;</span>|mdi_matrix|
|<span class="nerdfont big">&#xf858;</span>|mdi_maxcdn|
|<span class="nerdfont big">&#xfbed;</span>|mdi_medical_bag|
|<span class="nerdfont big">&#xf859;</span>|mdi_medium|
|<span class="nerdfont big">&#xf85a;</span>|mdi_memory|
|<span class="nerdfont big">&#xf85b;</span>|mdi_menu|
|<span class="nerdfont big">&#xf85c;</span>|mdi_menu_down|
|<span class="nerdfont big">&#xfbb4;</span>|mdi_menu_down_outline|
|<span class="nerdfont big">&#xf85d;</span>|mdi_menu_left|
|<span class="nerdfont big">&#xf85e;</span>|mdi_menu_right|
|<span class="nerdfont big">&#xf85f;</span>|mdi_menu_up|
|<span class="nerdfont big">&#xfbb5;</span>|mdi_menu_up_outline|
|<span class="nerdfont big">&#xf860;</span>|mdi_message|
|<span class="nerdfont big">&#xf861;</span>|mdi_message_alert|
|<span class="nerdfont big">&#xfba0;</span>|mdi_message_bulleted|
|<span class="nerdfont big">&#xfba1;</span>|mdi_message_bulleted_off|
|<span class="nerdfont big">&#xf862;</span>|mdi_message_draw|
|<span class="nerdfont big">&#xf863;</span>|mdi_message_image|
|<span class="nerdfont big">&#xf864;</span>|mdi_message_outline|
|<span class="nerdfont big">&#xfb52;</span>|mdi_message_plus|
|<span class="nerdfont big">&#xf865;</span>|mdi_message_processing|
|<span class="nerdfont big">&#xf866;</span>|mdi_message_reply|
|<span class="nerdfont big">&#xf867;</span>|mdi_message_reply_text|
|<span class="nerdfont big">&#xfbee;</span>|mdi_message_settings|
|<span class="nerdfont big">&#xfbef;</span>|mdi_message_settings_variant|
|<span class="nerdfont big">&#xf868;</span>|mdi_message_text|
|<span class="nerdfont big">&#xf869;</span>|mdi_message_text_outline|
|<span class="nerdfont big">&#xf86a;</span>|mdi_message_video|
|<span class="nerdfont big">&#xfb28;</span>|mdi_meteor|
|<span class="nerdfont big">&#xfcd8;</span>|mdi_metronome|
|<span class="nerdfont big">&#xfcd9;</span>|mdi_metronome_tick|
|<span class="nerdfont big">&#xfcda;</span>|mdi_micro_sd|
|<span class="nerdfont big">&#xf86b;</span>|mdi_microphone|
|<span class="nerdfont big">&#xf86c;</span>|mdi_microphone_off|
|<span class="nerdfont big">&#xf86d;</span>|mdi_microphone_outline|
|<span class="nerdfont big">&#xf86e;</span>|mdi_microphone_settings|
|<span class="nerdfont big">&#xf86f;</span>|mdi_microphone_variant|
|<span class="nerdfont big">&#xf870;</span>|mdi_microphone_variant_off|
|<span class="nerdfont big">&#xfb53;</span>|mdi_microscope|
|<span class="nerdfont big">&#xf871;</span>|mdi_microsoft|
|<span class="nerdfont big">&#xf872;</span>|mdi_minecraft|
|<span class="nerdfont big">&#xf873;</span>|mdi_minus|
|<span class="nerdfont big">&#xf874;</span>|mdi_minus_box|
|<span class="nerdfont big">&#xfbf0;</span>|mdi_minus_box_outline|
|<span class="nerdfont big">&#xf875;</span>|mdi_minus_circle|
|<span class="nerdfont big">&#xf876;</span>|mdi_minus_circle_outline|
|<span class="nerdfont big">&#xf877;</span>|mdi_minus_network|
|<span class="nerdfont big">&#xfb29;</span>|mdi_mixcloud|
|<span class="nerdfont big">&#xfcdb;</span>|mdi_mixer|
|<span class="nerdfont big">&#xf878;</span>|mdi_monitor|
|<span class="nerdfont big">&#xf879;</span>|mdi_monitor_multiple|
|<span class="nerdfont big">&#xf87a;</span>|mdi_more|
|<span class="nerdfont big">&#xf87b;</span>|mdi_motorbike|
|<span class="nerdfont big">&#xf87c;</span>|mdi_mouse|
|<span class="nerdfont big">&#xf87d;</span>|mdi_mouse_off|
|<span class="nerdfont big">&#xf87e;</span>|mdi_mouse_variant|
|<span class="nerdfont big">&#xf87f;</span>|mdi_mouse_variant_off|
|<span class="nerdfont big">&#xfb54;</span>|mdi_move_resize|
|<span class="nerdfont big">&#xfb55;</span>|mdi_move_resize_variant|
|<span class="nerdfont big">&#xf880;</span>|mdi_movie|
|<span class="nerdfont big">&#xfcdc;</span>|mdi_movie_roll|
|<span class="nerdfont big">&#xf881;</span>|mdi_multiplication|
|<span class="nerdfont big">&#xf882;</span>|mdi_multiplication_box|
|<span class="nerdfont big">&#xfcdd;</span>|mdi_mushroom|
|<span class="nerdfont big">&#xfcde;</span>|mdi_mushroom_outline|
|<span class="nerdfont big">&#xfc58;</span>|mdi_music|
|<span class="nerdfont big">&#xf883;</span>|mdi_music_box|
|<span class="nerdfont big">&#xf884;</span>|mdi_music_box_outline|
|<span class="nerdfont big">&#xf885;</span>|mdi_music_circle|
|<span class="nerdfont big">&#xf886;</span>|mdi_music_note|
|<span class="nerdfont big">&#xfafd;</span>|mdi_music_note_bluetooth|
|<span class="nerdfont big">&#xfafe;</span>|mdi_music_note_bluetooth_off|
|<span class="nerdfont big">&#xf887;</span>|mdi_music_note_eighth|
|<span class="nerdfont big">&#xf888;</span>|mdi_music_note_half|
|<span class="nerdfont big">&#xf889;</span>|mdi_music_note_off|
|<span class="nerdfont big">&#xf88a;</span>|mdi_music_note_quarter|
|<span class="nerdfont big">&#xf88b;</span>|mdi_music_note_sixteenth|
|<span class="nerdfont big">&#xf88c;</span>|mdi_music_note_whole|
|<span class="nerdfont big">&#xfc59;</span>|mdi_music_off|
|<span class="nerdfont big">&#xf88d;</span>|mdi_nature|
|<span class="nerdfont big">&#xf88e;</span>|mdi_nature_people|
|<span class="nerdfont big">&#xf88f;</span>|mdi_navigation|
|<span class="nerdfont big">&#xfacc;</span>|mdi_near_me|
|<span class="nerdfont big">&#xf890;</span>|mdi_needle|
|<span class="nerdfont big">&#xf891;</span>|mdi_nest_protect|
|<span class="nerdfont big">&#xf892;</span>|mdi_nest_thermostat|
|<span class="nerdfont big">&#xfc44;</span>|mdi_netflix|
|<span class="nerdfont big">&#xfbf1;</span>|mdi_network|
|<span class="nerdfont big">&#xf893;</span>|mdi_new_box|
|<span class="nerdfont big">&#xf894;</span>|mdi_newspaper|
|<span class="nerdfont big">&#xf895;</span>|mdi_nfc|
|<span class="nerdfont big">&#xf896;</span>|mdi_nfc_tap|
|<span class="nerdfont big">&#xf897;</span>|mdi_nfc_variant|
|<span class="nerdfont big">&#xfc72;</span>|mdi_ninja|
|<span class="nerdfont big">&#xfcdf;</span>|mdi_nintendo_switch|
|<span class="nerdfont big">&#xf898;</span>|mdi_nodejs|
|<span class="nerdfont big">&#xf899;</span>|mdi_note|
|<span class="nerdfont big">&#xfbb6;</span>|mdi_note_multiple|
|<span class="nerdfont big">&#xfbb7;</span>|mdi_note_multiple_outline|
|<span class="nerdfont big">&#xf89a;</span>|mdi_note_outline|
|<span class="nerdfont big">&#xf89b;</span>|mdi_note_plus|
|<span class="nerdfont big">&#xf89c;</span>|mdi_note_plus_outline|
|<span class="nerdfont big">&#xf89d;</span>|mdi_note_text|
|<span class="nerdfont big">&#xfd2c;</span>|mdi_notebook|
|<span class="nerdfont big">&#xf89e;</span>|mdi_notification_clear_all|
|<span class="nerdfont big">&#xfbf5;</span>|mdi_npm|
|<span class="nerdfont big">&#xfba2;</span>|mdi_nuke|
|<span class="nerdfont big">&#xfce0;</span>|mdi_null|
|<span class="nerdfont big">&#xf89f;</span>|mdi_numeric|
|<span class="nerdfont big">&#xf8a0;</span>|mdi_numeric_0_box|
|<span class="nerdfont big">&#xf8a1;</span>|mdi_numeric_0_box_multiple_outline|
|<span class="nerdfont big">&#xf8a2;</span>|mdi_numeric_0_box_outline|
|<span class="nerdfont big">&#xf8a3;</span>|mdi_numeric_1_box|
|<span class="nerdfont big">&#xf8a4;</span>|mdi_numeric_1_box_multiple_outline|
|<span class="nerdfont big">&#xf8a5;</span>|mdi_numeric_1_box_outline|
|<span class="nerdfont big">&#xf8a6;</span>|mdi_numeric_2_box|
|<span class="nerdfont big">&#xf8a7;</span>|mdi_numeric_2_box_multiple_outline|
|<span class="nerdfont big">&#xf8a8;</span>|mdi_numeric_2_box_outline|
|<span class="nerdfont big">&#xf8a9;</span>|mdi_numeric_3_box|
|<span class="nerdfont big">&#xf8aa;</span>|mdi_numeric_3_box_multiple_outline|
|<span class="nerdfont big">&#xf8ab;</span>|mdi_numeric_3_box_outline|
|<span class="nerdfont big">&#xf8ac;</span>|mdi_numeric_4_box|
|<span class="nerdfont big">&#xf8ad;</span>|mdi_numeric_4_box_multiple_outline|
|<span class="nerdfont big">&#xf8ae;</span>|mdi_numeric_4_box_outline|
|<span class="nerdfont big">&#xf8af;</span>|mdi_numeric_5_box|
|<span class="nerdfont big">&#xf8b0;</span>|mdi_numeric_5_box_multiple_outline|
|<span class="nerdfont big">&#xf8b1;</span>|mdi_numeric_5_box_outline|
|<span class="nerdfont big">&#xf8b2;</span>|mdi_numeric_6_box|
|<span class="nerdfont big">&#xf8b3;</span>|mdi_numeric_6_box_multiple_outline|
|<span class="nerdfont big">&#xf8b4;</span>|mdi_numeric_6_box_outline|
|<span class="nerdfont big">&#xf8b5;</span>|mdi_numeric_7_box|
|<span class="nerdfont big">&#xf8b6;</span>|mdi_numeric_7_box_multiple_outline|
|<span class="nerdfont big">&#xf8b7;</span>|mdi_numeric_7_box_outline|
|<span class="nerdfont big">&#xf8b8;</span>|mdi_numeric_8_box|
|<span class="nerdfont big">&#xf8b9;</span>|mdi_numeric_8_box_multiple_outline|
|<span class="nerdfont big">&#xf8ba;</span>|mdi_numeric_8_box_outline|
|<span class="nerdfont big">&#xf8bb;</span>|mdi_numeric_9_box|
|<span class="nerdfont big">&#xf8bc;</span>|mdi_numeric_9_box_multiple_outline|
|<span class="nerdfont big">&#xf8bd;</span>|mdi_numeric_9_box_outline|
|<span class="nerdfont big">&#xf8be;</span>|mdi_numeric_9_plus_box|
|<span class="nerdfont big">&#xf8bf;</span>|mdi_numeric_9_plus_box_multiple_outline|
|<span class="nerdfont big">&#xf8c0;</span>|mdi_numeric_9_plus_box_outline|
|<span class="nerdfont big">&#xfbf6;</span>|mdi_nut|
|<span class="nerdfont big">&#xf8c1;</span>|mdi_nutrition|
|<span class="nerdfont big">&#xfb7a;</span>|mdi_oar|
|<span class="nerdfont big">&#xf8c2;</span>|mdi_octagon|
|<span class="nerdfont big">&#xf8c3;</span>|mdi_octagon_outline|
|<span class="nerdfont big">&#xfbf7;</span>|mdi_octagram|
|<span class="nerdfont big">&#xfc73;</span>|mdi_octagram_outline|
|<span class="nerdfont big">&#xf8c4;</span>|mdi_odnoklassniki|
|<span class="nerdfont big">&#xf8c5;</span>|mdi_office|
|<span class="nerdfont big">&#xf8c6;</span>|mdi_oil|
|<span class="nerdfont big">&#xf8c7;</span>|mdi_oil_temperature|
|<span class="nerdfont big">&#xf8c8;</span>|mdi_omega|
|<span class="nerdfont big">&#xf8c9;</span>|mdi_onedrive|
|<span class="nerdfont big">&#xfc45;</span>|mdi_onenote|
|<span class="nerdfont big">&#xfacb;</span>|mdi_opacity|
|<span class="nerdfont big">&#xf8ca;</span>|mdi_open_in_app|
|<span class="nerdfont big">&#xf8cb;</span>|mdi_open_in_new|
|<span class="nerdfont big">&#xf8cc;</span>|mdi_openid|
|<span class="nerdfont big">&#xf8cd;</span>|mdi_opera|
|<span class="nerdfont big">&#xf517;</span>|mdi_orbit|
|<span class="nerdfont big">&#xf8ce;</span>|mdi_ornament|
|<span class="nerdfont big">&#xf8cf;</span>|mdi_ornament_variant|
|<span class="nerdfont big">&#xf8d1;</span>|mdi_owl|
|<span class="nerdfont big">&#xf8d2;</span>|mdi_package|
|<span class="nerdfont big">&#xf8d3;</span>|mdi_package_down|
|<span class="nerdfont big">&#xf8d4;</span>|mdi_package_up|
|<span class="nerdfont big">&#xf8d5;</span>|mdi_package_variant|
|<span class="nerdfont big">&#xf8d6;</span>|mdi_package_variant_closed|
|<span class="nerdfont big">&#xfaff;</span>|mdi_page_first|
|<span class="nerdfont big">&#xfb00;</span>|mdi_page_last|
|<span class="nerdfont big">&#xfbf8;</span>|mdi_page_layout_body|
|<span class="nerdfont big">&#xfbf9;</span>|mdi_page_layout_footer|
|<span class="nerdfont big">&#xfbfa;</span>|mdi_page_layout_header|
|<span class="nerdfont big">&#xfbfb;</span>|mdi_page_layout_sidebar_left|
|<span class="nerdfont big">&#xfbfc;</span>|mdi_page_layout_sidebar_right|
|<span class="nerdfont big">&#xf8d7;</span>|mdi_palette|
|<span class="nerdfont big">&#xf8d8;</span>|mdi_palette_advanced|
|<span class="nerdfont big">&#xf8d9;</span>|mdi_panda|
|<span class="nerdfont big">&#xf8da;</span>|mdi_pandora|
|<span class="nerdfont big">&#xf8db;</span>|mdi_panorama|
|<span class="nerdfont big">&#xf8dc;</span>|mdi_panorama_fisheye|
|<span class="nerdfont big">&#xf8dd;</span>|mdi_panorama_horizontal|
|<span class="nerdfont big">&#xf8de;</span>|mdi_panorama_vertical|
|<span class="nerdfont big">&#xf8df;</span>|mdi_panorama_wide_angle|
|<span class="nerdfont big">&#xf8e0;</span>|mdi_paper_cut_vertical|
|<span class="nerdfont big">&#xf8e1;</span>|mdi_paperclip|
|<span class="nerdfont big">&#xf8e2;</span>|mdi_parking|
|<span class="nerdfont big">&#xfce1;</span>|mdi_passport|
|<span class="nerdfont big">&#xf8e3;</span>|mdi_pause|
|<span class="nerdfont big">&#xf8e4;</span>|mdi_pause_circle|
|<span class="nerdfont big">&#xf8e5;</span>|mdi_pause_circle_outline|
|<span class="nerdfont big">&#xf8e6;</span>|mdi_pause_octagon|
|<span class="nerdfont big">&#xf8e7;</span>|mdi_pause_octagon_outline|
|<span class="nerdfont big">&#xf8e8;</span>|mdi_paw|
|<span class="nerdfont big">&#xfb56;</span>|mdi_paw_off|
|<span class="nerdfont big">&#xf8e9;</span>|mdi_pen|
|<span class="nerdfont big">&#xf8ea;</span>|mdi_pencil|
|<span class="nerdfont big">&#xf8eb;</span>|mdi_pencil_box|
|<span class="nerdfont big">&#xf8ec;</span>|mdi_pencil_box_outline|
|<span class="nerdfont big">&#xfbfd;</span>|mdi_pencil_circle|
|<span class="nerdfont big">&#xfc74;</span>|mdi_pencil_circle_outline|
|<span class="nerdfont big">&#xf8ed;</span>|mdi_pencil_lock|
|<span class="nerdfont big">&#xf8ee;</span>|mdi_pencil_off|
|<span class="nerdfont big">&#xfbfe;</span>|mdi_pentagon|
|<span class="nerdfont big">&#xfbff;</span>|mdi_pentagon_outline|
|<span class="nerdfont big">&#xf8ef;</span>|mdi_percent|
|<span class="nerdfont big">&#xfce2;</span>|mdi_periodic_table_co2|
|<span class="nerdfont big">&#xfc46;</span>|mdi_periscope|
|<span class="nerdfont big">&#xf8f0;</span>|mdi_pharmacy|
|<span class="nerdfont big">&#xf8f1;</span>|mdi_phone|
|<span class="nerdfont big">&#xf8f2;</span>|mdi_phone_bluetooth|
|<span class="nerdfont big">&#xfb01;</span>|mdi_phone_classic|
|<span class="nerdfont big">&#xf8f3;</span>|mdi_phone_forward|
|<span class="nerdfont big">&#xf8f4;</span>|mdi_phone_hangup|
|<span class="nerdfont big">&#xf8f5;</span>|mdi_phone_in_talk|
|<span class="nerdfont big">&#xf8f6;</span>|mdi_phone_incoming|
|<span class="nerdfont big">&#xf8f7;</span>|mdi_phone_locked|
|<span class="nerdfont big">&#xf8f8;</span>|mdi_phone_log|
|<span class="nerdfont big">&#xfb57;</span>|mdi_phone_minus|
|<span class="nerdfont big">&#xf8f9;</span>|mdi_phone_missed|
|<span class="nerdfont big">&#xf8fa;</span>|mdi_phone_outgoing|
|<span class="nerdfont big">&#xf8fb;</span>|mdi_phone_paused|
|<span class="nerdfont big">&#xfb58;</span>|mdi_phone_plus|
|<span class="nerdfont big">&#xfd2d;</span>|mdi_phone_return|
|<span class="nerdfont big">&#xf8fc;</span>|mdi_phone_settings|
|<span class="nerdfont big">&#xf8fd;</span>|mdi_phone_voip|
|<span class="nerdfont big">&#xf8fe;</span>|mdi_pi|
|<span class="nerdfont big">&#xf8ff;</span>|mdi_pi_box|
|<span class="nerdfont big">&#xfb7b;</span>|mdi_piano|
|<span class="nerdfont big">&#xf900;</span>|mdi_pig|
|<span class="nerdfont big">&#xf901;</span>|mdi_pill|
|<span class="nerdfont big">&#xfc00;</span>|mdi_pillar|
|<span class="nerdfont big">&#xf902;</span>|mdi_pin|
|<span class="nerdfont big">&#xf903;</span>|mdi_pin_off|
|<span class="nerdfont big">&#xf904;</span>|mdi_pine_tree|
|<span class="nerdfont big">&#xf905;</span>|mdi_pine_tree_box|
|<span class="nerdfont big">&#xf906;</span>|mdi_pinterest|
|<span class="nerdfont big">&#xf907;</span>|mdi_pinterest_box|
|<span class="nerdfont big">&#xfce3;</span>|mdi_pipe|
|<span class="nerdfont big">&#xfce4;</span>|mdi_pipe_disconnected|
|<span class="nerdfont big">&#xfc01;</span>|mdi_pistol|
|<span class="nerdfont big">&#xf908;</span>|mdi_pizza|
|<span class="nerdfont big">&#xfbb9;</span>|mdi_plane_shield|
|<span class="nerdfont big">&#xf909;</span>|mdi_play|
|<span class="nerdfont big">&#xf90a;</span>|mdi_play_box_outline|
|<span class="nerdfont big">&#xf90b;</span>|mdi_play_circle|
|<span class="nerdfont big">&#xf90c;</span>|mdi_play_circle_outline|
|<span class="nerdfont big">&#xf90d;</span>|mdi_play_pause|
|<span class="nerdfont big">&#xf90e;</span>|mdi_play_protected_content|
|<span class="nerdfont big">&#xfac6;</span>|mdi_playlist_check|
|<span class="nerdfont big">&#xf90f;</span>|mdi_playlist_minus|
|<span class="nerdfont big">&#xf910;</span>|mdi_playlist_play|
|<span class="nerdfont big">&#xf911;</span>|mdi_playlist_plus|
|<span class="nerdfont big">&#xf912;</span>|mdi_playlist_remove|
|<span class="nerdfont big">&#xf913;</span>|mdi_playstation|
|<span class="nerdfont big">&#xfbb8;</span>|mdi_plex|
|<span class="nerdfont big">&#xf914;</span>|mdi_plus|
|<span class="nerdfont big">&#xf915;</span>|mdi_plus_box|
|<span class="nerdfont big">&#xfc02;</span>|mdi_plus_box_outline|
|<span class="nerdfont big">&#xf916;</span>|mdi_plus_circle|
|<span class="nerdfont big">&#xf917;</span>|mdi_plus_circle_multiple_outline|
|<span class="nerdfont big">&#xf918;</span>|mdi_plus_circle_outline|
|<span class="nerdfont big">&#xf919;</span>|mdi_plus_network|
|<span class="nerdfont big">&#xf91a;</span>|mdi_plus_one|
|<span class="nerdfont big">&#xfc03;</span>|mdi_plus_outline|
|<span class="nerdfont big">&#xf91b;</span>|mdi_pocket|
|<span class="nerdfont big">&#xf91c;</span>|mdi_pokeball|
|<span class="nerdfont big">&#xfd2e;</span>|mdi_poker_chip|
|<span class="nerdfont big">&#xf91d;</span>|mdi_polaroid|
|<span class="nerdfont big">&#xf91e;</span>|mdi_poll|
|<span class="nerdfont big">&#xf91f;</span>|mdi_poll_box|
|<span class="nerdfont big">&#xf920;</span>|mdi_polymer|
|<span class="nerdfont big">&#xfb05;</span>|mdi_pool|
|<span class="nerdfont big">&#xf921;</span>|mdi_popcorn|
|<span class="nerdfont big">&#xfb59;</span>|mdi_pot|
|<span class="nerdfont big">&#xfb5a;</span>|mdi_pot_mix|
|<span class="nerdfont big">&#xf922;</span>|mdi_pound|
|<span class="nerdfont big">&#xf923;</span>|mdi_pound_box|
|<span class="nerdfont big">&#xf924;</span>|mdi_power|
|<span class="nerdfont big">&#xfba3;</span>|mdi_power_plug|
|<span class="nerdfont big">&#xfba4;</span>|mdi_power_plug_off|
|<span class="nerdfont big">&#xf925;</span>|mdi_power_settings|
|<span class="nerdfont big">&#xf926;</span>|mdi_power_socket|
|<span class="nerdfont big">&#xfce5;</span>|mdi_power_socket_eu|
|<span class="nerdfont big">&#xfce6;</span>|mdi_power_socket_uk|
|<span class="nerdfont big">&#xfce7;</span>|mdi_power_socket_us|
|<span class="nerdfont big">&#xfc04;</span>|mdi_prescription|
|<span class="nerdfont big">&#xf927;</span>|mdi_presentation|
|<span class="nerdfont big">&#xf928;</span>|mdi_presentation_play|
|<span class="nerdfont big">&#xf929;</span>|mdi_printer|
|<span class="nerdfont big">&#xf92a;</span>|mdi_printer_3d|
|<span class="nerdfont big">&#xf92b;</span>|mdi_printer_alert|
|<span class="nerdfont big">&#xfc05;</span>|mdi_printer_settings|
|<span class="nerdfont big">&#xfb02;</span>|mdi_priority_high|
|<span class="nerdfont big">&#xfb03;</span>|mdi_priority_low|
|<span class="nerdfont big">&#xf92c;</span>|mdi_professional_hexagon|
|<span class="nerdfont big">&#xf92d;</span>|mdi_projector|
|<span class="nerdfont big">&#xf92e;</span>|mdi_projector_screen|
|<span class="nerdfont big">&#xfba5;</span>|mdi_publish|
|<span class="nerdfont big">&#xf92f;</span>|mdi_pulse|
|<span class="nerdfont big">&#xf930;</span>|mdi_puzzle|
|<span class="nerdfont big">&#xfb04;</span>|mdi_qqchat|
|<span class="nerdfont big">&#xf931;</span>|mdi_qrcode|
|<span class="nerdfont big">&#xf932;</span>|mdi_qrcode_scan|
|<span class="nerdfont big">&#xf933;</span>|mdi_quadcopter|
|<span class="nerdfont big">&#xf934;</span>|mdi_quality_high|
|<span class="nerdfont big">&#xf935;</span>|mdi_quicktime|
|<span class="nerdfont big">&#xf936;</span>|mdi_radar|
|<span class="nerdfont big">&#xf937;</span>|mdi_radiator|
|<span class="nerdfont big">&#xf938;</span>|mdi_radio|
|<span class="nerdfont big">&#xf939;</span>|mdi_radio_handheld|
|<span class="nerdfont big">&#xf93a;</span>|mdi_radio_tower|
|<span class="nerdfont big">&#xf93b;</span>|mdi_radioactive|
|<span class="nerdfont big">&#xf93c;</span>|mdi_radiobox_blank|
|<span class="nerdfont big">&#xf93d;</span>|mdi_radiobox_marked|
|<span class="nerdfont big">&#xf93e;</span>|mdi_raspberrypi|
|<span class="nerdfont big">&#xf93f;</span>|mdi_ray_end|
|<span class="nerdfont big">&#xf940;</span>|mdi_ray_end_arrow|
|<span class="nerdfont big">&#xf941;</span>|mdi_ray_start|
|<span class="nerdfont big">&#xf942;</span>|mdi_ray_start_arrow|
|<span class="nerdfont big">&#xf943;</span>|mdi_ray_start_end|
|<span class="nerdfont big">&#xf944;</span>|mdi_ray_vertex|
|<span class="nerdfont big">&#xfc06;</span>|mdi_react|
|<span class="nerdfont big">&#xf946;</span>|mdi_read|
|<span class="nerdfont big">&#xf948;</span>|mdi_receipt|
|<span class="nerdfont big">&#xf949;</span>|mdi_record|
|<span class="nerdfont big">&#xf94a;</span>|mdi_record_rec|
|<span class="nerdfont big">&#xf94b;</span>|mdi_recycle|
|<span class="nerdfont big">&#xf94c;</span>|mdi_reddit|
|<span class="nerdfont big">&#xf94d;</span>|mdi_redo|
|<span class="nerdfont big">&#xf94e;</span>|mdi_redo_variant|
|<span class="nerdfont big">&#xf94f;</span>|mdi_refresh|
|<span class="nerdfont big">&#xf950;</span>|mdi_regex|
|<span class="nerdfont big">&#xf951;</span>|mdi_relative_scale|
|<span class="nerdfont big">&#xf952;</span>|mdi_reload|
|<span class="nerdfont big">&#xf953;</span>|mdi_remote|
|<span class="nerdfont big">&#xf954;</span>|mdi_rename_box|
|<span class="nerdfont big">&#xfb86;</span>|mdi_reorder_horizontal|
|<span class="nerdfont big">&#xfb87;</span>|mdi_reorder_vertical|
|<span class="nerdfont big">&#xf955;</span>|mdi_repeat|
|<span class="nerdfont big">&#xf956;</span>|mdi_repeat_off|
|<span class="nerdfont big">&#xf957;</span>|mdi_repeat_once|
|<span class="nerdfont big">&#xf958;</span>|mdi_replay|
|<span class="nerdfont big">&#xf959;</span>|mdi_reply|
|<span class="nerdfont big">&#xf95a;</span>|mdi_reply_all|
|<span class="nerdfont big">&#xf95b;</span>|mdi_reproduction|
|<span class="nerdfont big">&#xf95c;</span>|mdi_resize_bottom_right|
|<span class="nerdfont big">&#xf95d;</span>|mdi_responsive|
|<span class="nerdfont big">&#xfc07;</span>|mdi_restart|
|<span class="nerdfont big">&#xfba6;</span>|mdi_restore|
|<span class="nerdfont big">&#xf95e;</span>|mdi_rewind|
|<span class="nerdfont big">&#xfc08;</span>|mdi_rewind_outline|
|<span class="nerdfont big">&#xfc09;</span>|mdi_rhombus|
|<span class="nerdfont big">&#xfc0a;</span>|mdi_rhombus_outline|
|<span class="nerdfont big">&#xf95f;</span>|mdi_ribbon|
|<span class="nerdfont big">&#xfce8;</span>|mdi_rice|
|<span class="nerdfont big">&#xfce9;</span>|mdi_ring|
|<span class="nerdfont big">&#xf960;</span>|mdi_road|
|<span class="nerdfont big">&#xf961;</span>|mdi_road_variant|
|<span class="nerdfont big">&#xfba7;</span>|mdi_robot|
|<span class="nerdfont big">&#xf962;</span>|mdi_rocket|
|<span class="nerdfont big">&#xfc0b;</span>|mdi_roomba|
|<span class="nerdfont big">&#xf963;</span>|mdi_rotate_3d|
|<span class="nerdfont big">&#xf964;</span>|mdi_rotate_left|
|<span class="nerdfont big">&#xf965;</span>|mdi_rotate_left_variant|
|<span class="nerdfont big">&#xf966;</span>|mdi_rotate_right|
|<span class="nerdfont big">&#xf967;</span>|mdi_rotate_right_variant|
|<span class="nerdfont big">&#xfb06;</span>|mdi_rounded_corner|
|<span class="nerdfont big">&#xf968;</span>|mdi_router_wireless|
|<span class="nerdfont big">&#xf969;</span>|mdi_routes|
|<span class="nerdfont big">&#xfb07;</span>|mdi_rowing|
|<span class="nerdfont big">&#xf96a;</span>|mdi_rss|
|<span class="nerdfont big">&#xf96b;</span>|mdi_rss_box|
|<span class="nerdfont big">&#xf96c;</span>|mdi_ruler|
|<span class="nerdfont big">&#xfc0c;</span>|mdi_run|
|<span class="nerdfont big">&#xf96d;</span>|mdi_run_fast|
|<span class="nerdfont big">&#xf96e;</span>|mdi_sale|
|<span class="nerdfont big">&#xfcea;</span>|mdi_sass|
|<span class="nerdfont big">&#xf96f;</span>|mdi_satellite|
|<span class="nerdfont big">&#xf970;</span>|mdi_satellite_variant|
|<span class="nerdfont big">&#xfb08;</span>|mdi_saxophone|
|<span class="nerdfont big">&#xf971;</span>|mdi_scale|
|<span class="nerdfont big">&#xfad0;</span>|mdi_scale_balance|
|<span class="nerdfont big">&#xf972;</span>|mdi_scale_bathroom|
|<span class="nerdfont big">&#xfba9;</span>|mdi_scanner|
|<span class="nerdfont big">&#xf973;</span>|mdi_school|
|<span class="nerdfont big">&#xf974;</span>|mdi_screen_rotation|
|<span class="nerdfont big">&#xf975;</span>|mdi_screen_rotation_lock|
|<span class="nerdfont big">&#xf976;</span>|mdi_screwdriver|
|<span class="nerdfont big">&#xf977;</span>|mdi_script|
|<span class="nerdfont big">&#xf978;</span>|mdi_sd|
|<span class="nerdfont big">&#xf979;</span>|mdi_seal|
|<span class="nerdfont big">&#xfc0d;</span>|mdi_search_web|
|<span class="nerdfont big">&#xf97a;</span>|mdi_seat_flat|
|<span class="nerdfont big">&#xf97b;</span>|mdi_seat_flat_angled|
|<span class="nerdfont big">&#xf97c;</span>|mdi_seat_individual_suite|
|<span class="nerdfont big">&#xf97d;</span>|mdi_seat_legroom_extra|
|<span class="nerdfont big">&#xf97e;</span>|mdi_seat_legroom_normal|
|<span class="nerdfont big">&#xf97f;</span>|mdi_seat_legroom_reduced|
|<span class="nerdfont big">&#xf980;</span>|mdi_seat_recline_extra|
|<span class="nerdfont big">&#xf981;</span>|mdi_seat_recline_normal|
|<span class="nerdfont big">&#xf982;</span>|mdi_security|
|<span class="nerdfont big">&#xfb88;</span>|mdi_security_home|
|<span class="nerdfont big">&#xf983;</span>|mdi_security_network|
|<span class="nerdfont big">&#xf984;</span>|mdi_select|
|<span class="nerdfont big">&#xf985;</span>|mdi_select_all|
|<span class="nerdfont big">&#xf986;</span>|mdi_select_inverse|
|<span class="nerdfont big">&#xf987;</span>|mdi_select_off|
|<span class="nerdfont big">&#xf988;</span>|mdi_selection|
|<span class="nerdfont big">&#xfc75;</span>|mdi_selection_off|
|<span class="nerdfont big">&#xf989;</span>|mdi_send|
|<span class="nerdfont big">&#xfceb;</span>|mdi_send_secure|
|<span class="nerdfont big">&#xfb5b;</span>|mdi_serial_port|
|<span class="nerdfont big">&#xf98a;</span>|mdi_server|
|<span class="nerdfont big">&#xf98b;</span>|mdi_server_minus|
|<span class="nerdfont big">&#xf98c;</span>|mdi_server_network|
|<span class="nerdfont big">&#xf98d;</span>|mdi_server_network_off|
|<span class="nerdfont big">&#xf98e;</span>|mdi_server_off|
|<span class="nerdfont big">&#xf98f;</span>|mdi_server_plus|
|<span class="nerdfont big">&#xf990;</span>|mdi_server_remove|
|<span class="nerdfont big">&#xf991;</span>|mdi_server_security|
|<span class="nerdfont big">&#xfc76;</span>|mdi_set_all|
|<span class="nerdfont big">&#xfc77;</span>|mdi_set_center|
|<span class="nerdfont big">&#xfc78;</span>|mdi_set_center_right|
|<span class="nerdfont big">&#xfc79;</span>|mdi_set_left|
|<span class="nerdfont big">&#xfc7a;</span>|mdi_set_left_center|
|<span class="nerdfont big">&#xfc7b;</span>|mdi_set_left_right|
|<span class="nerdfont big">&#xfc7c;</span>|mdi_set_none|
|<span class="nerdfont big">&#xfc7d;</span>|mdi_set_right|
|<span class="nerdfont big">&#xf992;</span>|mdi_settings|
|<span class="nerdfont big">&#xf993;</span>|mdi_settings_box|
|<span class="nerdfont big">&#xfd2f;</span>|mdi_shape|
|<span class="nerdfont big">&#xfb5c;</span>|mdi_shape_circle_plus|
|<span class="nerdfont big">&#xfd30;</span>|mdi_shape_outline|
|<span class="nerdfont big">&#xf994;</span>|mdi_shape_plus|
|<span class="nerdfont big">&#xfb5d;</span>|mdi_shape_polygon_plus|
|<span class="nerdfont big">&#xfb5e;</span>|mdi_shape_rectangle_plus|
|<span class="nerdfont big">&#xfb5f;</span>|mdi_shape_square_plus|
|<span class="nerdfont big">&#xf995;</span>|mdi_share|
|<span class="nerdfont big">&#xf996;</span>|mdi_share_variant|
|<span class="nerdfont big">&#xf997;</span>|mdi_shield|
|<span class="nerdfont big">&#xfc7e;</span>|mdi_shield_half_full|
|<span class="nerdfont big">&#xf998;</span>|mdi_shield_outline|
|<span class="nerdfont big">&#xfd31;</span>|mdi_ship_wheel|
|<span class="nerdfont big">&#xf999;</span>|mdi_shopping|
|<span class="nerdfont big">&#xf99a;</span>|mdi_shopping_music|
|<span class="nerdfont big">&#xfc0e;</span>|mdi_shovel|
|<span class="nerdfont big">&#xfc0f;</span>|mdi_shovel_off|
|<span class="nerdfont big">&#xf99b;</span>|mdi_shredder|
|<span class="nerdfont big">&#xf99c;</span>|mdi_shuffle|
|<span class="nerdfont big">&#xf99d;</span>|mdi_shuffle_disabled|
|<span class="nerdfont big">&#xf99e;</span>|mdi_shuffle_variant|
|<span class="nerdfont big">&#xf99f;</span>|mdi_sigma|
|<span class="nerdfont big">&#xfb2a;</span>|mdi_sigma_lower|
|<span class="nerdfont big">&#xf9a0;</span>|mdi_sign_caution|
|<span class="nerdfont big">&#xfc7f;</span>|mdi_sign_direction|
|<span class="nerdfont big">&#xfc80;</span>|mdi_sign_text|
|<span class="nerdfont big">&#xf9a1;</span>|mdi_signal|
|<span class="nerdfont big">&#xfc10;</span>|mdi_signal_2g|
|<span class="nerdfont big">&#xfc11;</span>|mdi_signal_3g|
|<span class="nerdfont big">&#xfc12;</span>|mdi_signal_4g|
|<span class="nerdfont big">&#xfc13;</span>|mdi_signal_hspa|
|<span class="nerdfont big">&#xfc14;</span>|mdi_signal_hspa_plus|
|<span class="nerdfont big">&#xfc81;</span>|mdi_signal_off|
|<span class="nerdfont big">&#xfb09;</span>|mdi_signal_variant|
|<span class="nerdfont big">&#xf9a2;</span>|mdi_silverware|
|<span class="nerdfont big">&#xf9a3;</span>|mdi_silverware_fork|
|<span class="nerdfont big">&#xf9a4;</span>|mdi_silverware_spoon|
|<span class="nerdfont big">&#xf9a5;</span>|mdi_silverware_variant|
|<span class="nerdfont big">&#xf9a6;</span>|mdi_sim|
|<span class="nerdfont big">&#xf9a7;</span>|mdi_sim_alert|
|<span class="nerdfont big">&#xf9a8;</span>|mdi_sim_off|
|<span class="nerdfont big">&#xf9a9;</span>|mdi_sitemap|
|<span class="nerdfont big">&#xf9aa;</span>|mdi_skip_backward|
|<span class="nerdfont big">&#xf9ab;</span>|mdi_skip_forward|
|<span class="nerdfont big">&#xf9ac;</span>|mdi_skip_next|
|<span class="nerdfont big">&#xfb60;</span>|mdi_skip_next_circle|
|<span class="nerdfont big">&#xfb61;</span>|mdi_skip_next_circle_outline|
|<span class="nerdfont big">&#xf9ad;</span>|mdi_skip_previous|
|<span class="nerdfont big">&#xfb62;</span>|mdi_skip_previous_circle|
|<span class="nerdfont big">&#xfb63;</span>|mdi_skip_previous_circle_outline|
|<span class="nerdfont big">&#xfb8a;</span>|mdi_skull|
|<span class="nerdfont big">&#xf9ae;</span>|mdi_skype|
|<span class="nerdfont big">&#xf9af;</span>|mdi_skype_business|
|<span class="nerdfont big">&#xf9b0;</span>|mdi_slack|
|<span class="nerdfont big">&#xf9b1;</span>|mdi_sleep|
|<span class="nerdfont big">&#xf9b2;</span>|mdi_sleep_off|
|<span class="nerdfont big">&#xf9b3;</span>|mdi_smoking|
|<span class="nerdfont big">&#xf9b4;</span>|mdi_smoking_off|
|<span class="nerdfont big">&#xf9b5;</span>|mdi_snapchat|
|<span class="nerdfont big">&#xfc15;</span>|mdi_snowflake|
|<span class="nerdfont big">&#xf9b6;</span>|mdi_snowman|
|<span class="nerdfont big">&#xf9b7;</span>|mdi_soccer|
|<span class="nerdfont big">&#xfd32;</span>|mdi_soccer_field|
|<span class="nerdfont big">&#xf9b8;</span>|mdi_sofa|
|<span class="nerdfont big">&#xfb8b;</span>|mdi_solid|
|<span class="nerdfont big">&#xf9b9;</span>|mdi_sort|
|<span class="nerdfont big">&#xf9ba;</span>|mdi_sort_alphabetical|
|<span class="nerdfont big">&#xf9bb;</span>|mdi_sort_ascending|
|<span class="nerdfont big">&#xf9bc;</span>|mdi_sort_descending|
|<span class="nerdfont big">&#xf9bd;</span>|mdi_sort_numeric|
|<span class="nerdfont big">&#xf9be;</span>|mdi_sort_variant|
|<span class="nerdfont big">&#xf9bf;</span>|mdi_soundcloud|
|<span class="nerdfont big">&#xfb2b;</span>|mdi_source_branch|
|<span class="nerdfont big">&#xfc16;</span>|mdi_source_commit|
|<span class="nerdfont big">&#xfc17;</span>|mdi_source_commit_end|
|<span class="nerdfont big">&#xfc18;</span>|mdi_source_commit_end_local|
|<span class="nerdfont big">&#xfc19;</span>|mdi_source_commit_local|
|<span class="nerdfont big">&#xfc1a;</span>|mdi_source_commit_next_local|
|<span class="nerdfont big">&#xfc1b;</span>|mdi_source_commit_start|
|<span class="nerdfont big">&#xfc1c;</span>|mdi_source_commit_start_next_local|
|<span class="nerdfont big">&#xf9c0;</span>|mdi_source_fork|
|<span class="nerdfont big">&#xfb2c;</span>|mdi_source_merge|
|<span class="nerdfont big">&#xf9c1;</span>|mdi_source_pull|
|<span class="nerdfont big">&#xfcec;</span>|mdi_soy_sauce|
|<span class="nerdfont big">&#xf9c2;</span>|mdi_speaker|
|<span class="nerdfont big">&#xf9c3;</span>|mdi_speaker_off|
|<span class="nerdfont big">&#xfc1d;</span>|mdi_speaker_wireless|
|<span class="nerdfont big">&#xf9c4;</span>|mdi_speedometer|
|<span class="nerdfont big">&#xf9c5;</span>|mdi_spellcheck|
|<span class="nerdfont big">&#xf9c6;</span>|mdi_spotify|
|<span class="nerdfont big">&#xf9c7;</span>|mdi_spotlight|
|<span class="nerdfont big">&#xf9c8;</span>|mdi_spotlight_beam|
|<span class="nerdfont big">&#xfb64;</span>|mdi_spray|
|<span class="nerdfont big">&#xfc62;</span>|mdi_square|
|<span class="nerdfont big">&#xf9c9;</span>|mdi_square_inc|
|<span class="nerdfont big">&#xf9ca;</span>|mdi_square_inc_cash|
|<span class="nerdfont big">&#xfc61;</span>|mdi_square_outline|
|<span class="nerdfont big">&#xfc82;</span>|mdi_square_root|
|<span class="nerdfont big">&#xf9cb;</span>|mdi_stack_overflow|
|<span class="nerdfont big">&#xfb0a;</span>|mdi_stackexchange|
|<span class="nerdfont big">&#xfc1e;</span>|mdi_stadium|
|<span class="nerdfont big">&#xf9cc;</span>|mdi_stairs|
|<span class="nerdfont big">&#xfced;</span>|mdi_standard_definition|
|<span class="nerdfont big">&#xf9cd;</span>|mdi_star|
|<span class="nerdfont big">&#xf9ce;</span>|mdi_star_circle|
|<span class="nerdfont big">&#xf9cf;</span>|mdi_star_half|
|<span class="nerdfont big">&#xf9d0;</span>|mdi_star_off|
|<span class="nerdfont big">&#xf9d1;</span>|mdi_star_outline|
|<span class="nerdfont big">&#xf9d2;</span>|mdi_steam|
|<span class="nerdfont big">&#xf9d3;</span>|mdi_steering|
|<span class="nerdfont big">&#xf9d4;</span>|mdi_step_backward|
|<span class="nerdfont big">&#xf9d5;</span>|mdi_step_backward_2|
|<span class="nerdfont big">&#xf9d6;</span>|mdi_step_forward|
|<span class="nerdfont big">&#xf9d7;</span>|mdi_step_forward_2|
|<span class="nerdfont big">&#xf9d8;</span>|mdi_stethoscope|
|<span class="nerdfont big">&#xfacf;</span>|mdi_sticker|
|<span class="nerdfont big">&#xfc83;</span>|mdi_sticker_emoji|
|<span class="nerdfont big">&#xf9d9;</span>|mdi_stocking|
|<span class="nerdfont big">&#xf9da;</span>|mdi_stop|
|<span class="nerdfont big">&#xfb65;</span>|mdi_stop_circle|
|<span class="nerdfont big">&#xfb66;</span>|mdi_stop_circle_outline|
|<span class="nerdfont big">&#xf9db;</span>|mdi_store|
|<span class="nerdfont big">&#xf9dc;</span>|mdi_store_24_hour|
|<span class="nerdfont big">&#xf9dd;</span>|mdi_stove|
|<span class="nerdfont big">&#xfb0b;</span>|mdi_subdirectory_arrow_left|
|<span class="nerdfont big">&#xfb0c;</span>|mdi_subdirectory_arrow_right|
|<span class="nerdfont big">&#xfbaa;</span>|mdi_subway|
|<span class="nerdfont big">&#xf9de;</span>|mdi_subway_variant|
|<span class="nerdfont big">&#xfc84;</span>|mdi_summit|
|<span class="nerdfont big">&#xf9df;</span>|mdi_sunglasses|
|<span class="nerdfont big">&#xfac4;</span>|mdi_surround_sound|
|<span class="nerdfont big">&#xfcee;</span>|mdi_surround_sound_2_0|
|<span class="nerdfont big">&#xfcef;</span>|mdi_surround_sound_3_1|
|<span class="nerdfont big">&#xfcf0;</span>|mdi_surround_sound_5_1|
|<span class="nerdfont big">&#xfcf1;</span>|mdi_surround_sound_7_1|
|<span class="nerdfont big">&#xfc1f;</span>|mdi_svg|
|<span class="nerdfont big">&#xf9e0;</span>|mdi_swap_horizontal|
|<span class="nerdfont big">&#xf9e1;</span>|mdi_swap_vertical|
|<span class="nerdfont big">&#xf9e2;</span>|mdi_swim|
|<span class="nerdfont big">&#xf9e3;</span>|mdi_switch|
|<span class="nerdfont big">&#xf9e4;</span>|mdi_sword|
|<span class="nerdfont big">&#xfc85;</span>|mdi_sword_cross|
|<span class="nerdfont big">&#xf9e5;</span>|mdi_sync|
|<span class="nerdfont big">&#xf9e6;</span>|mdi_sync_alert|
|<span class="nerdfont big">&#xf9e7;</span>|mdi_sync_off|
|<span class="nerdfont big">&#xf9e8;</span>|mdi_tab|
|<span class="nerdfont big">&#xfc5a;</span>|mdi_tab_plus|
|<span class="nerdfont big">&#xf9e9;</span>|mdi_tab_unselected|
|<span class="nerdfont big">&#xf9ea;</span>|mdi_table|
|<span class="nerdfont big">&#xfd33;</span>|mdi_table_column|
|<span class="nerdfont big">&#xf9eb;</span>|mdi_table_column_plus_after|
|<span class="nerdfont big">&#xf9ec;</span>|mdi_table_column_plus_before|
|<span class="nerdfont big">&#xf9ed;</span>|mdi_table_column_remove|
|<span class="nerdfont big">&#xf9ee;</span>|mdi_table_column_width|
|<span class="nerdfont big">&#xf9ef;</span>|mdi_table_edit|
|<span class="nerdfont big">&#xf9f0;</span>|mdi_table_large|
|<span class="nerdfont big">&#xfd34;</span>|mdi_table_of_contents|
|<span class="nerdfont big">&#xfd35;</span>|mdi_table_row|
|<span class="nerdfont big">&#xf9f1;</span>|mdi_table_row_height|
|<span class="nerdfont big">&#xf9f2;</span>|mdi_table_row_plus_after|
|<span class="nerdfont big">&#xf9f3;</span>|mdi_table_row_plus_before|
|<span class="nerdfont big">&#xf9f4;</span>|mdi_table_row_remove|
|<span class="nerdfont big">&#xfd36;</span>|mdi_table_settings|
|<span class="nerdfont big">&#xf9f5;</span>|mdi_tablet|
|<span class="nerdfont big">&#xf9f6;</span>|mdi_tablet_android|
|<span class="nerdfont big">&#xf9f7;</span>|mdi_tablet_ipad|
|<span class="nerdfont big">&#xfc60;</span>|mdi_taco|
|<span class="nerdfont big">&#xf9f8;</span>|mdi_tag|
|<span class="nerdfont big">&#xf9f9;</span>|mdi_tag_faces|
|<span class="nerdfont big">&#xfb89;</span>|mdi_tag_heart|
|<span class="nerdfont big">&#xf9fa;</span>|mdi_tag_multiple|
|<span class="nerdfont big">&#xf9fb;</span>|mdi_tag_outline|
|<span class="nerdfont big">&#xfc20;</span>|mdi_tag_plus|
|<span class="nerdfont big">&#xfc21;</span>|mdi_tag_remove|
|<span class="nerdfont big">&#xf9fc;</span>|mdi_tag_text_outline|
|<span class="nerdfont big">&#xf9fd;</span>|mdi_target|
|<span class="nerdfont big">&#xf9fe;</span>|mdi_taxi|
|<span class="nerdfont big">&#xf9ff;</span>|mdi_teamviewer|
|<span class="nerdfont big">&#xfa00;</span>|mdi_telegram|
|<span class="nerdfont big">&#xfa01;</span>|mdi_television|
|<span class="nerdfont big">&#xfd37;</span>|mdi_television_box|
|<span class="nerdfont big">&#xfcf2;</span>|mdi_television_classic|
|<span class="nerdfont big">&#xfd38;</span>|mdi_television_classic_off|
|<span class="nerdfont big">&#xfa02;</span>|mdi_television_guide|
|<span class="nerdfont big">&#xfd39;</span>|mdi_television_off|
|<span class="nerdfont big">&#xfa03;</span>|mdi_temperature_celsius|
|<span class="nerdfont big">&#xfa04;</span>|mdi_temperature_fahrenheit|
|<span class="nerdfont big">&#xfa05;</span>|mdi_temperature_kelvin|
|<span class="nerdfont big">&#xfa06;</span>|mdi_tennis|
|<span class="nerdfont big">&#xfa07;</span>|mdi_tent|
|<span class="nerdfont big">&#xfa08;</span>|mdi_terrain|
|<span class="nerdfont big">&#xfb67;</span>|mdi_test_tube|
|<span class="nerdfont big">&#xfb68;</span>|mdi_text_shadow|
|<span class="nerdfont big">&#xfa09;</span>|mdi_text_to_speech|
|<span class="nerdfont big">&#xfa0a;</span>|mdi_text_to_speech_off|
|<span class="nerdfont big">&#xfb0d;</span>|mdi_textbox|
|<span class="nerdfont big">&#xfcf3;</span>|mdi_textbox_password|
|<span class="nerdfont big">&#xfa0b;</span>|mdi_texture|
|<span class="nerdfont big">&#xfa0c;</span>|mdi_theater|
|<span class="nerdfont big">&#xfa0d;</span>|mdi_theme_light_dark|
|<span class="nerdfont big">&#xfa0e;</span>|mdi_thermometer|
|<span class="nerdfont big">&#xfa0f;</span>|mdi_thermometer_lines|
|<span class="nerdfont big">&#xfcf4;</span>|mdi_thought_bubble|
|<span class="nerdfont big">&#xfcf5;</span>|mdi_thought_bubble_outline|
|<span class="nerdfont big">&#xfa10;</span>|mdi_thumb_down|
|<span class="nerdfont big">&#xfa11;</span>|mdi_thumb_down_outline|
|<span class="nerdfont big">&#xfa12;</span>|mdi_thumb_up|
|<span class="nerdfont big">&#xfa13;</span>|mdi_thumb_up_outline|
|<span class="nerdfont big">&#xfa14;</span>|mdi_thumbs_up_down|
|<span class="nerdfont big">&#xfa15;</span>|mdi_ticket|
|<span class="nerdfont big">&#xfa16;</span>|mdi_ticket_account|
|<span class="nerdfont big">&#xfa17;</span>|mdi_ticket_confirmation|
|<span class="nerdfont big">&#xfc22;</span>|mdi_ticket_percent|
|<span class="nerdfont big">&#xfa18;</span>|mdi_tie|
|<span class="nerdfont big">&#xfc23;</span>|mdi_tilde|
|<span class="nerdfont big">&#xfa19;</span>|mdi_timelapse|
|<span class="nerdfont big">&#xfa1a;</span>|mdi_timer|
|<span class="nerdfont big">&#xfa1c;</span>|mdi_timer_3|
|<span class="nerdfont big">&#xfa1b;</span>|mdi_timer_10|
|<span class="nerdfont big">&#xfa1d;</span>|mdi_timer_off|
|<span class="nerdfont big">&#xfa1e;</span>|mdi_timer_sand|
|<span class="nerdfont big">&#xfbab;</span>|mdi_timer_sand_empty|
|<span class="nerdfont big">&#xfc8a;</span>|mdi_timer_sand_full|
|<span class="nerdfont big">&#xfa1f;</span>|mdi_timetable|
|<span class="nerdfont big">&#xfa20;</span>|mdi_toggle_switch|
|<span class="nerdfont big">&#xfa21;</span>|mdi_toggle_switch_off|
|<span class="nerdfont big">&#xfa22;</span>|mdi_tooltip|
|<span class="nerdfont big">&#xfa23;</span>|mdi_tooltip_edit|
|<span class="nerdfont big">&#xfa24;</span>|mdi_tooltip_image|
|<span class="nerdfont big">&#xfa25;</span>|mdi_tooltip_outline|
|<span class="nerdfont big">&#xfa26;</span>|mdi_tooltip_outline_plus|
|<span class="nerdfont big">&#xfa27;</span>|mdi_tooltip_text|
|<span class="nerdfont big">&#xfa28;</span>|mdi_tooth|
|<span class="nerdfont big">&#xfa29;</span>|mdi_tor|
|<span class="nerdfont big">&#xfb7f;</span>|mdi_tower_beach|
|<span class="nerdfont big">&#xfb80;</span>|mdi_tower_fire|
|<span class="nerdfont big">&#xfd3a;</span>|mdi_towing|
|<span class="nerdfont big">&#xfcf6;</span>|mdi_trackpad|
|<span class="nerdfont big">&#xfa2a;</span>|mdi_traffic_light|
|<span class="nerdfont big">&#xfa2b;</span>|mdi_train|
|<span class="nerdfont big">&#xfa2c;</span>|mdi_tram|
|<span class="nerdfont big">&#xfa2d;</span>|mdi_transcribe|
|<span class="nerdfont big">&#xfa2e;</span>|mdi_transcribe_close|
|<span class="nerdfont big">&#xfa2f;</span>|mdi_transfer|
|<span class="nerdfont big">&#xfbac;</span>|mdi_transit_transfer|
|<span class="nerdfont big">&#xfac9;</span>|mdi_translate|
|<span class="nerdfont big">&#xfc24;</span>|mdi_treasure_chest|
|<span class="nerdfont big">&#xfa30;</span>|mdi_tree|
|<span class="nerdfont big">&#xfa31;</span>|mdi_trello|
|<span class="nerdfont big">&#xfa32;</span>|mdi_trending_down|
|<span class="nerdfont big">&#xfa33;</span>|mdi_trending_neutral|
|<span class="nerdfont big">&#xfa34;</span>|mdi_trending_up|
|<span class="nerdfont big">&#xfa35;</span>|mdi_triangle|
|<span class="nerdfont big">&#xfa36;</span>|mdi_triangle_outline|
|<span class="nerdfont big">&#xfa37;</span>|mdi_trophy|
|<span class="nerdfont big">&#xfa38;</span>|mdi_trophy_award|
|<span class="nerdfont big">&#xfa39;</span>|mdi_trophy_outline|
|<span class="nerdfont big">&#xfa3a;</span>|mdi_trophy_variant|
|<span class="nerdfont big">&#xfa3b;</span>|mdi_trophy_variant_outline|
|<span class="nerdfont big">&#xfa3c;</span>|mdi_truck|
|<span class="nerdfont big">&#xfa3d;</span>|mdi_truck_delivery|
|<span class="nerdfont big">&#xfc86;</span>|mdi_truck_fast|
|<span class="nerdfont big">&#xfc25;</span>|mdi_truck_trailer|
|<span class="nerdfont big">&#xfa3e;</span>|mdi_tshirt_crew|
|<span class="nerdfont big">&#xfa3f;</span>|mdi_tshirt_v|
|<span class="nerdfont big">&#xfa40;</span>|mdi_tumblr|
|<span class="nerdfont big">&#xfa41;</span>|mdi_tumblr_reblog|
|<span class="nerdfont big">&#xfb2d;</span>|mdi_tune|
|<span class="nerdfont big">&#xfb69;</span>|mdi_tune_vertical|
|<span class="nerdfont big">&#xfa42;</span>|mdi_twitch|
|<span class="nerdfont big">&#xfa43;</span>|mdi_twitter|
|<span class="nerdfont big">&#xfa44;</span>|mdi_twitter_box|
|<span class="nerdfont big">&#xfa45;</span>|mdi_twitter_circle|
|<span class="nerdfont big">&#xfa46;</span>|mdi_twitter_retweet|
|<span class="nerdfont big">&#xfc47;</span>|mdi_uber|
|<span class="nerdfont big">&#xfa47;</span>|mdi_ubuntu|
|<span class="nerdfont big">&#xfcf7;</span>|mdi_ultra_high_definition|
|<span class="nerdfont big">&#xfa48;</span>|mdi_umbraco|
|<span class="nerdfont big">&#xfa49;</span>|mdi_umbrella|
|<span class="nerdfont big">&#xfa4a;</span>|mdi_umbrella_outline|
|<span class="nerdfont big">&#xfa4b;</span>|mdi_undo|
|<span class="nerdfont big">&#xfa4c;</span>|mdi_undo_variant|
|<span class="nerdfont big">&#xfa4d;</span>|mdi_unfold_less_horizontal|
|<span class="nerdfont big">&#xfc5e;</span>|mdi_unfold_less_vertical|
|<span class="nerdfont big">&#xfa4e;</span>|mdi_unfold_more_horizontal|
|<span class="nerdfont big">&#xfc5f;</span>|mdi_unfold_more_vertical|
|<span class="nerdfont big">&#xfa4f;</span>|mdi_ungroup|
|<span class="nerdfont big">&#xfbad;</span>|mdi_unity|
|<span class="nerdfont big">&#xfa50;</span>|mdi_untappd|
|<span class="nerdfont big">&#xfbae;</span>|mdi_update|
|<span class="nerdfont big">&#xfa51;</span>|mdi_upload|
|<span class="nerdfont big">&#xfd3b;</span>|mdi_upload_multiple|
|<span class="nerdfont big">&#xfbf4;</span>|mdi_upload_network|
|<span class="nerdfont big">&#xfa52;</span>|mdi_usb|
|<span class="nerdfont big">&#xfcf8;</span>|mdi_van_passenger|
|<span class="nerdfont big">&#xfcf9;</span>|mdi_van_utility|
|<span class="nerdfont big">&#xfcfa;</span>|mdi_vanish|
|<span class="nerdfont big">&#xfa53;</span>|mdi_vector_arrange_above|
|<span class="nerdfont big">&#xfa54;</span>|mdi_vector_arrange_below|
|<span class="nerdfont big">&#xfa55;</span>|mdi_vector_circle|
|<span class="nerdfont big">&#xfa56;</span>|mdi_vector_circle_variant|
|<span class="nerdfont big">&#xfa57;</span>|mdi_vector_combine|
|<span class="nerdfont big">&#xfa58;</span>|mdi_vector_curve|
|<span class="nerdfont big">&#xfa59;</span>|mdi_vector_difference|
|<span class="nerdfont big">&#xfa5a;</span>|mdi_vector_difference_ab|
|<span class="nerdfont big">&#xfa5b;</span>|mdi_vector_difference_ba|
|<span class="nerdfont big">&#xfa5c;</span>|mdi_vector_intersection|
|<span class="nerdfont big">&#xfa5d;</span>|mdi_vector_line|
|<span class="nerdfont big">&#xfa5e;</span>|mdi_vector_point|
|<span class="nerdfont big">&#xfa5f;</span>|mdi_vector_polygon|
|<span class="nerdfont big">&#xfa60;</span>|mdi_vector_polyline|
|<span class="nerdfont big">&#xfc48;</span>|mdi_vector_radius|
|<span class="nerdfont big">&#xfac5;</span>|mdi_vector_rectangle|
|<span class="nerdfont big">&#xfa61;</span>|mdi_vector_selection|
|<span class="nerdfont big">&#xf500;</span>|mdi_vector_square|
|<span class="nerdfont big">&#xfa62;</span>|mdi_vector_triangle|
|<span class="nerdfont big">&#xfa63;</span>|mdi_vector_union|
|<span class="nerdfont big">&#xfa77;</span>|mdi_venmo|
|<span class="nerdfont big">&#xfa64;</span>|mdi_verified|
|<span class="nerdfont big">&#xfa65;</span>|mdi_vibrate|
|<span class="nerdfont big">&#xfa66;</span>|mdi_video|
|<span class="nerdfont big">&#xfcfb;</span>|mdi_video_3d|
|<span class="nerdfont big">&#xfd3c;</span>|mdi_video_4k_box|
|<span class="nerdfont big">&#xfd3d;</span>|mdi_video_input_antenna|
|<span class="nerdfont big">&#xfd3e;</span>|mdi_video_input_component|
|<span class="nerdfont big">&#xfd3f;</span>|mdi_video_input_hdmi|
|<span class="nerdfont big">&#xfd40;</span>|mdi_video_input_svideo|
|<span class="nerdfont big">&#xfa67;</span>|mdi_video_off|
|<span class="nerdfont big">&#xfa68;</span>|mdi_video_switch|
|<span class="nerdfont big">&#xfa69;</span>|mdi_view_agenda|
|<span class="nerdfont big">&#xfa6a;</span>|mdi_view_array|
|<span class="nerdfont big">&#xfa6b;</span>|mdi_view_carousel|
|<span class="nerdfont big">&#xfa6c;</span>|mdi_view_column|
|<span class="nerdfont big">&#xfa6d;</span>|mdi_view_dashboard|
|<span class="nerdfont big">&#xfd41;</span>|mdi_view_dashboard_variant|
|<span class="nerdfont big">&#xfa6e;</span>|mdi_view_day|
|<span class="nerdfont big">&#xfa6f;</span>|mdi_view_grid|
|<span class="nerdfont big">&#xfa70;</span>|mdi_view_headline|
|<span class="nerdfont big">&#xfa71;</span>|mdi_view_list|
|<span class="nerdfont big">&#xfa72;</span>|mdi_view_module|
|<span class="nerdfont big">&#xfc26;</span>|mdi_view_parallel|
|<span class="nerdfont big">&#xfa73;</span>|mdi_view_quilt|
|<span class="nerdfont big">&#xfc27;</span>|mdi_view_sequential|
|<span class="nerdfont big">&#xfa74;</span>|mdi_view_stream|
|<span class="nerdfont big">&#xfa75;</span>|mdi_view_week|
|<span class="nerdfont big">&#xfa76;</span>|mdi_vimeo|
|<span class="nerdfont big">&#xfb0e;</span>|mdi_violin|
|<span class="nerdfont big">&#xfb0f;</span>|mdi_visualstudio|
|<span class="nerdfont big">&#xfa78;</span>|mdi_vk|
|<span class="nerdfont big">&#xfa79;</span>|mdi_vk_box|
|<span class="nerdfont big">&#xfa7a;</span>|mdi_vk_circle|
|<span class="nerdfont big">&#xfa7b;</span>|mdi_vlc|
|<span class="nerdfont big">&#xfaca;</span>|mdi_voice|
|<span class="nerdfont big">&#xfa7c;</span>|mdi_voicemail|
|<span class="nerdfont big">&#xfa7d;</span>|mdi_volume_high|
|<span class="nerdfont big">&#xfa7e;</span>|mdi_volume_low|
|<span class="nerdfont big">&#xfa7f;</span>|mdi_volume_medium|
|<span class="nerdfont big">&#xfc5c;</span>|mdi_volume_minus|
|<span class="nerdfont big">&#xfc5d;</span>|mdi_volume_mute|
|<span class="nerdfont big">&#xfa80;</span>|mdi_volume_off|
|<span class="nerdfont big">&#xfc5b;</span>|mdi_volume_plus|
|<span class="nerdfont big">&#xfa81;</span>|mdi_vpn|
|<span class="nerdfont big">&#xfd42;</span>|mdi_vuejs|
|<span class="nerdfont big">&#xfa82;</span>|mdi_walk|
|<span class="nerdfont big">&#xfcfc;</span>|mdi_wall|
|<span class="nerdfont big">&#xfa83;</span>|mdi_wallet|
|<span class="nerdfont big">&#xfa84;</span>|mdi_wallet_giftcard|
|<span class="nerdfont big">&#xfa85;</span>|mdi_wallet_membership|
|<span class="nerdfont big">&#xfa86;</span>|mdi_wallet_travel|
|<span class="nerdfont big">&#xfa87;</span>|mdi_wan|
|<span class="nerdfont big">&#xfc28;</span>|mdi_washing_machine|
|<span class="nerdfont big">&#xfa88;</span>|mdi_watch|
|<span class="nerdfont big">&#xfa89;</span>|mdi_watch_export|
|<span class="nerdfont big">&#xfa8a;</span>|mdi_watch_import|
|<span class="nerdfont big">&#xfbaf;</span>|mdi_watch_vibrate|
|<span class="nerdfont big">&#xfa8b;</span>|mdi_water|
|<span class="nerdfont big">&#xfa8c;</span>|mdi_water_off|
|<span class="nerdfont big">&#xfa8d;</span>|mdi_water_percent|
|<span class="nerdfont big">&#xfa8e;</span>|mdi_water_pump|
|<span class="nerdfont big">&#xfb11;</span>|mdi_watermark|
|<span class="nerdfont big">&#xfc8b;</span>|mdi_waves|
|<span class="nerdfont big">&#xfa8f;</span>|mdi_weather_cloudy|
|<span class="nerdfont big">&#xfa90;</span>|mdi_weather_fog|
|<span class="nerdfont big">&#xfa91;</span>|mdi_weather_hail|
|<span class="nerdfont big">&#xfa92;</span>|mdi_weather_lightning|
|<span class="nerdfont big">&#xfb7c;</span>|mdi_weather_lightning_rainy|
|<span class="nerdfont big">&#xfa93;</span>|mdi_weather_night|
|<span class="nerdfont big">&#xfa94;</span>|mdi_weather_partlycloudy|
|<span class="nerdfont big">&#xfa95;</span>|mdi_weather_pouring|
|<span class="nerdfont big">&#xfa96;</span>|mdi_weather_rainy|
|<span class="nerdfont big">&#xfa97;</span>|mdi_weather_snowy|
|<span class="nerdfont big">&#xfb7d;</span>|mdi_weather_snowy_rainy|
|<span class="nerdfont big">&#xfa98;</span>|mdi_weather_sunny|
|<span class="nerdfont big">&#xfa99;</span>|mdi_weather_sunset|
|<span class="nerdfont big">&#xfa9a;</span>|mdi_weather_sunset_down|
|<span class="nerdfont big">&#xfa9b;</span>|mdi_weather_sunset_up|
|<span class="nerdfont big">&#xfa9c;</span>|mdi_weather_windy|
|<span class="nerdfont big">&#xfa9d;</span>|mdi_weather_windy_variant|
|<span class="nerdfont big">&#xfa9e;</span>|mdi_web|
|<span class="nerdfont big">&#xfa9f;</span>|mdi_webcam|
|<span class="nerdfont big">&#xfb2e;</span>|mdi_webhook|
|<span class="nerdfont big">&#xfc29;</span>|mdi_webpack|
|<span class="nerdfont big">&#xfb10;</span>|mdi_wechat|
|<span class="nerdfont big">&#xfaa0;</span>|mdi_weight|
|<span class="nerdfont big">&#xfaa1;</span>|mdi_weight_kilogram|
|<span class="nerdfont big">&#xfaa2;</span>|mdi_whatsapp|
|<span class="nerdfont big">&#xfaa3;</span>|mdi_wheelchair_accessibility|
|<span class="nerdfont big">&#xfaa4;</span>|mdi_white_balance_auto|
|<span class="nerdfont big">&#xfaa5;</span>|mdi_white_balance_incandescent|
|<span class="nerdfont big">&#xfaa6;</span>|mdi_white_balance_iridescent|
|<span class="nerdfont big">&#xfaa7;</span>|mdi_white_balance_sunny|
|<span class="nerdfont big">&#xfc2a;</span>|mdi_widgets|
|<span class="nerdfont big">&#xfaa8;</span>|mdi_wifi|
|<span class="nerdfont big">&#xfaa9;</span>|mdi_wifi_off|
|<span class="nerdfont big">&#xfaaa;</span>|mdi_wii|
|<span class="nerdfont big">&#xfc2b;</span>|mdi_wiiu|
|<span class="nerdfont big">&#xfaab;</span>|mdi_wikipedia|
|<span class="nerdfont big">&#xfaac;</span>|mdi_window_close|
|<span class="nerdfont big">&#xfaad;</span>|mdi_window_closed|
|<span class="nerdfont big">&#xfaae;</span>|mdi_window_maximize|
|<span class="nerdfont big">&#xfaaf;</span>|mdi_window_minimize|
|<span class="nerdfont big">&#xfab0;</span>|mdi_window_open|
|<span class="nerdfont big">&#xfab1;</span>|mdi_window_restore|
|<span class="nerdfont big">&#xfab2;</span>|mdi_windows|
|<span class="nerdfont big">&#xfab3;</span>|mdi_wordpress|
|<span class="nerdfont big">&#xfab4;</span>|mdi_worker|
|<span class="nerdfont big">&#xfab5;</span>|mdi_wrap|
|<span class="nerdfont big">&#xfab6;</span>|mdi_wrench|
|<span class="nerdfont big">&#xfab7;</span>|mdi_wunderlist|
|<span class="nerdfont big">&#xfd43;</span>|mdi_xamarin|
|<span class="nerdfont big">&#xfd44;</span>|mdi_xamarin_outline|
|<span class="nerdfont big">&#xfb72;</span>|mdi_xaml|
|<span class="nerdfont big">&#xfab8;</span>|mdi_xbox|
|<span class="nerdfont big">&#xfab9;</span>|mdi_xbox_controller|
|<span class="nerdfont big">&#xfc49;</span>|mdi_xbox_controller_battery_alert|
|<span class="nerdfont big">&#xfc4a;</span>|mdi_xbox_controller_battery_empty|
|<span class="nerdfont big">&#xfc4b;</span>|mdi_xbox_controller_battery_full|
|<span class="nerdfont big">&#xfc4c;</span>|mdi_xbox_controller_battery_low|
|<span class="nerdfont big">&#xfc4d;</span>|mdi_xbox_controller_battery_medium|
|<span class="nerdfont big">&#xfc4e;</span>|mdi_xbox_controller_battery_unknown|
|<span class="nerdfont big">&#xfaba;</span>|mdi_xbox_controller_off|
|<span class="nerdfont big">&#xfabb;</span>|mdi_xda|
|<span class="nerdfont big">&#xfabc;</span>|mdi_xing|
|<span class="nerdfont big">&#xfabd;</span>|mdi_xing_box|
|<span class="nerdfont big">&#xfabe;</span>|mdi_xing_circle|
|<span class="nerdfont big">&#xfabf;</span>|mdi_xml|
|<span class="nerdfont big">&#xfcfd;</span>|mdi_xmpp|
|<span class="nerdfont big">&#xfc87;</span>|mdi_yammer|
|<span class="nerdfont big">&#xfac0;</span>|mdi_yeast|
|<span class="nerdfont big">&#xfac1;</span>|mdi_yelp|
|<span class="nerdfont big">&#xfb7e;</span>|mdi_yin_yang|
|<span class="nerdfont big">&#xfd45;</span>|mdi_youtube_creator_studio|
|<span class="nerdfont big">&#xfd46;</span>|mdi_youtube_gaming|
|<span class="nerdfont big">&#xfac2;</span>|mdi_youtube_play|
|<span class="nerdfont big">&#xf947;</span>|mdi_youtube_tv|
|<span class="nerdfont big">&#xfac3;</span>|mdi_zip_box|
|<span class="nerdfont big">&#xf421;</span>|oct_alert|
|<span class="nerdfont big">&#xf433;</span>|oct_arrow_down|
|<span class="nerdfont big">&#xf434;</span>|oct_arrow_left|
|<span class="nerdfont big">&#xf432;</span>|oct_arrow_right|
|<span class="nerdfont big">&#xf479;</span>|oct_arrow_small_down|
|<span class="nerdfont big">&#xf47a;</span>|oct_arrow_small_left|
|<span class="nerdfont big">&#xf45c;</span>|oct_arrow_small_right|
|<span class="nerdfont big">&#xf478;</span>|oct_arrow_small_up|
|<span class="nerdfont big">&#xf431;</span>|oct_arrow_up|
|<span class="nerdfont big">&#xf499;</span>|oct_beaker|
|<span class="nerdfont big">&#xf49a;</span>|oct_bell|
|<span class="nerdfont big">&#xf49d;</span>|oct_bold|
|<span class="nerdfont big">&#xf405;</span>|oct_book|
|<span class="nerdfont big">&#xf461;</span>|oct_bookmark|
|<span class="nerdfont big">&#xf491;</span>|oct_briefcase|
|<span class="nerdfont big">&#xf43c;</span>|oct_broadcast|
|<span class="nerdfont big">&#xf488;</span>|oct_browser|
|<span class="nerdfont big">&#xf46f;</span>|oct_bug|
|<span class="nerdfont big">&#xf455;</span>|oct_calendar|
|<span class="nerdfont big">&#xf42e;</span>|oct_check|
|<span class="nerdfont big">&#xf45e;</span>|oct_checklist|
|<span class="nerdfont big">&#xf47c;</span>|oct_chevron_down|
|<span class="nerdfont big">&#xf47d;</span>|oct_chevron_left|
|<span class="nerdfont big">&#xf460;</span>|oct_chevron_right|
|<span class="nerdfont big">&#xf47b;</span>|oct_chevron_up|
|<span class="nerdfont big">&#xf468;</span>|oct_circle_slash|
|<span class="nerdfont big">&#xf493;</span>|oct_circuit_board|
|<span class="nerdfont big">&#xf429;</span>|oct_clippy|
|<span class="nerdfont big">&#xf43a;</span>|oct_clock|
|<span class="nerdfont big">&#xf409;</span>|oct_cloud_download|
|<span class="nerdfont big">&#xf40a;</span>|oct_cloud_upload|
|<span class="nerdfont big">&#xf44f;</span>|oct_code|
|<span class="nerdfont big">&#xf41f;</span>|oct_comment|
|<span class="nerdfont big">&#xf442;</span>|oct_comment_discussion|
|<span class="nerdfont big">&#xf439;</span>|oct_credit_card|
|<span class="nerdfont big">&#xf48b;</span>|oct_dash|
|<span class="nerdfont big">&#xf463;</span>|oct_dashboard|
|<span class="nerdfont big">&#xf472;</span>|oct_database|
|<span class="nerdfont big">&#xf498;</span>|oct_desktop_download|
|<span class="nerdfont big">&#xf446;</span>|oct_device_camera|
|<span class="nerdfont big">&#xf447;</span>|oct_device_camera_video|
|<span class="nerdfont big">&#xf67c;</span>|oct_device_desktop|
|<span class="nerdfont big">&#xf42c;</span>|oct_device_mobile|
|<span class="nerdfont big">&#xf440;</span>|oct_diff|
|<span class="nerdfont big">&#xf457;</span>|oct_diff_added|
|<span class="nerdfont big">&#xf474;</span>|oct_diff_ignored|
|<span class="nerdfont big">&#xf459;</span>|oct_diff_modified|
|<span class="nerdfont big">&#xf458;</span>|oct_diff_removed|
|<span class="nerdfont big">&#xf45a;</span>|oct_diff_renamed|
|<span class="nerdfont big">&#xf4a4;</span>|oct_ellipses|
|<span class="nerdfont big">&#xf475;</span>|oct_ellipsis|
|<span class="nerdfont big">&#xf441;</span>|oct_eye|
|<span class="nerdfont big">&#xf4a5;</span>|oct_file|
|<span class="nerdfont big">&#xf471;</span>|oct_file_binary|
|<span class="nerdfont big">&#xf40d;</span>|oct_file_code|
|<span class="nerdfont big">&#xf413;</span>|oct_file_directory|
|<span class="nerdfont big">&#xf40f;</span>|oct_file_media|
|<span class="nerdfont big">&#xf411;</span>|oct_file_pdf|
|<span class="nerdfont big">&#xf414;</span>|oct_file_submodule|
|<span class="nerdfont big">&#xf482;</span>|oct_file_symlink_directory|
|<span class="nerdfont big">&#xf481;</span>|oct_file_symlink_file|
|<span class="nerdfont big">&#xf40e;</span>|oct_file_text|
|<span class="nerdfont big">&#xf410;</span>|oct_file_zip|
|<span class="nerdfont big">&#xf490;</span>|oct_flame|
|<span class="nerdfont big">&#xf48c;</span>|oct_fold|
|<span class="nerdfont big">&#xf423;</span>|oct_gear|
|<span class="nerdfont big">&#xf436;</span>|oct_gift|
|<span class="nerdfont big">&#xf40c;</span>|oct_gist|
|<span class="nerdfont big">&#xf46c;</span>|oct_gist_secret|
|<span class="nerdfont big">&#xf418;</span>|oct_git_branch|
|<span class="nerdfont big">&#xf417;</span>|oct_git_commit|
|<span class="nerdfont big">&#xf47f;</span>|oct_git_compare|
|<span class="nerdfont big">&#xf419;</span>|oct_git_merge|
|<span class="nerdfont big">&#xf407;</span>|oct_git_pull_request|
|<span class="nerdfont big">&#xf484;</span>|oct_globe|
|<span class="nerdfont big">&#xf4a6;</span>|oct_grabber|
|<span class="nerdfont big">&#xf437;</span>|oct_graph|
|<span class="nerdfont big">&#x2665;</span>|oct_heart|
|<span class="nerdfont big">&#xf464;</span>|oct_history|
|<span class="nerdfont big">&#xf46d;</span>|oct_home|
|<span class="nerdfont big">&#xf45b;</span>|oct_horizontal_rule|
|<span class="nerdfont big">&#xf477;</span>|oct_hubot|
|<span class="nerdfont big">&#xf48d;</span>|oct_inbox|
|<span class="nerdfont big">&#xf449;</span>|oct_info|
|<span class="nerdfont big">&#xf41d;</span>|oct_issue_closed|
|<span class="nerdfont big">&#xf41b;</span>|oct_issue_opened|
|<span class="nerdfont big">&#xf41c;</span>|oct_issue_reopened|
|<span class="nerdfont big">&#xf49f;</span>|oct_italic|
|<span class="nerdfont big">&#xf416;</span>|oct_jersey|
|<span class="nerdfont big">&#xf43d;</span>|oct_key|
|<span class="nerdfont big">&#xf40b;</span>|oct_keyboard|
|<span class="nerdfont big">&#xf495;</span>|oct_law|
|<span class="nerdfont big">&#xf400;</span>|oct_light_bulb|
|<span class="nerdfont big">&#xf44c;</span>|oct_link|
|<span class="nerdfont big">&#xf465;</span>|oct_link_external|
|<span class="nerdfont big">&#xf452;</span>|oct_list_ordered|
|<span class="nerdfont big">&#xf451;</span>|oct_list_unordered|
|<span class="nerdfont big">&#xf450;</span>|oct_location|
|<span class="nerdfont big">&#xf456;</span>|oct_lock|
|<span class="nerdfont big">&#xf480;</span>|oct_logo_gist|
|<span class="nerdfont big">&#xf470;</span>|oct_logo_github|
|<span class="nerdfont big">&#xf42f;</span>|oct_mail|
|<span class="nerdfont big">&#xf430;</span>|oct_mail_read|
|<span class="nerdfont big">&#xf443;</span>|oct_mail_reply|
|<span class="nerdfont big">&#xf408;</span>|oct_mark_github|
|<span class="nerdfont big">&#xf48a;</span>|oct_markdown|
|<span class="nerdfont big">&#xf45f;</span>|oct_megaphone|
|<span class="nerdfont big">&#xf486;</span>|oct_mention|
|<span class="nerdfont big">&#xf45d;</span>|oct_milestone|
|<span class="nerdfont big">&#xf41a;</span>|oct_mirror|
|<span class="nerdfont big">&#xf494;</span>|oct_mortar_board|
|<span class="nerdfont big">&#xf466;</span>|oct_mute|
|<span class="nerdfont big">&#xf476;</span>|oct_no_newline|
|<span class="nerdfont big">&#xf406;</span>|oct_octoface|
|<span class="nerdfont big">&#xf42b;</span>|oct_organization|
|<span class="nerdfont big">&#xf487;</span>|oct_package|
|<span class="nerdfont big">&#xf48f;</span>|oct_paintcan|
|<span class="nerdfont big">&#xf448;</span>|oct_pencil|
|<span class="nerdfont big">&#xf415;</span>|oct_person|
|<span class="nerdfont big">&#xf435;</span>|oct_pin|
|<span class="nerdfont big">&#xf492;</span>|oct_plug|
|<span class="nerdfont big">&#xf44d;</span>|oct_plus|
|<span class="nerdfont big">&#xf4a7;</span>|oct_plus_small|
|<span class="nerdfont big">&#xf444;</span>|oct_primitive_dot|
|<span class="nerdfont big">&#xf445;</span>|oct_primitive_square|
|<span class="nerdfont big">&#xf469;</span>|oct_pulse|
|<span class="nerdfont big">&#xf420;</span>|oct_question|
|<span class="nerdfont big">&#xf453;</span>|oct_quote|
|<span class="nerdfont big">&#xf424;</span>|oct_radio_tower|
|<span class="nerdfont big">&#xf4a8;</span>|oct_reply|
|<span class="nerdfont big">&#xf401;</span>|oct_repo|
|<span class="nerdfont big">&#xf43f;</span>|oct_repo_clone|
|<span class="nerdfont big">&#xf43e;</span>|oct_repo_force_push|
|<span class="nerdfont big">&#xf402;</span>|oct_repo_forked|
|<span class="nerdfont big">&#xf404;</span>|oct_repo_pull|
|<span class="nerdfont big">&#xf403;</span>|oct_repo_push|
|<span class="nerdfont big">&#xf427;</span>|oct_rocket|
|<span class="nerdfont big">&#xf428;</span>|oct_rss|
|<span class="nerdfont big">&#xf43b;</span>|oct_ruby|
|<span class="nerdfont big">&#xf422;</span>|oct_search|
|<span class="nerdfont big">&#xf473;</span>|oct_server|
|<span class="nerdfont big">&#xf462;</span>|oct_settings|
|<span class="nerdfont big">&#xf49c;</span>|oct_shield|
|<span class="nerdfont big">&#xf42a;</span>|oct_sign_in|
|<span class="nerdfont big">&#xf426;</span>|oct_sign_out|
|<span class="nerdfont big">&#xf4a2;</span>|oct_smiley|
|<span class="nerdfont big">&#xf483;</span>|oct_squirrel|
|<span class="nerdfont big">&#xf41e;</span>|oct_star|
|<span class="nerdfont big">&#xf46e;</span>|oct_stop|
|<span class="nerdfont big">&#xf46a;</span>|oct_sync|
|<span class="nerdfont big">&#xf412;</span>|oct_tag|
|<span class="nerdfont big">&#xf4a0;</span>|oct_tasklist|
|<span class="nerdfont big">&#xf46b;</span>|oct_telescope|
|<span class="nerdfont big">&#xf489;</span>|oct_terminal|
|<span class="nerdfont big">&#xf49e;</span>|oct_text_size|
|<span class="nerdfont big">&#xf44e;</span>|oct_three_bars|
|<span class="nerdfont big">&#xf497;</span>|oct_thumbsdown|
|<span class="nerdfont big">&#xf496;</span>|oct_thumbsup|
|<span class="nerdfont big">&#xf425;</span>|oct_tools|
|<span class="nerdfont big">&#xf48e;</span>|oct_trashcan|
|<span class="nerdfont big">&#xf44b;</span>|oct_triangle_down|
|<span class="nerdfont big">&#xf438;</span>|oct_triangle_left|
|<span class="nerdfont big">&#xf44a;</span>|oct_triangle_right|
|<span class="nerdfont big">&#xf47e;</span>|oct_triangle_up|
|<span class="nerdfont big">&#xf42d;</span>|oct_unfold|
|<span class="nerdfont big">&#xf485;</span>|oct_unmute|
|<span class="nerdfont big">&#xf4a3;</span>|oct_unverified|
|<span class="nerdfont big">&#xf4a1;</span>|oct_verified|
|<span class="nerdfont big">&#xf454;</span>|oct_versions|
|<span class="nerdfont big">&#xf49b;</span>|oct_watch|
|<span class="nerdfont big">&#xf467;</span>|oct_x|
|<span class="nerdfont big">&#x26a1;</span>|oct_zap|
|<span class="nerdfont big">&#xe0a0;</span>|pl_branch|
|<span class="nerdfont big">&#xe0a2;</span>|pl_hostname|
|<span class="nerdfont big">&#xe0b0;</span>|pl_left_hard_divider|
|<span class="nerdfont big">&#xe0b1;</span>|pl_left_soft_divider|
|<span class="nerdfont big">&#xe0a1;</span>|pl_line_number|
|<span class="nerdfont big">&#xe0b2;</span>|pl_right_hard_divider|
|<span class="nerdfont big">&#xe0b3;</span>|pl_right_soft_divider|
|<span class="nerdfont big">&#xe0b9;</span>|ple_backslash_separator|
|<span class="nerdfont big">&#xe0bf;</span>|ple_backslash_separator_redundant|
|<span class="nerdfont big">&#xe0a3;</span>|ple_column_number|
|<span class="nerdfont big">&#xe0c0;</span>|ple_flame_thick|
|<span class="nerdfont big">&#xe0c2;</span>|ple_flame_thick_mirrored|
|<span class="nerdfont big">&#xe0c1;</span>|ple_flame_thin|
|<span class="nerdfont big">&#xe0c3;</span>|ple_flame_thin_mirrored|
|<span class="nerdfont big">&#xe0bb;</span>|ple_forwardslash_separator|
|<span class="nerdfont big">&#xe0bd;</span>|ple_forwardslash_separator_redundant|
|<span class="nerdfont big">&#xe0cc;</span>|ple_honeycomb|
|<span class="nerdfont big">&#xe0cd;</span>|ple_honeycomb_outline|
|<span class="nerdfont big">&#xe0c8;</span>|ple_ice_waveform|
|<span class="nerdfont big">&#xe0ca;</span>|ple_ice_waveform_mirrored|
|<span class="nerdfont big">&#xe0b6;</span>|ple_left_half_circle_thick|
|<span class="nerdfont big">&#xe0b7;</span>|ple_left_half_circle_thin|
|<span class="nerdfont big">&#xe0d0;</span>|ple_lego_block_facing|
|<span class="nerdfont big">&#xe0d1;</span>|ple_lego_block_sideways|
|<span class="nerdfont big">&#xe0ce;</span>|ple_lego_separator|
|<span class="nerdfont big">&#xe0cf;</span>|ple_lego_separator_thin|
|<span class="nerdfont big">&#xe0b8;</span>|ple_lower_left_triangle|
|<span class="nerdfont big">&#xe0ba;</span>|ple_lower_right_triangle|
|<span class="nerdfont big">&#xe0c6;</span>|ple_pixelated_squares_big|
|<span class="nerdfont big">&#xe0c7;</span>|ple_pixelated_squares_big_mirrored|
|<span class="nerdfont big">&#xe0c4;</span>|ple_pixelated_squares_small|
|<span class="nerdfont big">&#xe0c5;</span>|ple_pixelated_squares_small_mirrored|
|<span class="nerdfont big">&#xe0b4;</span>|ple_right_half_circle_thick|
|<span class="nerdfont big">&#xe0b5;</span>|ple_right_half_circle_thin|
|<span class="nerdfont big">&#xe0d2;</span>|ple_trapezoid_top_bottom|
|<span class="nerdfont big">&#xe0d4;</span>|ple_trapezoid_top_bottom_mirrored|
|<span class="nerdfont big">&#xe0bc;</span>|ple_upper_left_triangle|
|<span class="nerdfont big">&#xe0be;</span>|ple_upper_right_triangle|
|<span class="nerdfont big">&#xe007;</span>|pom_away|
|<span class="nerdfont big">&#xe000;</span>|pom_clean_code|
|<span class="nerdfont big">&#xe00a;</span>|pom_external_interruption|
|<span class="nerdfont big">&#xe009;</span>|pom_internal_interruption|
|<span class="nerdfont big">&#xe006;</span>|pom_long_pause|
|<span class="nerdfont big">&#xe008;</span>|pom_pair_programming|
|<span class="nerdfont big">&#xe001;</span>|pom_pomodoro_done|
|<span class="nerdfont big">&#xe002;</span>|pom_pomodoro_estimated|
|<span class="nerdfont big">&#xe004;</span>|pom_pomodoro_squashed|
|<span class="nerdfont big">&#xe003;</span>|pom_pomodoro_ticking|
|<span class="nerdfont big">&#xe005;</span>|pom_short_pause|
|<span class="nerdfont big">&#xe635;</span>|seti_apple|
|<span class="nerdfont big">&#xe636;</span>|seti_argdown|
|<span class="nerdfont big">&#xe637;</span>|seti_asm|
|<span class="nerdfont big">&#xe638;</span>|seti_audio|
|<span class="nerdfont big">&#xe639;</span>|seti_babel|
|<span class="nerdfont big">&#xe63a;</span>|seti_bazel|
|<span class="nerdfont big">&#xe63b;</span>|seti_bicep|
|<span class="nerdfont big">&#xe61a;</span>|seti_bower|
|<span class="nerdfont big">&#xe63c;</span>|seti_bsl|
|<span class="nerdfont big">&#xe649;</span>|seti_c|
|<span class="nerdfont big">&#xe648;</span>|seti_c_sharp|
|<span class="nerdfont big">&#xe63e;</span>|seti_cake|
|<span class="nerdfont big">&#xe63d;</span>|seti_cake_php|
|<span class="nerdfont big">&#xe63f;</span>|seti_checkbox|
|<span class="nerdfont big">&#xe640;</span>|seti_checkbox_unchecked|
|<span class="nerdfont big">&#xe641;</span>|seti_clock|
|<span class="nerdfont big">&#xe642;</span>|seti_clojure|
|<span class="nerdfont big">&#xe643;</span>|seti_code_climate|
|<span class="nerdfont big">&#xe644;</span>|seti_code_search|
|<span class="nerdfont big">&#xe61b;</span>|seti_coffee|
|<span class="nerdfont big">&#xe645;</span>|seti_coldfusion|
|<span class="nerdfont big">&#xe615;</span>|seti_config|
|<span class="nerdfont big">&#xe646;</span>|seti_cpp|
|<span class="nerdfont big">&#xe647;</span>|seti_crystal_embedded|
|<span class="nerdfont big">&#xe614;</span>|seti_css|
|<span class="nerdfont big">&#xe64a;</span>|seti_csv|
|<span class="nerdfont big">&#xe64b;</span>|seti_cu|
|<span class="nerdfont big">&#xe651;</span>|seti_d|
|<span class="nerdfont big">&#xe64c;</span>|seti_dart|
|<span class="nerdfont big">&#xe64d;</span>|seti_db|
|<span class="nerdfont big">&#xe64e;</span>|seti_default|
|<span class="nerdfont big">&#xe64f;</span>|seti_deprecation_cop|
|<span class="nerdfont big">&#xe650;</span>|seti_docker|
|<span class="nerdfont big">&#xe652;</span>|seti_editorconfig|
|<span class="nerdfont big">&#xe618;</span>|seti_ejs|
|<span class="nerdfont big">&#xe653;</span>|seti_elixir_script|
|<span class="nerdfont big">&#xe654;</span>|seti_error|
|<span class="nerdfont big">&#xe655;</span>|seti_eslint|
|<span class="nerdfont big">&#xe656;</span>|seti_ethereum|
|<span class="nerdfont big">&#xe65a;</span>|seti_f_sharp|
|<span class="nerdfont big">&#xe623;</span>|seti_favicon|
|<span class="nerdfont big">&#xe657;</span>|seti_firebase|
|<span class="nerdfont big">&#xe658;</span>|seti_firefox|
|<span class="nerdfont big">&#xe613;</span>|seti_folder|
|<span class="nerdfont big">&#xe659;</span>|seti_font|
|<span class="nerdfont big">&#xe65d;</span>|seti_git|
|<span class="nerdfont big">&#xe65b;</span>|seti_github|
|<span class="nerdfont big">&#xe65c;</span>|seti_gitlab|
|<span class="nerdfont big">&#xe627;</span>|seti_go|
|<span class="nerdfont big">&#xe65e;</span>|seti_go2|
|<span class="nerdfont big">&#xe65f;</span>|seti_godot|
|<span class="nerdfont big">&#xe660;</span>|seti_gradle|
|<span class="nerdfont big">&#xe661;</span>|seti_grails|
|<span class="nerdfont big">&#xe662;</span>|seti_graphql|
|<span class="nerdfont big">&#xe611;</span>|seti_grunt|
|<span class="nerdfont big">&#xe610;</span>|seti_gulp|
|<span class="nerdfont big">&#xe663;</span>|seti_hacklang|
|<span class="nerdfont big">&#xe664;</span>|seti_haml|
|<span class="nerdfont big">&#xe665;</span>|seti_happenings|
|<span class="nerdfont big">&#xe61f;</span>|seti_haskell|
|<span class="nerdfont big">&#xe666;</span>|seti_haxe|
|<span class="nerdfont big">&#xe607;</span>|seti_heroku|
|<span class="nerdfont big">&#xe667;</span>|seti_hex|
|<span class="nerdfont big">&#xe60e;</span>|seti_html|
|<span class="nerdfont big">&#xe668;</span>|seti_ignored|
|<span class="nerdfont big">&#xe669;</span>|seti_illustrator|
|<span class="nerdfont big">&#xe60d;</span>|seti_image|
|<span class="nerdfont big">&#xe66a;</span>|seti_info|
|<span class="nerdfont big">&#xe66b;</span>|seti_ionic|
|<span class="nerdfont big">&#xe66c;</span>|seti_jade|
|<span class="nerdfont big">&#xe66d;</span>|seti_java|
|<span class="nerdfont big">&#xe60c;</span>|seti_javascript|
|<span class="nerdfont big">&#xe66e;</span>|seti_jenkins|
|<span class="nerdfont big">&#xe66f;</span>|seti_jinja|
|<span class="nerdfont big">&#xe60b;</span>|seti_json|
|<span class="nerdfont big">&#xe624;</span>|seti_julia|
|<span class="nerdfont big">&#xe622;</span>|seti_karma|
|<span class="nerdfont big">&#xe60a;</span>|seti_license|
|<span class="nerdfont big">&#xe670;</span>|seti_liquid|
|<span class="nerdfont big">&#xe671;</span>|seti_livescript|
|<span class="nerdfont big">&#xe672;</span>|seti_lock|
|<span class="nerdfont big">&#xe620;</span>|seti_lua|
|<span class="nerdfont big">&#xe673;</span>|seti_makefile|
|<span class="nerdfont big">&#xe609;</span>|seti_markdown|
|<span class="nerdfont big">&#xe674;</span>|seti_maven|
|<span class="nerdfont big">&#xe675;</span>|seti_mdo|
|<span class="nerdfont big">&#xe60f;</span>|seti_mustache|
|<span class="nerdfont big">&#xe676;</span>|seti_new_file|
|<span class="nerdfont big">&#xe677;</span>|seti_nim|
|<span class="nerdfont big">&#xe678;</span>|seti_notebook|
|<span class="nerdfont big">&#xe616;</span>|seti_npm|
|<span class="nerdfont big">&#xe679;</span>|seti_nunjucks|
|<span class="nerdfont big">&#xe67a;</span>|seti_ocaml|
|<span class="nerdfont big">&#xe67b;</span>|seti_odata|
|<span class="nerdfont big">&#xe67c;</span>|seti_pddl|
|<span class="nerdfont big">&#xe67d;</span>|seti_pdf|
|<span class="nerdfont big">&#xe67e;</span>|seti_perl|
|<span class="nerdfont big">&#xe67f;</span>|seti_photoshop|
|<span class="nerdfont big">&#xe608;</span>|seti_php|
|<span class="nerdfont big">&#xe680;</span>|seti_pipeline|
|<span class="nerdfont big">&#xe681;</span>|seti_plan|
|<span class="nerdfont big">&#xe682;</span>|seti_platformio|
|<span class="nerdfont big">&#xe683;</span>|seti_powershell|
|<span class="nerdfont big">&#xe684;</span>|seti_prisma|
|<span class="nerdfont big">&#xe601;</span>|seti_project|
|<span class="nerdfont big">&#xe685;</span>|seti_prolog|
|<span class="nerdfont big">&#xe686;</span>|seti_pug|
|<span class="nerdfont big">&#xe631;</span>|seti_puppet|
|<span class="nerdfont big">&#xe606;</span>|seti_python|
|<span class="nerdfont big">&#xe68a;</span>|seti_r|
|<span class="nerdfont big">&#xe604;</span>|seti_rails|
|<span class="nerdfont big">&#xe625;</span>|seti_react|
|<span class="nerdfont big">&#xe687;</span>|seti_reasonml|
|<span class="nerdfont big">&#xe688;</span>|seti_rescript|
|<span class="nerdfont big">&#xe689;</span>|seti_rollup|
|<span class="nerdfont big">&#xe605;</span>|seti_ruby|
|<span class="nerdfont big">&#xe68b;</span>|seti_rust|
|<span class="nerdfont big">&#xe68c;</span>|seti_salesforce|
|<span class="nerdfont big">&#xe603;</span>|seti_sass|
|<span class="nerdfont big">&#xe68d;</span>|seti_sbt|
|<span class="nerdfont big">&#xe68e;</span>|seti_scala|
|<span class="nerdfont big">&#xe68f;</span>|seti_search|
|<span class="nerdfont big">&#xe690;</span>|seti_settings|
|<span class="nerdfont big">&#xe691;</span>|seti_shell|
|<span class="nerdfont big">&#xe692;</span>|seti_slim|
|<span class="nerdfont big">&#xe693;</span>|seti_smarty|
|<span class="nerdfont big">&#xe694;</span>|seti_spring|
|<span class="nerdfont big">&#xe695;</span>|seti_stylelint|
|<span class="nerdfont big">&#xe600;</span>|seti_stylus|
|<span class="nerdfont big">&#xe696;</span>|seti_sublime|
|<span class="nerdfont big">&#xe697;</span>|seti_svelte|
|<span class="nerdfont big">&#xe698;</span>|seti_svg|
|<span class="nerdfont big">&#xe699;</span>|seti_swift|
|<span class="nerdfont big">&#xe69a;</span>|seti_terraform|
|<span class="nerdfont big">&#xe69b;</span>|seti_tex|
|<span class="nerdfont big">&#xe69c;</span>|seti_todo|
|<span class="nerdfont big">&#xe69d;</span>|seti_tsconfig|
|<span class="nerdfont big">&#xe61c;</span>|seti_twig|
|<span class="nerdfont big">&#xe628;</span>|seti_typescript|
|<span class="nerdfont big">&#xe69e;</span>|seti_vala|
|<span class="nerdfont big">&#xe69f;</span>|seti_video|
|<span class="nerdfont big">&#xe6a0;</span>|seti_vue|
|<span class="nerdfont big">&#xe6a1;</span>|seti_wasm|
|<span class="nerdfont big">&#xe6a2;</span>|seti_wat|
|<span class="nerdfont big">&#xe6a3;</span>|seti_webpack|
|<span class="nerdfont big">&#xe6a4;</span>|seti_wgt|
|<span class="nerdfont big">&#xe6a5;</span>|seti_word|
|<span class="nerdfont big">&#xe6a6;</span>|seti_xls|
|<span class="nerdfont big">&#xe619;</span>|seti_xml|
|<span class="nerdfont big">&#xe6a7;</span>|seti_yarn|
|<span class="nerdfont big">&#xe6a8;</span>|seti_yml|
|<span class="nerdfont big">&#xe6a9;</span>|seti_zig|
|<span class="nerdfont big">&#xe6aa;</span>|seti_zip|
|<span class="nerdfont big">&#xe36e;</span>|weather_alien|
|<span class="nerdfont big">&#xe345;</span>|weather_aliens|
|<span class="nerdfont big">&#xe372;</span>|weather_barometer|
|<span class="nerdfont big">&#xe339;</span>|weather_celsius|
|<span class="nerdfont big">&#xe33d;</span>|weather_cloud|
|<span class="nerdfont big">&#xe33a;</span>|weather_cloud_down|
|<span class="nerdfont big">&#xe33b;</span>|weather_cloud_refresh|
|<span class="nerdfont big">&#xe33c;</span>|weather_cloud_up|
|<span class="nerdfont big">&#xe312;</span>|weather_cloudy|
|<span class="nerdfont big">&#xe310;</span>|weather_cloudy_gusts|
|<span class="nerdfont big">&#xe311;</span>|weather_cloudy_windy|
|<span class="nerdfont big">&#xe302;</span>|weather_day_cloudy|
|<span class="nerdfont big">&#xe300;</span>|weather_day_cloudy_gusts|
|<span class="nerdfont big">&#xe376;</span>|weather_day_cloudy_high|
|<span class="nerdfont big">&#xe301;</span>|weather_day_cloudy_windy|
|<span class="nerdfont big">&#xe303;</span>|weather_day_fog|
|<span class="nerdfont big">&#xe304;</span>|weather_day_hail|
|<span class="nerdfont big">&#xe3ae;</span>|weather_day_haze|
|<span class="nerdfont big">&#xe3bc;</span>|weather_day_light_wind|
|<span class="nerdfont big">&#xe305;</span>|weather_day_lightning|
|<span class="nerdfont big">&#xe308;</span>|weather_day_rain|
|<span class="nerdfont big">&#xe306;</span>|weather_day_rain_mix|
|<span class="nerdfont big">&#xe307;</span>|weather_day_rain_wind|
|<span class="nerdfont big">&#xe309;</span>|weather_day_showers|
|<span class="nerdfont big">&#xe3aa;</span>|weather_day_sleet|
|<span class="nerdfont big">&#xe362;</span>|weather_day_sleet_storm|
|<span class="nerdfont big">&#xe30a;</span>|weather_day_snow|
|<span class="nerdfont big">&#xe365;</span>|weather_day_snow_thunderstorm|
|<span class="nerdfont big">&#xe35f;</span>|weather_day_snow_wind|
|<span class="nerdfont big">&#xe30b;</span>|weather_day_sprinkle|
|<span class="nerdfont big">&#xe30e;</span>|weather_day_storm_showers|
|<span class="nerdfont big">&#xe30d;</span>|weather_day_sunny|
|<span class="nerdfont big">&#xe30c;</span>|weather_day_sunny_overcast|
|<span class="nerdfont big">&#xe30f;</span>|weather_day_thunderstorm|
|<span class="nerdfont big">&#xe37d;</span>|weather_day_windy|
|<span class="nerdfont big">&#xe33e;</span>|weather_degrees|
|<span class="nerdfont big">&#xe340;</span>|weather_direction_down|
|<span class="nerdfont big">&#xe33f;</span>|weather_direction_down_left|
|<span class="nerdfont big">&#xe380;</span>|weather_direction_down_right|
|<span class="nerdfont big">&#xe344;</span>|weather_direction_left|
|<span class="nerdfont big">&#xe349;</span>|weather_direction_right|
|<span class="nerdfont big">&#xe353;</span>|weather_direction_up|
|<span class="nerdfont big">&#xe37f;</span>|weather_direction_up_left|
|<span class="nerdfont big">&#xe352;</span>|weather_direction_up_right|
|<span class="nerdfont big">&#xe35d;</span>|weather_dust|
|<span class="nerdfont big">&#xe3be;</span>|weather_earthquake|
|<span class="nerdfont big">&#xe341;</span>|weather_fahrenheit|
|<span class="nerdfont big">&#xe3bf;</span>|weather_fire|
|<span class="nerdfont big">&#xe375;</span>|weather_flood|
|<span class="nerdfont big">&#xe313;</span>|weather_fog|
|<span class="nerdfont big">&#xe3c5;</span>|weather_gale_warning|
|<span class="nerdfont big">&#xe314;</span>|weather_hail|
|<span class="nerdfont big">&#xe343;</span>|weather_horizon|
|<span class="nerdfont big">&#xe342;</span>|weather_horizon_alt|
|<span class="nerdfont big">&#xe36b;</span>|weather_hot|
|<span class="nerdfont big">&#xe373;</span>|weather_humidity|
|<span class="nerdfont big">&#xe36c;</span>|weather_hurricane|
|<span class="nerdfont big">&#xe3c7;</span>|weather_hurricane_warning|
|<span class="nerdfont big">&#xe315;</span>|weather_lightning|
|<span class="nerdfont big">&#xe369;</span>|weather_lunar_eclipse|
|<span class="nerdfont big">&#xe36a;</span>|weather_meteor|
|<span class="nerdfont big">&#xe3ce;</span>|weather_moon_alt_first_quarter|
|<span class="nerdfont big">&#xe3d5;</span>|weather_moon_alt_full|
|<span class="nerdfont big">&#xe3e3;</span>|weather_moon_alt_new|
|<span class="nerdfont big">&#xe3dc;</span>|weather_moon_alt_third_quarter|
|<span class="nerdfont big">&#xe3dd;</span>|weather_moon_alt_waning_crescent_1|
|<span class="nerdfont big">&#xe3de;</span>|weather_moon_alt_waning_crescent_2|
|<span class="nerdfont big">&#xe3df;</span>|weather_moon_alt_waning_crescent_3|
|<span class="nerdfont big">&#xe3e0;</span>|weather_moon_alt_waning_crescent_4|
|<span class="nerdfont big">&#xe3e1;</span>|weather_moon_alt_waning_crescent_5|
|<span class="nerdfont big">&#xe3e2;</span>|weather_moon_alt_waning_crescent_6|
|<span class="nerdfont big">&#xe3d6;</span>|weather_moon_alt_waning_gibbous_1|
|<span class="nerdfont big">&#xe3d7;</span>|weather_moon_alt_waning_gibbous_2|
|<span class="nerdfont big">&#xe3d8;</span>|weather_moon_alt_waning_gibbous_3|
|<span class="nerdfont big">&#xe3d9;</span>|weather_moon_alt_waning_gibbous_4|
|<span class="nerdfont big">&#xe3da;</span>|weather_moon_alt_waning_gibbous_5|
|<span class="nerdfont big">&#xe3db;</span>|weather_moon_alt_waning_gibbous_6|
|<span class="nerdfont big">&#xe3c8;</span>|weather_moon_alt_waxing_crescent_1|
|<span class="nerdfont big">&#xe3c9;</span>|weather_moon_alt_waxing_crescent_2|
|<span class="nerdfont big">&#xe3ca;</span>|weather_moon_alt_waxing_crescent_3|
|<span class="nerdfont big">&#xe3cb;</span>|weather_moon_alt_waxing_crescent_4|
|<span class="nerdfont big">&#xe3cc;</span>|weather_moon_alt_waxing_crescent_5|
|<span class="nerdfont big">&#xe3cd;</span>|weather_moon_alt_waxing_crescent_6|
|<span class="nerdfont big">&#xe3cf;</span>|weather_moon_alt_waxing_gibbous_1|
|<span class="nerdfont big">&#xe3d0;</span>|weather_moon_alt_waxing_gibbous_2|
|<span class="nerdfont big">&#xe3d1;</span>|weather_moon_alt_waxing_gibbous_3|
|<span class="nerdfont big">&#xe3d2;</span>|weather_moon_alt_waxing_gibbous_4|
|<span class="nerdfont big">&#xe3d3;</span>|weather_moon_alt_waxing_gibbous_5|
|<span class="nerdfont big">&#xe3d4;</span>|weather_moon_alt_waxing_gibbous_6|
|<span class="nerdfont big">&#xe394;</span>|weather_moon_first_quarter|
|<span class="nerdfont big">&#xe39b;</span>|weather_moon_full|
|<span class="nerdfont big">&#xe38d;</span>|weather_moon_new|
|<span class="nerdfont big">&#xe3a2;</span>|weather_moon_third_quarter|
|<span class="nerdfont big">&#xe3a3;</span>|weather_moon_waning_crescent_1|
|<span class="nerdfont big">&#xe3a4;</span>|weather_moon_waning_crescent_2|
|<span class="nerdfont big">&#xe3a5;</span>|weather_moon_waning_crescent_3|
|<span class="nerdfont big">&#xe3a6;</span>|weather_moon_waning_crescent_4|
|<span class="nerdfont big">&#xe3a7;</span>|weather_moon_waning_crescent_5|
|<span class="nerdfont big">&#xe3a8;</span>|weather_moon_waning_crescent_6|
|<span class="nerdfont big">&#xe39c;</span>|weather_moon_waning_gibbous_1|
|<span class="nerdfont big">&#xe39d;</span>|weather_moon_waning_gibbous_2|
|<span class="nerdfont big">&#xe39e;</span>|weather_moon_waning_gibbous_3|
|<span class="nerdfont big">&#xe39f;</span>|weather_moon_waning_gibbous_4|
|<span class="nerdfont big">&#xe3a0;</span>|weather_moon_waning_gibbous_5|
|<span class="nerdfont big">&#xe3a1;</span>|weather_moon_waning_gibbous_6|
|<span class="nerdfont big">&#xe38e;</span>|weather_moon_waxing_crescent_1|
|<span class="nerdfont big">&#xe38f;</span>|weather_moon_waxing_crescent_2|
|<span class="nerdfont big">&#xe390;</span>|weather_moon_waxing_crescent_3|
|<span class="nerdfont big">&#xe391;</span>|weather_moon_waxing_crescent_4|
|<span class="nerdfont big">&#xe392;</span>|weather_moon_waxing_crescent_5|
|<span class="nerdfont big">&#xe393;</span>|weather_moon_waxing_crescent_6|
|<span class="nerdfont big">&#xe395;</span>|weather_moon_waxing_gibbous_1|
|<span class="nerdfont big">&#xe396;</span>|weather_moon_waxing_gibbous_2|
|<span class="nerdfont big">&#xe397;</span>|weather_moon_waxing_gibbous_3|
|<span class="nerdfont big">&#xe398;</span>|weather_moon_waxing_gibbous_4|
|<span class="nerdfont big">&#xe399;</span>|weather_moon_waxing_gibbous_5|
|<span class="nerdfont big">&#xe39a;</span>|weather_moon_waxing_gibbous_6|
|<span class="nerdfont big">&#xe3c1;</span>|weather_moonrise|
|<span class="nerdfont big">&#xe3c2;</span>|weather_moonset|
|<span class="nerdfont big">&#xe374;</span>|weather_na|
|<span class="nerdfont big">&#xe37e;</span>|weather_night_alt_cloudy|
|<span class="nerdfont big">&#xe31f;</span>|weather_night_alt_cloudy_gusts|
|<span class="nerdfont big">&#xe377;</span>|weather_night_alt_cloudy_high|
|<span class="nerdfont big">&#xe320;</span>|weather_night_alt_cloudy_windy|
|<span class="nerdfont big">&#xe321;</span>|weather_night_alt_hail|
|<span class="nerdfont big">&#xe322;</span>|weather_night_alt_lightning|
|<span class="nerdfont big">&#xe379;</span>|weather_night_alt_partly_cloudy|
|<span class="nerdfont big">&#xe325;</span>|weather_night_alt_rain|
|<span class="nerdfont big">&#xe323;</span>|weather_night_alt_rain_mix|
|<span class="nerdfont big">&#xe326;</span>|weather_night_alt_rain_mix|
|<span class="nerdfont big">&#xe324;</span>|weather_night_alt_rain_wind|
|<span class="nerdfont big">&#xe3ac;</span>|weather_night_alt_sleet|
|<span class="nerdfont big">&#xe364;</span>|weather_night_alt_sleet_storm|
|<span class="nerdfont big">&#xe327;</span>|weather_night_alt_snow|
|<span class="nerdfont big">&#xe367;</span>|weather_night_alt_snow_thunderstorm|
|<span class="nerdfont big">&#xe361;</span>|weather_night_alt_snow_wind|
|<span class="nerdfont big">&#xe328;</span>|weather_night_alt_sprinkle|
|<span class="nerdfont big">&#xe329;</span>|weather_night_alt_storm_showers|
|<span class="nerdfont big">&#xe32a;</span>|weather_night_alt_thunderstorm|
|<span class="nerdfont big">&#xe32b;</span>|weather_night_clear|
|<span class="nerdfont big">&#xe32e;</span>|weather_night_cloudy|
|<span class="nerdfont big">&#xe32c;</span>|weather_night_cloudy_gusts|
|<span class="nerdfont big">&#xe378;</span>|weather_night_cloudy_high|
|<span class="nerdfont big">&#xe32d;</span>|weather_night_cloudy_windy|
|<span class="nerdfont big">&#xe346;</span>|weather_night_fog|
|<span class="nerdfont big">&#xe32f;</span>|weather_night_hail|
|<span class="nerdfont big">&#xe330;</span>|weather_night_lightning|
|<span class="nerdfont big">&#xe37b;</span>|weather_night_partly_cloudy|
|<span class="nerdfont big">&#xe333;</span>|weather_night_rain|
|<span class="nerdfont big">&#xe331;</span>|weather_night_rain_mix|
|<span class="nerdfont big">&#xe332;</span>|weather_night_rain_wind|
|<span class="nerdfont big">&#xe334;</span>|weather_night_showers|
|<span class="nerdfont big">&#xe3ab;</span>|weather_night_sleet|
|<span class="nerdfont big">&#xe363;</span>|weather_night_sleet_storm|
|<span class="nerdfont big">&#xe335;</span>|weather_night_snow|
|<span class="nerdfont big">&#xe366;</span>|weather_night_snow_thunderstorm|
|<span class="nerdfont big">&#xe360;</span>|weather_night_snow_wind|
|<span class="nerdfont big">&#xe336;</span>|weather_night_sprinkle|
|<span class="nerdfont big">&#xe337;</span>|weather_night_storm_showers|
|<span class="nerdfont big">&#xe338;</span>|weather_night_thunderstorm|
|<span class="nerdfont big">&#xe318;</span>|weather_rain|
|<span class="nerdfont big">&#xe316;</span>|weather_rain_mix|
|<span class="nerdfont big">&#xe317;</span>|weather_rain_wind|
|<span class="nerdfont big">&#xe371;</span>|weather_raindrop|
|<span class="nerdfont big">&#xe34a;</span>|weather_raindrops|
|<span class="nerdfont big">&#xe348;</span>|weather_refresh|
|<span class="nerdfont big">&#xe347;</span>|weather_refresh_alt|
|<span class="nerdfont big">&#xe37a;</span>|weather_sandstorm|
|<span class="nerdfont big">&#xe319;</span>|weather_showers|
|<span class="nerdfont big">&#xe3ad;</span>|weather_sleet|
|<span class="nerdfont big">&#xe3c4;</span>|weather_small_craft_advisory|
|<span class="nerdfont big">&#xe36d;</span>|weather_smog|
|<span class="nerdfont big">&#xe35c;</span>|weather_smoke|
|<span class="nerdfont big">&#xe31a;</span>|weather_snow|
|<span class="nerdfont big">&#xe35e;</span>|weather_snow_wind|
|<span class="nerdfont big">&#xe36f;</span>|weather_snowflake_cold|
|<span class="nerdfont big">&#xe368;</span>|weather_solar_eclipse|
|<span class="nerdfont big">&#xe31b;</span>|weather_sprinkle|
|<span class="nerdfont big">&#xe370;</span>|weather_stars|
|<span class="nerdfont big">&#xe31c;</span>|weather_storm_showers|
|<span class="nerdfont big">&#xe3c6;</span>|weather_storm_warning|
|<span class="nerdfont big">&#xe34b;</span>|weather_strong_wind|
|<span class="nerdfont big">&#xe34c;</span>|weather_sunrise|
|<span class="nerdfont big">&#xe34d;</span>|weather_sunset|
|<span class="nerdfont big">&#xe350;</span>|weather_thermometer|
|<span class="nerdfont big">&#xe34e;</span>|weather_thermometer_exterior|
|<span class="nerdfont big">&#xe34f;</span>|weather_thermometer_internal|
|<span class="nerdfont big">&#xe31d;</span>|weather_thunderstorm|
|<span class="nerdfont big">&#xe382;</span>|weather_time_1|
|<span class="nerdfont big">&#xe383;</span>|weather_time_2|
|<span class="nerdfont big">&#xe384;</span>|weather_time_3|
|<span class="nerdfont big">&#xe385;</span>|weather_time_4|
|<span class="nerdfont big">&#xe386;</span>|weather_time_5|
|<span class="nerdfont big">&#xe387;</span>|weather_time_6|
|<span class="nerdfont big">&#xe388;</span>|weather_time_7|
|<span class="nerdfont big">&#xe389;</span>|weather_time_8|
|<span class="nerdfont big">&#xe38a;</span>|weather_time_9|
|<span class="nerdfont big">&#xe38b;</span>|weather_time_10|
|<span class="nerdfont big">&#xe38c;</span>|weather_time_11|
|<span class="nerdfont big">&#xe381;</span>|weather_time_12|
|<span class="nerdfont big">&#xe351;</span>|weather_tornado|
|<span class="nerdfont big">&#xe3c3;</span>|weather_train|
|<span class="nerdfont big">&#xe3bd;</span>|weather_tsunami|
|<span class="nerdfont big">&#xe37c;</span>|weather_umbrella|
|<span class="nerdfont big">&#xe3c0;</span>|weather_volcano|
|<span class="nerdfont big">&#xe3af;</span>|weather_wind_beaufort_0|
|<span class="nerdfont big">&#xe3b0;</span>|weather_wind_beaufort_1|
|<span class="nerdfont big">&#xe3b1;</span>|weather_wind_beaufort_2|
|<span class="nerdfont big">&#xe3b2;</span>|weather_wind_beaufort_3|
|<span class="nerdfont big">&#xe3b3;</span>|weather_wind_beaufort_4|
|<span class="nerdfont big">&#xe3b4;</span>|weather_wind_beaufort_5|
|<span class="nerdfont big">&#xe3b5;</span>|weather_wind_beaufort_6|
|<span class="nerdfont big">&#xe3b6;</span>|weather_wind_beaufort_7|
|<span class="nerdfont big">&#xe3b7;</span>|weather_wind_beaufort_8|
|<span class="nerdfont big">&#xe3b8;</span>|weather_wind_beaufort_9|
|<span class="nerdfont big">&#xe3b9;</span>|weather_wind_beaufort_10|
|<span class="nerdfont big">&#xe3ba;</span>|weather_wind_beaufort_11|
|<span class="nerdfont big">&#xe3bb;</span>|weather_wind_beaufort_12|
|<span class="nerdfont big">&#xe3a9;</span>|weather_wind_direction|
|<span class="nerdfont big">&#xe35b;</span>|weather_wind_east|
|<span class="nerdfont big">&#xe35a;</span>|weather_wind_north|
|<span class="nerdfont big">&#xe359;</span>|weather_wind_north_east|
|<span class="nerdfont big">&#xe358;</span>|weather_wind_north_west|
|<span class="nerdfont big">&#xe357;</span>|weather_wind_south|
|<span class="nerdfont big">&#xe356;</span>|weather_wind_south_east|
|<span class="nerdfont big">&#xe355;</span>|weather_wind_south_west|
|<span class="nerdfont big">&#xe354;</span>|weather_wind_west|
|<span class="nerdfont big">&#xe31e;</span>|weather_windy|
